'use strict';


let xs2playerStatsRequests = [];

if (typeof(xs2content) === "undefined") {
    var xs2content = {};
}

document.addEventListener('DOMContentLoaded', function() {
    var players = document.getElementsByClassName('xs2player');

    for (var i = 0; i < players.length; ++i) {
        var player = players[i];  

        xs2player_load(player);
    }
});


function xs2player_load(player) {
    var title = player.dataset.title || player.dataset.postTitle || '';
    var description = player.dataset.description || '';

    var postId = player.dataset.postId || 0;
    var postTitle = player.dataset.postTitle || '';
    var postImage = player.dataset.postImage || '';
    var template = player.dataset.template || xs2content.template || 'simple';
    var style = player.dataset.style || xs2content.style || 'default';
    var type = player.dataset.type || 'widget';
    var waveColor = player.dataset.waveColor || xs2content.waveColor || '#999';
    var progressColor = player.dataset.progressColor || xs2content.progressColor || false
    var blockStyle = '';

    var styling = '';
    var backgroundColor = player.dataset.backgroundColor || xs2content.backgroundColor || false
    var textColor = player.dataset.textColor || xs2content.textColor || false

    if (backgroundColor) {
        styling += 'background: ' + backgroundColor + ';';
    }
    if (textColor) {
        styling += 'color: ' + textColor;
    }

    if (!progressColor) {
        if (template == 'block') {
            switch (style) {
                case 'blue':
                    progressColor = '#324286';
                    break;
                case 'yellow':
                    progressColor = '#cda814';
                    break;
                case 'red':
                    progressColor = '#9e1f18';
                    break;
                default:
                    progressColor = '#555';
            }
        }
        else {
            progressColor = '#555';
        }
    }

    if (template != 'wavesurfer') {
        player.addEventListener("play", function() {
            xs2player_save_stat('started', postId, postTitle, type);
        });
        player.addEventListener("ended", function() {
            xs2player_save_stat('finished', postId, postTitle, type);
        });

        let trackHalfway = function(current) {
            if (this.currentTime > (this.duration / 2)) {
                xs2player_save_stat('halfway', postId, postTitle, type);
                player.removeEventListener("timeupdate", trackHalfway);
            }
        }
        player.addEventListener("timeupdate", trackHalfway);
    }

    if (template == 'simple') {
        var html = '<div class="xs2player-player xs2player-template-' + template + ' xs2player-style-' + style + '"' + (styling ? ' style="' + styling + '"' : '' ) + '>';
        if (title) {
            html += '<h3 class="xs2player-player-title">' + title + '</h3>';
        }
        html += '</div>';
        player.insertAdjacentHTML('beforebegin', html);
        var playerHTML = player.previousSibling;
    }
    else if (template == 'block' || template == 'wavesurfer') {
        player.style.display = "none";

        var html = '<div class="xs2player-player xs2player-template-' + template + ' xs2player-style-' + style + '"' + (styling ? ' style="' + styling + '"' : '' ) + '>';

        html += '<div class="xs2player-info">';
        if (title) {
            html += '<h3 class="xs2player-player-title">' + title + '</h3>';
        }
        if (description) {
            html += '<p class="xs2player-player-description">' + description + '</p>';
        }
        html += '</div>';

        html += '<div class="xs2player-columns ' + (postImage ? '' : 'no-image') + '">';

        html += '<div class="xs2player-play-mute">';
        html += '<button class="xs2player-play"><span class="icon-play"></span></button> <br>';

        if (template == 'wavesurfer') {
            html += '<button class="xs2player-mute"><span class="icon-volume-high"></span></button>';
        }
        html += '</div>';

        if (template == 'wavesurfer') {

            html += '<div class="xs2player-rewind-forward">';
            html += '<button class="xs2player-rewind"><span class="icon-rewind">15</span></button>';
            html += '<button class="xs2player-forward"><span class="icon-forward">15</span></button>';
            html += '</div>';

            html += '<div class="xs2player-visual">';
            html += '<div class="xs2player-waveform"></div>';
            html += '<div class="xs2player-currenttime">0:00</div>';
            html += '<div class="xs2player-totaltime">' + (player.dataset.totalTime || '') + '</div>';
            html += '</div>';
        }

        if (postImage) {
            html += '<div class="xs2player-image">';
            html += '<img src="' + postImage + '" alt="">';
            html += '</div>';
        }

        html += '</div>';

        if (template == 'block') {
            html += '<div class="xs2player-timeline"></div>';
        }

        html += '</div>';

        player.insertAdjacentHTML('afterend', html);
        var playerHTML = player.nextSibling;

        if (template == 'block') {
            playerHTML.getElementsByClassName('xs2player-play')[0].addEventListener("click", function(){
                if (player.paused) {
                    player.play();
                } else  {
                   player.pause();
                }
            });

            player.addEventListener("play", function() {
                playerHTML.getElementsByClassName('xs2player-play')[0].innerHTML = '<span class="icon-pause"></span>';
            });
            player.addEventListener("pause", function() {
                playerHTML.getElementsByClassName('xs2player-play')[0].innerHTML = '<span class="icon-play"></span>';
            });

            var playhead =  playerHTML.getElementsByClassName('xs2player-timeline')[0];
            player.addEventListener("timeupdate", function() {
                var duration = this.duration;
                var currentTime = this.currentTime;
                var percentage = (currentTime / duration) * 100;

                playhead.style.background = 'linear-gradient(90deg,' + progressColor + ' ' + percentage + '%, #FFFFFF 0%)';
            });
        }
        else if (template == 'wavesurfer') {
            var autoPlay = false;
            var wavesurfer = WaveSurfer.create({
                container: playerHTML.getElementsByClassName('xs2player-waveform')[0],
                backend: 'MediaElement',
                barWidth: parseInt(player.dataset.barWidth || xs2content.barWidth || 2),
                barHeight: parseInt(player.dataset.barHeight || xs2content.barHeight || 1),
                barGap: parseInt(player.dataset.barGap || xs2content.barGap || 2),
                cursorWidth: parseInt(player.dataset.cursorWidth || xs2content.cursorWidth || 0),
                height: parseInt(player.dataset.WaveSurferHeight || xs2content.height || 90),
                responsive: true,
                skipLength: parseInt(player.dataset.skipLength || xs2content.skipLength || 15),

                progressColor: progressColor,
                waveColor: waveColor,
            });

            wavesurfer.on('error', function(e) {
                if (typeof e === 'object' && e.message.includes("HTTP error status: 403") ) {
                    playerHTML.style.display = "none";
                }
                else {
                    playerHTML.getElementsByClassName('xs2player-waveform')[0].innerHTML = '<div class="xs2player-error">Not loaded</div>';
                }
            });

            wavesurfer.on('play', function() {
                xs2player_save_stat('started', postId, postTitle, type);
                playerHTML.getElementsByClassName('xs2player-play')[0].innerHTML = '<span class="icon-pause"></span>';
            });

            wavesurfer.on('finish', function() {
                xs2player_save_stat('finished', postId, postTitle, type);
            });

            wavesurfer.on('ready', function() {
                if (autoPlay) {
                    wavesurfer.play();
                    autoPlay = false;
                }
            });

            wavesurfer.on('pause', function() {
                playerHTML.getElementsByClassName('xs2player-play')[0].innerHTML = '<span class="icon-play"></span>';
            });

            wavesurfer.on('mute', function(isMuted) {
                if (isMuted) {
                    playerHTML.getElementsByClassName('xs2player-mute')[0].innerHTML = '<span class="icon-volume-mute"></span>';
                }
                else {
                    playerHTML.getElementsByClassName('xs2player-mute')[0].innerHTML = '<span class="icon-volume-high"></span>';
                }
            });

            wavesurfer.on('audioprocess', function() {
                if(wavesurfer.isPlaying()) {
                    playerHTML.getElementsByClassName('xs2player-currenttime')[0].innerHTML = xs2player_time_format(wavesurfer.getCurrentTime());
                }
            });
            
            let trackHalfway = function(current) {
                if (current > (wavesurfer.getDuration() / 2)) {
                    xs2player_save_stat('halfway', postId, postTitle, type);
                    wavesurfer.un('audioprocess', trackHalfway);
                }
            }
            wavesurfer.on('audioprocess', trackHalfway);

            wavesurfer.on('ready', function() {
                playerHTML.getElementsByClassName('xs2player-totaltime')[0].innerHTML = xs2player_time_format(wavesurfer.getDuration());
            });

            // Load audio from URL
            wavesurfer.load(
                player.src,
                xs2player_get_peaks(player.src),
                'none'
            );

            // Button
            const play = playerHTML.querySelector('.xs2player-play');
            play.addEventListener('click', wavesurfer.playPause.bind(wavesurfer));

            const mute = playerHTML.querySelector('.xs2player-mute');
            mute.addEventListener('click', wavesurfer.toggleMute.bind(wavesurfer));

            const rewind = playerHTML.querySelector('.xs2player-rewind');
            rewind.addEventListener('click', function() { wavesurfer.skipBackward(); });

            const forward = playerHTML.querySelector('.xs2player-forward');
            forward.addEventListener('click', function() { wavesurfer.skipForward(); });
        }
    }

    if (player.parentNode.classList.contains('xs2player-playlist')) {
        let links = player.parentNode.querySelectorAll('li');
        let currentTrack = 0;

        // Load a track by index and highlight the corresponding link
        let setCurrentSong = function(index) {
            links[currentTrack].classList.remove('active');
            currentTrack = index;
            links[currentTrack].classList.add('active');

            postTitle = links[currentTrack].innerHTML;
            postId = links[currentTrack].dataset.postId;

            if (playerHTML && playerHTML.querySelector('h3')) {
                playerHTML.querySelector('h3').innerHTML = links[currentTrack].innerHTML;
            }

            if (playerHTML && playerHTML.querySelector('img')) {
                playerHTML.querySelector('img').src = links[currentTrack].dataset.image;

                if (links[currentTrack].dataset.image) {
                    playerHTML.querySelector('.xs2player-columns').style.gridTemplateColumns = "64px 20px auto 90px";
                    playerHTML.querySelector('.xs2player-image').style.display = "block";
                }
                else {
                    playerHTML.querySelector('.xs2player-columns').style.gridTemplateColumns = "64px 20px auto";
                    playerHTML.querySelector('.xs2player-image').style.display = "none";
                }
            }

            if (template == 'wavesurfer') {
                autoPlay = true;
                wavesurfer.load(links[currentTrack].dataset.url);
            }
            else {
                player.src = links[currentTrack].dataset.url;
                player.play();
            }
        };

        // Load the track on click
        Array.prototype.forEach.call(links, function(link, index) {
            link.addEventListener('click', function(e) {
                e.preventDefault();
                setCurrentSong(index);
            });
        });
    }
}


function xs2player_save_stat(type, postId, postTitle, playerType)
{
    if (xs2content.analyticsEnabled !== 'on' || xs2content.restUrl === "") {
        return;
    }

    if (xs2playerStatsRequests.includes(postId + ':' + type)) {
        return
    }
    xs2playerStatsRequests.push(postId + ':' + type);

    fetch( xs2content.restUrl + '/stats', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
            'X-WP-Nonce': xs2content.restNonce,
        },
        body: JSON.stringify({
            'postId': postId,
            'type': type
        })
    })
    .catch(function(err) {
        console.log('Error: ', err);
    });

    if (typeof dataLayer === 'object' && typeof dataLayer.push === 'function') {
        var gAction = 'audio_unknown';
        switch (type) {
            case 'started':
                gAction = "audio_start";
                break;
            case 'halfway':
                gAction = "audio_progress_50";
                break;
            case 'finished':
                gAction = "audio_complete";
                break;
        }

        dataLayer.push({
            'event': gAction,
            'event_category': 'xs2radio_' + playerType + '_play',
            'event_label': postTitle
        });
    }
}

function xs2player_time_format(duration)
{   
    // Hours, minutes and seconds
    var hrs = ~~(duration / 3600);
    var mins = ~~((duration % 3600) / 60);
    var secs = ~~duration % 60;

    // Output like "1:01" or "4:03:59" or "123:03:59"
    var ret = "";

    if (hrs > 0) {
        ret += "" + hrs + ":" + (mins < 10 ? "0" : "");
    }

    ret += "" + mins + ":" + (secs < 10 ? "0" : "");
    ret += "" + secs;
    return ret;
}

function xs2player_get_peaks(url)
{
    return [-0.24,0.25,-0.21,0.21,-0.16,0.21,-0.09,0.12,-0.03,0.04,-0.01,0.01,-0.1,0.08,-0.06,0.05,-0.05,0.05,-0.08,0.14,-0.07,0.11,-0.06,0.07,-0.26,0.24,-0.24,0.23,-0.21,0.22,-0.12,0.21,-0.05,0.04,-0.01,0.02,-0.27,0.22,-0.27,0.16,-0.12,0.11,-0.21,0.21,-0.22,0.15,-0.14,0.13,-0.1,0.12,-0.08,0.07,-0.03,0.04,-0.08,0.1,-0.07,0.1,-0.04,0.04,-0.14,0.14,-0.44,0.39,-0.46,0.45,-0.11,0.1,-0.32,0.36,-0.38,0.37,-0.49,0.36,-0.25,0.37,-0.25,0.35,-0.28,0.33,-0.51,0.45,-0.51,0.42,-0.51,0.38,-0.26,0.38,-0.15,0.14,-0.29,0.4,-0.45,0.42,-0.47,0.38,-0.22,0.32,-0.18,0.31,-0.33,0.36,-0.44,0.4,-0.43,0.38,-0.34,0.42,-0.24,0.41,-0.14,0.14,-0.27,0.25,-0.3,0.36,-0.16,0.13,-0.17,0.21,-0.25,0.45,-0.29,0.46,-0.08,0.08,-0.18,0.2,-0.26,0.41,-0.27,0.4,-0.1,0.1,-0.32,0.39,-0.29,0.36,-0.31,0.38,-0.3,0.38,-0.14,0.12,-0.49,0.39,-0.51,0.35,-0.36,0.25,-0.13,0.14,-0.28,0.32,-0.32,0.34,-0.32,0.38,-0.34,0.34,-0.27,0.22,-0.33,0.25,-0.24,0.34,-0.2,0.25,-0.49,0.45,-0.52,0.37,-0.4,0.35,-0.07,0.07,-0.18,0.2,-0.26,0.29,-0.18,0.2,-0.27,0.31,-0.23,0.27,-0.11,0.12,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.04,0.04,-0.02,0.03,-0.02,0.02,-0.04,0.05,-0.03,0.03,-0.03,0.03,-0.03,0.05,-0.02,0.03,-0.02,0.02,-0.04,0.04,-0.02,0.03,-0.02,0.02,-0.03,0.06,-0.03,0.03,-0.02,0.03,-0.03,0.05,-0.03,0.04,-0.02,0.03,-0.03,0.06,-0.03,0.04,-0.02,0.03,-0.01,0.02,-0.03,0.01,-0.03,0.01,-0.03,0.03,-0.02,0.04,-0.02,0.04,-0.02,0.01,-0.02,0.01,-0.01,0.01,-0.05,0.07,-0.42,0.27,-0.36,0.36,-0.09,0.11,-0.18,0.16,-0.09,0.11,-0.16,0.3,-0.23,0.3,-0.25,0.38,-0.22,0.38,-0.3,0.29,-0.25,0.32,-0.23,0.36,-0.09,0.12,-0.14,0.1,-0.28,0.32,-0.29,0.32,-0.15,0.23,-0.08,0.09,-0.21,0.28,-0.16,0.23,-0.23,0.27,-0.22,0.27,-0.22,0.19,-0.22,0.23,-0.21,0.27,-0.22,0.3,-0.18,0.3,-0.15,0.2,-0.11,0.11,-0.17,0.22,-0.18,0.21,-0.23,0.25,-0.25,0.27,-0.15,0.29,-0.18,0.14,-0.08,0.1,-0.29,0.27,-0.33,0.35,-0.25,0.29,-0.17,0.23,-0.28,0.25,-0.31,0.17,-0.14,0.16,-0.32,0.32,-0.33,0.34,-0.31,0.29,-0.15,0.1,-0.18,0.21,-0.08,0.08,-0.06,0.13,-0.12,0.12,-0.25,0.23,-0.18,0.23,-0.15,0.18,-0.1,0.11,-0.06,0.06,-0.18,0.23,-0.34,0.27,-0.32,0.21,-0.2,0.24,-0.09,0.06,-0.13,0.14,-0.2,0.24,-0.18,0.23,-0.2,0.2,-0.21,0.22,-0.08,0.13,-0.14,0.22,-0.17,0.22,-0.16,0.16,-0.15,0.14,-0.18,0.25,-0.13,0.16,-0.27,0.23,-0.25,0.23,-0.03,0.03,-0.17,0.16,-0.26,0.26,-0.27,0.27,-0.23,0.27,-0.17,0.23,-0.16,0.26,-0.17,0.28,-0.19,0.28,-0.15,0.17,-0.21,0.26,-0.21,0.27,-0.17,0.24,-0.16,0.17,-0.18,0.18,-0.27,0.27,-0.29,0.29,-0.2,0.28,-0.2,0.27,-0.18,0.29,-0.23,0.26,-0.32,0.28,-0.22,0.22,-0.12,0.17,-0.16,0.26,-0.23,0.23,-0.26,0.25,-0.11,0.08,-0.16,0.16,-0.21,0.3,-0.12,0.23,-0.04,0.06,-0.14,0.28,-0.16,0.25,-0.08,0.08,-0.21,0.27,-0.18,0.27,-0.2,0.21,-0.19,0.22,-0.15,0.1,-0.29,0.25,-0.29,0.19,-0.08,0.07,-0.2,0.21,-0.12,0.18,-0.16,0.22,-0.18,0.24,-0.14,0.16,-0.12,0.14,-0.11,0.14,-0.07,0.1,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.17,0.22,-0.23,0.29,-0.2,0.22,-0.24,0.34,-0.16,0.27,-0.1,0.12,-0.32,0.32,-0.34,0.33,-0.17,0.2,-0.29,0.3,-0.21,0.24,-0.1,0.18,-0.17,0.22,-0.25,0.22,-0.14,0.16,-0.21,0.29,-0.23,0.29,-0.21,0.27,-0.29,0.27,-0.1,0.16,-0.13,0.12,-0.23,0.29,-0.18,0.25,-0.11,0.12,-0.19,0.13,-0.18,0.14,-0.18,0.25,-0.32,0.26,-0.27,0.29,-0.17,0.27,-0.13,0.14,-0.08,0.07,-0.15,0.27,-0.14,0.27,-0.05,0.07,-0.17,0.26,-0.15,0.24,-0.23,0.18,-0.18,0.23,-0.16,0.2,-0.13,0.12,-0.42,0.31,-0.41,0.36,-0.35,0.37,-0.16,0.24,-0.18,0.29,-0.21,0.22,-0.21,0.28,-0.22,0.31,-0.16,0.21,-0.16,0.18,-0.16,0.27,-0.13,0.16,-0.07,0.1,-0.2,0.2,-0.19,0.23,-0.11,0.04,-0.23,0.14,-0.16,0.22,-0.27,0.27,-0.28,0.25,-0.32,0.25,-0.39,0.34,-0.4,0.32,-0.18,0.1,-0.15,0.11,-0.22,0.21,-0.27,0.23,-0.27,0.31,-0.4,0.3,-0.36,0.3,-0.21,0.21,-0.13,0.17,-0.38,0.3,-0.38,0.23,-0.25,0.29,-0.18,0.29,-0.18,0.2,-0.27,0.27,-0.34,0.29,-0.25,0.25,-0.16,0.27,-0.18,0.27,-0.22,0.21,-0.15,0.18,-0.07,0.0,-0.21,0.22,-0.23,0.17,-0.11,0.1,-0.1,0.11,-0.08,0.12,-0.13,0.14,-0.17,0.14,-0.17,0.14,-0.12,0.1,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.05,0.07,-0.32,0.32,-0.29,0.32,-0.1,0.16,-0.18,0.27,-0.34,0.26,-0.21,0.31,-0.22,0.32,-0.26,0.29,-0.27,0.31,-0.31,0.29,-0.27,0.34,-0.17,0.23,-0.22,0.13,-0.18,0.19,-0.32,0.21,-0.26,0.24,-0.19,0.27,-0.03,0.01,-0.26,0.27,-0.28,0.28,-0.25,0.29,-0.24,0.3,-0.25,0.23,-0.22,0.29,-0.22,0.31,-0.17,0.24,-0.05,0.1,0.0,0.01,-0.14,0.14,-0.27,0.26,-0.24,0.27,-0.23,0.25,-0.23,0.26,-0.25,0.31,-0.12,0.2,-0.15,0.01,-0.27,0.32,-0.27,0.29,-0.27,0.27,-0.32,0.27,-0.26,0.32,-0.28,0.25,-0.26,0.3,-0.12,0.1,-0.24,0.31,-0.08,0.14,-0.08,0.08,-0.42,0.34,-0.42,0.25,-0.3,0.27,-0.18,0.22,-0.17,0.25,-0.12,0.1,-0.24,0.21,-0.12,0.12,-0.11,0.17,-0.1,0.14,-0.06,0.05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.07,0.06,-0.03,0.03,-0.04,0.04,-0.07,0.08,-0.05,0.05,-0.02,0.02,-0.06,0.08,-0.04,0.04,-0.04,0.04,-0.07,0.08,-0.03,0.05,-0.04,0.05,-0.06,0.1,-0.05,0.05,-0.02,0.03,-0.06,0.1,-0.04,0.07,-0.05,0.04,-0.06,0.1,-0.05,0.03,-0.03,0.05,-0.01,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.04,-0.02,0.01,-0.01,0.01,-0.01,0.01,-0.12,0.15,-0.33,0.29,-0.25,0.38,-0.25,0.35,-0.42,0.42,-0.37,0.4,-0.19,0.25,-0.27,0.33,-0.34,0.38,-0.34,0.35,-0.39,0.35,-0.32,0.28,-0.16,0.21,-0.18,0.26,-0.19,0.25,-0.18,0.14,-0.14,0.13,-0.09,0.09,-0.19,0.22,-0.26,0.31,-0.39,0.29,-0.34,0.23,-0.16,0.25,-0.08,0.08,-0.21,0.26,-0.21,0.26,-0.21,0.26,-0.18,0.26,-0.09,0.1,-0.08,0.18,-0.27,0.3,-0.28,0.34,-0.2,0.32,-0.21,0.31,-0.18,0.23,-0.1,0.14,-0.18,0.25,-0.22,0.29,-0.27,0.29,-0.37,0.42,-0.37,0.38,-0.3,0.31,-0.17,0.25,-0.2,0.25,-0.34,0.34,-0.34,0.33,-0.16,0.23,-0.15,0.25,-0.18,0.27,-0.25,0.18,-0.21,0.22,-0.06,0.07,-0.17,0.27,-0.18,0.26,-0.14,0.21,-0.38,0.26,-0.41,0.38,-0.36,0.36,-0.05,0.05,-0.13,0.19,-0.23,0.29,-0.21,0.14,-0.08,0.11,-0.17,0.23,-0.21,0.35,-0.21,0.3,-0.02,0.01,-0.19,0.32,-0.17,0.34,-0.18,0.21,-0.23,0.29,-0.21,0.31,-0.21,0.24,-0.16,0.13,-0.19,0.31,-0.17,0.27,-0.12,0.18,-0.14,0.21,-0.25,0.3,-0.28,0.28,-0.29,0.31,-0.05,0.08,-0.1,0.12,-0.22,0.25,-0.26,0.32,-0.18,0.32,-0.29,0.19,-0.18,0.17,-0.19,0.29,-0.4,0.28,-0.4,0.29,-0.21,0.31,-0.28,0.32,-0.2,0.28,-0.21,0.28,-0.2,0.29,-0.21,0.23,-0.08,0.13,-0.19,0.23,-0.1,0.05,-0.21,0.26,-0.26,0.21,-0.32,0.3,-0.38,0.41,-0.16,0.13,-0.16,0.11,-0.32,0.34,-0.36,0.42,-0.21,0.27,-0.15,0.11,-0.09,0.1,-0.08,0.08,-0.21,0.23,-0.23,0.32,-0.36,0.33,-0.25,0.35,-0.13,0.05,-0.08,0.08,-0.17,0.2,-0.29,0.33,-0.24,0.29,-0.25,0.32,-0.23,0.16,-0.23,0.14,-0.14,0.25,-0.08,0.09,-0.12,0.12,-0.39,0.41,-0.4,0.4,-0.39,0.34,-0.33,0.31,-0.18,0.32,-0.22,0.34,-0.12,0.19,-0.08,0.1,-0.18,0.22,-0.23,0.27,-0.25,0.32,-0.12,0.15,-0.27,0.31,-0.1,0.18,-0.19,0.16,-0.27,0.3,-0.16,0.26,-0.13,0.24,-0.27,0.3,-0.37,0.37,-0.38,0.44,-0.3,0.35,-0.13,0.19,-0.14,0.16,-0.18,0.2,-0.25,0.2,-0.3,0.38,-0.29,0.25,-0.16,0.25,-0.18,0.23,-0.18,0.29,-0.24,0.31,-0.37,0.34,-0.21,0.21,-0.14,0.11,-0.14,0.1,-0.12,0.17,-0.16,0.16,-0.2,0.18,-0.14,0.19,-0.12,0.16,-0.05,0.05,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,-0.26,0.33,-0.31,0.35,-0.09,0.12,-0.22,0.33,-0.33,0.29,-0.26,0.24,-0.27,0.36,-0.27,0.32,-0.25,0.25,-0.3,0.21,-0.18,0.25,-0.22,0.27,-0.25,0.28,-0.3,0.34,-0.27,0.33,-0.22,0.35,-0.2,0.2,-0.16,0.28,-0.16,0.3,-0.15,0.26,-0.19,0.32,-0.22,0.32,-0.26,0.32,-0.27,0.32,-0.28,0.33,-0.23,0.3,-0.23,0.25,-0.18,0.25,-0.21,0.32,-0.22,0.34,-0.29,0.27,-0.33,0.25,-0.21,0.28,-0.13,0.13,-0.23,0.32,-0.34,0.31,-0.27,0.25,-0.15,0.18,-0.09,0.11,-0.18,0.23,-0.18,0.24,-0.29,0.32,-0.19,0.31,-0.12,0.16,-0.12,0.08,-0.18,0.28,-0.25,0.37,-0.06,0.08,-0.14,0.08,-0.2,0.36,-0.23,0.34,-0.1,0.11,-0.23,0.3,-0.29,0.3,-0.32,0.31,-0.25,0.27,-0.3,0.27,-0.21,0.28,-0.27,0.28,-0.32,0.3,-0.18,0.29,-0.31,0.36,-0.29,0.34,-0.16,0.21,-0.27,0.28,-0.14,0.13,-0.38,0.39,-0.42,0.43,-0.43,0.32,-0.3,0.25,-0.08,0.14,-0.12,0.2,-0.19,0.33,-0.17,0.31,-0.1,0.06,-0.26,0.3,-0.28,0.27,-0.18,0.18,-0.16,0.16,-0.28,0.36,-0.24,0.36,-0.17,0.18,-0.32,0.3,-0.36,0.36,-0.43,0.32,-0.34,0.32,-0.18,0.21,-0.08,0.06,-0.22,0.29,-0.2,0.27,-0.18,0.23,-0.36,0.32,-0.35,0.34,-0.11,0.11,-0.36,0.34,-0.16,0.14,-0.29,0.29,-0.3,0.29,-0.32,0.32,-0.39,0.29,-0.36,0.29,-0.23,0.27,-0.23,0.26,-0.21,0.31,-0.28,0.32,-0.27,0.29,-0.23,0.26,-0.24,0.28,-0.21,0.27,-0.19,0.34,-0.13,0.26,-0.08,0.12,-0.14,0.24,-0.16,0.32,-0.14,0.26,-0.31,0.29,-0.29,0.32,-0.2,0.27,-0.28,0.25,-0.19,0.16,-0.14,0.24,-0.27,0.26,-0.12,0.14,-0.23,0.34,-0.3,0.29,-0.26,0.32,-0.23,0.25,-0.21,0.29,-0.13,0.17,-0.16,0.16,-0.2,0.19,-0.18,0.18,-0.15,0.17,-0.12,0.16,-0.06,0.03,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.03,0.06,-0.03,0.02,-0.08,0.05,-0.06,0.08,-0.06,0.05,-0.04,0.02,-0.06,0.09,-0.04,0.05,-0.05,0.05,-0.08,0.08,-0.03,0.04,-0.05,0.05,-0.07,0.11,-0.05,0.05,-0.02,0.03,-0.06,0.1,-0.05,0.07,-0.05,0.05,-0.06,0.1,-0.05,0.05,0.0,0.03,-0.04,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.04,-0.03,0.05,0.0,0.01,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.11,0.08,-0.33,0.46,-0.47,0.43,-0.48,0.43,-0.25,0.37,-0.32,0.45,-0.42,0.39,-0.14,0.18,-0.47,0.37,-0.45,0.31,-0.27,0.27,-0.07,0.05,-0.3,0.29,-0.25,0.29,-0.03,0.02,-0.16,0.26,-0.24,0.34,-0.12,0.22,-0.17,0.23,-0.22,0.27,-0.27,0.3,-0.27,0.25,-0.23,0.25,-0.03,0.02,-0.39,0.36,-0.47,0.36,-0.42,0.41,-0.32,0.4,-0.25,0.36,-0.14,0.3,-0.1,0.09,-0.27,0.33,-0.25,0.31,-0.27,0.29,-0.26,0.3,-0.09,0.1,-0.23,0.34,-0.42,0.4,-0.28,0.4,-0.14,0.14,-0.16,0.2,-0.05,0.05,-0.08,0.08,-0.23,0.3,-0.29,0.32,-0.26,0.35,-0.22,0.34,-0.23,0.27,-0.38,0.34,-0.25,0.27,-0.17,0.28,-0.19,0.3,-0.17,0.24,-0.16,0.14,-0.08,0.05,-0.32,0.3,-0.34,0.3,-0.16,0.16,-0.08,0.07,-0.19,0.24,-0.22,0.29,-0.28,0.27,-0.23,0.25,-0.26,0.28,-0.21,0.26,-0.21,0.22,-0.21,0.23,-0.27,0.33,-0.25,0.3,-0.12,0.12,-0.08,0.08,-0.43,0.38,-0.34,0.31,-0.31,0.32,-0.2,0.16,-0.12,0.25,-0.22,0.31,-0.24,0.3,-0.26,0.33,-0.45,0.32,-0.42,0.4,-0.34,0.27,-0.21,0.29,-0.28,0.21,-0.3,0.26,-0.39,0.35,-0.43,0.27,-0.36,0.29,-0.2,0.29,-0.09,0.13,-0.03,0.02,-0.02,0.03,-0.2,0.25,-0.32,0.25,-0.25,0.19,-0.17,0.24,-0.08,0.06,-0.23,0.24,-0.26,0.29,-0.46,0.42,-0.45,0.38,-0.36,0.37,-0.15,0.18,-0.27,0.29,-0.25,0.26,-0.16,0.32,-0.4,0.4,-0.38,0.33,-0.18,0.25,-0.08,0.06,-0.21,0.29,-0.17,0.26,-0.32,0.32,-0.3,0.32,-0.35,0.34,-0.36,0.35,-0.25,0.32,-0.16,0.23,-0.26,0.36,-0.21,0.25,-0.45,0.34,-0.45,0.36,-0.39,0.33,-0.24,0.26,-0.08,0.13,-0.19,0.25,-0.29,0.23,-0.31,0.3,-0.15,0.22,-0.1,0.08,-0.21,0.29,-0.24,0.32,-0.29,0.32,-0.29,0.32,-0.18,0.25,-0.21,0.33,-0.22,0.28,-0.25,0.27,-0.29,0.29,-0.29,0.29,-0.27,0.3,-0.05,0.07,-0.1,0.11,0.0,0.0,-0.1,0.14,-0.22,0.31,-0.25,0.29,-0.27,0.33,-0.24,0.36,-0.36,0.34,-0.29,0.32,-0.05,0.03,-0.16,0.29,-0.16,0.31,-0.14,0.19,-0.09,0.1,-0.16,0.29,-0.48,0.32,-0.47,0.29,-0.3,0.34,-0.14,0.3,-0.18,0.27,-0.21,0.32,-0.3,0.38,-0.27,0.26,-0.18,0.24,-0.11,0.11,-0.27,0.31,-0.27,0.31,-0.08,0.11,-0.18,0.25,-0.18,0.27,-0.21,0.32,-0.15,0.32,-0.1,0.1,-0.17,0.26,-0.16,0.25,-0.23,0.28,-0.23,0.28,-0.17,0.2,-0.47,0.31,-0.46,0.36,-0.37,0.33,-0.18,0.18,-0.19,0.21,-0.18,0.14,-0.12,0.14,-0.11,0.1,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.06,-0.03,0.03,-0.08,0.08,-0.05,0.08,-0.06,0.05,-0.07,0.09,-0.05,0.07,-0.03,0.04,-0.08,0.08,-0.04,0.05,-0.03,0.03,-0.05,0.11,-0.07,0.05,-0.05,0.05,-0.06,0.1,-0.06,0.08,-0.05,0.05,-0.05,0.05,-0.06,0.1,-0.05,0.05,0.0,0.03,-0.04,0.02,-0.04,0.01,-0.04,0.01,-0.03,0.04,-0.03,0.05,-0.01,0.0,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.08,0.05,-0.53,0.42,-0.53,0.43,-0.49,0.37,-0.01,0.03,-0.21,0.32,-0.22,0.32,-0.18,0.25,-0.18,0.21,-0.24,0.34,-0.23,0.32,-0.1,0.1,-0.16,0.29,-0.48,0.34,-0.45,0.27,-0.3,0.3,-0.21,0.33,-0.25,0.34,-0.12,0.14,-0.23,0.32,-0.29,0.27,-0.36,0.36,-0.39,0.38,-0.23,0.31,-0.19,0.23,-0.23,0.33,-0.17,0.25,-0.12,0.2,-0.23,0.28,-0.23,0.25,-0.12,0.12,-0.17,0.21,-0.25,0.38,-0.22,0.33,-0.05,0.03,-0.16,0.33,-0.21,0.32,-0.09,0.1,-0.22,0.32,-0.24,0.31,-0.27,0.27,-0.23,0.29,-0.12,0.14,-0.4,0.34,-0.41,0.3,-0.37,0.26,-0.22,0.23,-0.22,0.23,-0.28,0.31,-0.25,0.29,-0.09,0.09,-0.14,0.15,-0.22,0.33,-0.23,0.34,-0.29,0.31,-0.3,0.25,-0.15,0.17,-0.28,0.27,-0.27,0.35,-0.08,0.09,-0.18,0.29,-0.21,0.3,-0.42,0.34,-0.45,0.28,-0.27,0.3,-0.14,0.16,-0.09,0.14,-0.21,0.32,-0.16,0.26,-0.22,0.19,-0.21,0.25,-0.23,0.27,-0.2,0.29,-0.23,0.33,-0.23,0.33,-0.27,0.19,-0.16,0.22,-0.23,0.26,-0.23,0.3,-0.32,0.35,-0.33,0.36,-0.25,0.33,-0.11,0.1,-0.15,0.24,-0.24,0.26,-0.25,0.26,-0.33,0.33,-0.33,0.36,-0.27,0.34,-0.22,0.29,-0.2,0.33,-0.24,0.28,-0.35,0.32,-0.25,0.24,-0.13,0.16,-0.12,0.14,-0.08,0.08,-0.01,0.01,-0.01,0.01,-0.17,0.29,-0.21,0.35,-0.16,0.14,-0.19,0.31,-0.38,0.44,-0.25,0.29,-0.19,0.22,-0.1,0.12,-0.18,0.33,-0.2,0.27,-0.2,0.25,-0.22,0.34,-0.29,0.38,-0.19,0.23,-0.13,0.12,-0.21,0.23,-0.06,0.07,-0.2,0.33,-0.25,0.31,-0.25,0.28,-0.38,0.36,-0.4,0.32,-0.12,0.16,-0.22,0.1,-0.1,0.18,-0.34,0.32,-0.25,0.3,-0.12,0.11,-0.28,0.34,-0.25,0.32,-0.21,0.19,-0.27,0.3,-0.14,0.13,-0.38,0.38,-0.35,0.31,-0.2,0.18,-0.08,0.09,-0.14,0.18,-0.13,0.18,-0.12,0.24,-0.12,0.27,-0.13,0.1,-0.05,0.05,-0.17,0.27,-0.22,0.27,-0.23,0.25,-0.08,0.07,-0.34,0.35,-0.37,0.36,-0.27,0.25,-0.34,0.36,-0.07,0.1,-0.14,0.23,-0.25,0.29,-0.19,0.31,-0.19,0.32,-0.03,0.03,-0.24,0.22,-0.23,0.34,-0.29,0.34,-0.31,0.34,-0.27,0.34,-0.27,0.34,-0.22,0.25,-0.16,0.14,0.0,0.0,-0.33,0.34,-0.38,0.36,-0.15,0.18,-0.18,0.16,-0.09,0.09,-0.25,0.33,-0.33,0.31,-0.28,0.29,-0.2,0.23,-0.22,0.24,-0.29,0.34,-0.26,0.32,-0.14,0.19,-0.12,0.16,-0.21,0.27,-0.25,0.31,-0.23,0.25,-0.14,0.12,-0.28,0.3,-0.24,0.29,-0.27,0.34,-0.32,0.36,-0.34,0.32,-0.27,0.31,-0.05,0.11,-0.2,0.18,-0.21,0.18,-0.12,0.1,-0.09,0.09,-0.02,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.03,0.05,-0.04,0.04,-0.08,0.08,-0.06,0.07,-0.05,0.03,-0.06,0.08,-0.04,0.04,-0.05,0.04,-0.07,0.08,-0.04,0.05,-0.03,0.05,-0.06,0.11,-0.05,0.05,-0.03,0.03,-0.06,0.1,-0.05,0.07,-0.05,0.04,-0.06,0.1,-0.05,0.06,-0.03,0.05,-0.01,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.02,0.01,-0.02,0.01,-0.01,0.01,0.0,0.01,-0.16,0.25,-0.25,0.32,-0.24,0.31,-0.31,0.36,-0.36,0.38,-0.36,0.41,-0.25,0.33,-0.32,0.34,-0.25,0.37,-0.24,0.33,-0.23,0.31,-0.24,0.36,-0.25,0.27,-0.27,0.35,-0.21,0.28,-0.03,0.01,-0.23,0.35,-0.33,0.32,-0.34,0.32,-0.22,0.29,-0.28,0.27,-0.18,0.22,-0.12,0.22,-0.12,0.15,-0.23,0.29,-0.27,0.29,-0.39,0.28,-0.45,0.32,-0.44,0.27,-0.32,0.35,-0.26,0.38,-0.24,0.37,-0.17,0.32,-0.19,0.18,-0.32,0.35,-0.26,0.33,-0.25,0.32,-0.27,0.34,-0.3,0.31,-0.18,0.17,-0.08,0.09,-0.23,0.3,-0.24,0.32,-0.27,0.3,0.0,0.0,-0.1,0.14,-0.23,0.32,-0.29,0.27,-0.28,0.23,-0.24,0.35,-0.14,0.18,-0.09,0.14,-0.23,0.25,-0.24,0.26,-0.32,0.33,-0.29,0.33,-0.01,0.02,-0.15,0.14,-0.23,0.36,-0.22,0.34,-0.05,0.03,-0.15,0.36,-0.21,0.36,-0.08,0.08,-0.28,0.32,-0.23,0.31,-0.28,0.32,-0.24,0.35,-0.12,0.12,-0.41,0.35,-0.42,0.44,-0.18,0.18,-0.13,0.19,-0.12,0.04,-0.19,0.31,-0.21,0.27,-0.25,0.25,-0.25,0.38,-0.29,0.33,-0.26,0.34,-0.16,0.14,-0.16,0.25,-0.25,0.27,-0.24,0.31,-0.25,0.32,-0.19,0.25,-0.24,0.37,-0.21,0.4,-0.03,0.01,-0.17,0.27,-0.27,0.28,-0.27,0.29,-0.16,0.24,-0.27,0.25,-0.36,0.29,-0.12,0.12,-0.27,0.36,-0.25,0.34,-0.27,0.36,-0.28,0.36,-0.25,0.37,-0.19,0.14,-0.22,0.23,-0.1,0.15,-0.25,0.27,-0.34,0.29,-0.34,0.28,-0.23,0.23,-0.22,0.29,-0.16,0.29,-0.14,0.12,0.0,0.01,-0.12,0.16,-0.16,0.23,-0.11,0.1,-0.11,0.23,-0.36,0.34,-0.38,0.29,-0.25,0.25,-0.18,0.24,-0.21,0.24,-0.16,0.16,-0.36,0.38,-0.42,0.4,-0.44,0.35,-0.36,0.3,-0.1,0.08,-0.18,0.27,-0.3,0.34,-0.38,0.32,-0.4,0.29,-0.16,0.25,-0.12,0.22,-0.29,0.3,-0.31,0.3,-0.29,0.3,-0.28,0.33,-0.27,0.33,-0.12,0.1,-0.08,0.13,-0.17,0.21,-0.05,0.02,-0.12,0.12,-0.13,0.2,-0.35,0.29,-0.25,0.32,-0.27,0.23,-0.33,0.28,-0.28,0.24,-0.15,0.16,-0.11,0.07,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.06,-0.04,0.04,-0.08,0.08,-0.06,0.07,-0.06,0.05,-0.07,0.09,-0.05,0.07,-0.04,0.05,-0.08,0.08,-0.04,0.06,-0.03,0.05,-0.07,0.12,-0.08,0.06,-0.04,0.05,-0.08,0.11,-0.07,0.08,-0.04,0.04,-0.07,0.12,-0.06,0.07,-0.04,0.05,-0.01,0.03,-0.04,0.02,-0.05,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.06,-0.01,0.01,-0.03,0.01,-0.01,0.01,-0.01,0.01,-0.18,0.22,-0.28,0.39,-0.08,0.12,-0.13,0.3,-0.32,0.4,-0.31,0.31,-0.2,0.25,-0.27,0.34,-0.34,0.33,-0.25,0.27,-0.31,0.38,-0.28,0.38,-0.27,0.35,-0.24,0.37,-0.24,0.36,-0.27,0.34,-0.23,0.19,-0.12,0.14,-0.18,0.29,-0.32,0.32,-0.34,0.3,-0.34,0.27,-0.26,0.33,-0.29,0.34,-0.12,0.25,-0.09,0.1,-0.16,0.27,-0.21,0.23,-0.18,0.23,-0.27,0.33,-0.16,0.23,-0.18,0.25,-0.34,0.37,-0.23,0.41,-0.34,0.29,-0.24,0.25,-0.18,0.33,-0.19,0.23,-0.32,0.32,-0.29,0.32,-0.26,0.28,-0.28,0.31,-0.32,0.32,-0.33,0.34,-0.23,0.28,-0.03,0.03,-0.12,0.21,-0.24,0.27,-0.24,0.25,-0.25,0.32,-0.22,0.3,-0.24,0.27,-0.21,0.24,-0.14,0.16,-0.14,0.13,-0.49,0.35,-0.47,0.42,-0.38,0.43,-0.16,0.22,-0.27,0.36,-0.07,0.08,-0.16,0.29,-0.25,0.33,-0.24,0.25,-0.29,0.31,-0.26,0.27,-0.17,0.19,-0.41,0.38,-0.41,0.33,-0.08,0.11,-0.09,0.08,-0.45,0.35,-0.47,0.27,-0.36,0.34,-0.21,0.36,-0.21,0.36,-0.24,0.16,-0.16,0.18,-0.27,0.35,-0.23,0.32,-0.39,0.42,-0.32,0.43,-0.28,0.3,-0.23,0.3,-0.16,0.3,-0.18,0.27,-0.05,0.06,-0.01,0.01,-0.16,0.21,-0.2,0.25,-0.36,0.35,-0.36,0.34,-0.13,0.1,-0.21,0.32,-0.16,0.14,-0.1,0.14,-0.2,0.34,-0.25,0.39,-0.05,0.08,-0.12,0.12,-0.18,0.36,-0.2,0.34,-0.09,0.08,-0.31,0.36,-0.29,0.33,-0.24,0.32,-0.25,0.34,-0.12,0.13,-0.38,0.36,-0.46,0.29,-0.34,0.27,-0.2,0.28,-0.23,0.27,-0.27,0.25,-0.27,0.32,-0.26,0.32,-0.14,0.21,-0.2,0.31,-0.11,0.16,-0.17,0.16,-0.27,0.24,-0.2,0.18,-0.47,0.36,-0.47,0.32,-0.38,0.31,-0.18,0.23,-0.2,0.25,-0.29,0.34,-0.21,0.27,-0.18,0.17,-0.07,0.14,-0.24,0.32,-0.3,0.27,-0.36,0.37,-0.14,0.23,-0.15,0.26,-0.18,0.28,-0.15,0.21,-0.06,0.1,-0.23,0.29,-0.24,0.33,-0.23,0.32,-0.2,0.29,-0.14,0.23,-0.25,0.3,-0.3,0.31,-0.19,0.33,-0.2,0.34,-0.17,0.21,-0.08,0.12,-0.17,0.21,-0.21,0.27,-0.2,0.33,-0.09,0.1,-0.19,0.22,-0.29,0.29,-0.01,0.01,-0.28,0.33,-0.25,0.31,-0.42,0.3,-0.49,0.36,-0.45,0.34,-0.36,0.29,-0.22,0.18,-0.33,0.37,-0.29,0.38,-0.38,0.35,-0.37,0.29,-0.1,0.1,-0.14,0.14,-0.31,0.32,-0.29,0.37,-0.27,0.34,-0.22,0.27,-0.22,0.33,-0.24,0.34,-0.18,0.27,-0.37,0.35,-0.39,0.39,-0.03,0.05,-0.13,0.12,-0.19,0.32,-0.01,0.02,-0.19,0.31,-0.23,0.31,-0.24,0.28,-0.37,0.36,-0.34,0.36,-0.21,0.27,-0.3,0.29,-0.19,0.27,-0.19,0.25,-0.19,0.29,-0.22,0.34,-0.14,0.18,-0.2,0.29,-0.05,0.06,-0.12,0.12,-0.23,0.27,-0.22,0.26,-0.18,0.24,-0.18,0.3,-0.23,0.27,-0.26,0.29,-0.21,0.27,-0.1,0.12,-0.15,0.21,-0.18,0.27,-0.18,0.18,-0.07,0.1,-0.12,0.08,-0.06,0.08,-0.04,0.03,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.02,-0.19,0.32,-0.33,0.37,-0.14,0.26,-0.23,0.34,-0.25,0.31,-0.27,0.29,-0.31,0.38,-0.31,0.29,-0.16,0.22,-0.25,0.24,-0.29,0.33,-0.1,0.11,-0.07,0.07,-0.31,0.35,-0.26,0.35,-0.18,0.32,-0.31,0.36,-0.32,0.33,-0.32,0.34,-0.27,0.38,-0.25,0.36,-0.18,0.34,-0.29,0.38,-0.08,0.12,-0.23,0.34,-0.27,0.34,-0.27,0.36,-0.27,0.29,-0.23,0.32,-0.21,0.29,-0.14,0.18,-0.27,0.29,-0.32,0.32,-0.29,0.28,-0.31,0.37,-0.23,0.38,-0.1,0.1,-0.18,0.2,-0.18,0.25,-0.29,0.27,-0.01,0.01,-0.15,0.12,-0.3,0.34,-0.29,0.3,-0.21,0.25,-0.11,0.13,-0.14,0.11,-0.03,0.03,-0.22,0.32,-0.21,0.33,-0.08,0.05,-0.21,0.28,-0.27,0.24,-0.29,0.34,-0.16,0.13,-0.34,0.37,-0.3,0.29,-0.23,0.23,-0.12,0.06,-0.13,0.16,-0.11,0.13,-0.1,0.11,-0.08,0.08,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,-0.3,0.33,-0.29,0.37,-0.13,0.17,-0.26,0.36,-0.24,0.36,-0.28,0.29,-0.22,0.3,-0.21,0.21,-0.15,0.15,-0.5,0.41,-0.49,0.43,-0.42,0.45,-0.27,0.26,-0.27,0.38,-0.06,0.06,-0.1,0.13,-0.28,0.34,-0.19,0.32,-0.17,0.28,-0.19,0.27,-0.21,0.3,-0.21,0.32,-0.25,0.29,-0.26,0.33,-0.34,0.35,-0.32,0.35,-0.25,0.35,-0.04,0.08,-0.37,0.34,-0.34,0.35,-0.29,0.36,-0.25,0.32,-0.23,0.32,-0.28,0.33,-0.26,0.32,-0.12,0.16,-0.11,0.2,-0.23,0.3,-0.29,0.33,-0.4,0.34,-0.43,0.45,-0.42,0.41,-0.28,0.36,-0.25,0.31,-0.22,0.29,-0.38,0.37,-0.36,0.34,-0.16,0.26,-0.16,0.27,-0.19,0.32,-0.16,0.27,-0.04,0.03,-0.11,0.1,-0.17,0.25,-0.21,0.23,-0.27,0.26,-0.23,0.32,-0.23,0.27,-0.29,0.24,-0.32,0.38,-0.29,0.34,-0.19,0.25,-0.18,0.14,-0.24,0.27,-0.25,0.26,-0.25,0.33,-0.23,0.29,-0.2,0.26,-0.25,0.38,-0.23,0.34,-0.14,0.17,-0.04,0.06,-0.2,0.28,-0.31,0.36,-0.3,0.36,-0.13,0.18,-0.09,0.08,-0.18,0.25,-0.34,0.32,-0.34,0.28,-0.22,0.27,-0.21,0.21,-0.14,0.18,-0.08,0.08,-0.08,0.08,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.03,0.06,-0.03,0.03,-0.08,0.04,-0.06,0.08,-0.06,0.05,-0.02,0.02,-0.06,0.09,-0.04,0.05,-0.05,0.05,-0.08,0.08,-0.03,0.05,-0.05,0.05,-0.07,0.11,-0.05,0.06,-0.02,0.03,-0.07,0.1,-0.05,0.08,-0.05,0.05,-0.06,0.11,-0.05,0.05,-0.01,0.03,-0.04,0.03,-0.04,0.01,-0.05,0.01,-0.03,0.04,-0.03,0.05,0.0,0.01,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.09,0.06,-0.16,0.26,-0.35,0.4,-0.35,0.43,-0.32,0.41,-0.33,0.42,-0.27,0.39,-0.12,0.15,-0.23,0.32,-0.31,0.29,-0.32,0.22,-0.22,0.34,-0.27,0.32,-0.47,0.29,-0.49,0.32,-0.33,0.34,-0.05,0.07,-0.17,0.3,-0.2,0.23,-0.17,0.19,-0.39,0.42,-0.43,0.4,-0.44,0.34,-0.36,0.29,-0.07,0.1,-0.16,0.28,-0.32,0.37,-0.4,0.34,-0.4,0.28,-0.16,0.24,-0.18,0.25,-0.34,0.34,-0.38,0.37,-0.22,0.29,-0.23,0.34,-0.12,0.13,-0.1,0.1,-0.27,0.29,-0.32,0.3,-0.28,0.32,-0.12,0.18,-0.05,0.05,-0.12,0.11,0.0,0.0,-0.18,0.26,-0.21,0.29,-0.32,0.27,-0.22,0.35,-0.22,0.32,-0.12,0.22,-0.17,0.25,-0.25,0.28,-0.39,0.25,-0.27,0.14,-0.17,0.13,-0.22,0.24,-0.23,0.23,-0.17,0.17,-0.1,0.14,-0.16,0.22,-0.16,0.21,-0.21,0.27,-0.19,0.3,-0.27,0.34,-0.31,0.32,-0.32,0.33,-0.25,0.31,-0.13,0.15,-0.21,0.28,-0.15,0.25,-0.21,0.32,-0.19,0.31,-0.18,0.17,-0.08,0.1,-0.29,0.35,-0.25,0.34,-0.25,0.36,-0.23,0.25,-0.39,0.35,-0.41,0.38,-0.23,0.27,-0.18,0.32,-0.21,0.32,-0.21,0.29,-0.1,0.08,-0.14,0.0,-0.34,0.33,-0.34,0.3,-0.13,0.18,-0.1,0.09,-0.16,0.23,-0.21,0.28,-0.26,0.29,-0.23,0.27,-0.21,0.29,-0.23,0.29,-0.1,0.13,-0.08,0.07,-0.28,0.26,-0.29,0.36,-0.18,0.15,-0.18,0.18,-0.32,0.27,-0.32,0.27,-0.16,0.22,-0.1,0.08,-0.22,0.32,-0.23,0.28,-0.17,0.22,-0.28,0.26,-0.35,0.27,-0.11,0.1,-0.27,0.36,-0.22,0.34,-0.23,0.32,-0.24,0.32,-0.24,0.3,-0.14,0.11,-0.14,0.18,-0.1,0.14,-0.21,0.23,-0.21,0.21,-0.16,0.16,-0.12,0.1,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.21,0.21,-0.29,0.35,-0.33,0.36,-0.29,0.37,-0.21,0.25,-0.25,0.37,-0.18,0.35,-0.1,0.08,-0.27,0.33,-0.27,0.32,-0.25,0.3,-0.22,0.29,-0.24,0.33,-0.2,0.31,-0.1,0.11,-0.08,0.06,-0.23,0.34,-0.29,0.38,-0.23,0.25,-0.21,0.21,-0.1,0.18,-0.42,0.42,-0.37,0.42,-0.14,0.19,-0.16,0.21,-0.29,0.29,-0.3,0.26,-0.24,0.28,-0.12,0.17,-0.01,0.01,-0.01,0.01,-0.14,0.16,-0.42,0.38,-0.45,0.36,-0.33,0.25,-0.22,0.32,-0.25,0.36,-0.12,0.15,-0.15,0.33,-0.14,0.31,-0.22,0.18,-0.25,0.15,-0.27,0.29,-0.36,0.36,-0.22,0.34,-0.3,0.3,-0.24,0.22,-0.25,0.32,-0.26,0.36,-0.25,0.34,-0.27,0.34,-0.23,0.34,-0.21,0.35,-0.13,0.13,-0.16,0.29,-0.09,0.1,-0.21,0.3,-0.21,0.28,-0.23,0.32,-0.26,0.33,-0.24,0.29,-0.23,0.34,-0.22,0.15,-0.21,0.22,-0.2,0.23,-0.16,0.12,-0.5,0.38,-0.48,0.42,-0.41,0.44,-0.22,0.27,-0.21,0.34,-0.22,0.25,-0.22,0.3,-0.27,0.35,-0.25,0.34,-0.22,0.23,-0.2,0.19,-0.26,0.34,-0.11,0.14,-0.21,0.25,-0.22,0.27,-0.29,0.27,-0.23,0.29,-0.14,0.18,-0.22,0.33,-0.27,0.3,-0.3,0.32,-0.29,0.32,-0.18,0.27,-0.19,0.32,-0.29,0.32,-0.16,0.25,-0.07,0.06,-0.31,0.34,-0.49,0.39,-0.48,0.38,-0.44,0.3,-0.16,0.19,-0.14,0.22,-0.19,0.34,-0.23,0.34,-0.31,0.27,-0.3,0.26,-0.13,0.21,-0.07,0.07,-0.07,0.05,-0.23,0.34,-0.25,0.33,-0.21,0.25,-0.16,0.14,-0.29,0.28,-0.28,0.3,-0.26,0.34,-0.27,0.36,-0.28,0.36,-0.25,0.34,-0.23,0.36,-0.23,0.29,-0.31,0.25,-0.13,0.14,-0.25,0.29,-0.45,0.4,-0.45,0.36,-0.39,0.32,-0.08,0.09,-0.21,0.27,-0.28,0.29,-0.31,0.25,-0.31,0.22,-0.1,0.12,-0.32,0.24,-0.32,0.25,-0.12,0.11,-0.14,0.17,-0.19,0.14,-0.2,0.19,-0.19,0.22,-0.14,0.16,-0.09,0.09,-0.07,0.08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.02,0.01,-0.03,0.01,-0.32,0.36,-0.35,0.36,-0.2,0.18,-0.23,0.31,-0.45,0.49,-0.26,0.33,-0.1,0.1,-0.1,0.12,-0.22,0.34,-0.26,0.32,-0.23,0.29,-0.25,0.39,-0.27,0.36,-0.07,0.07,-0.25,0.36,-0.3,0.36,-0.29,0.37,-0.26,0.26,-0.26,0.3,-0.2,0.28,-0.42,0.36,-0.42,0.29,-0.29,0.32,-0.23,0.32,-0.25,0.28,-0.18,0.25,-0.4,0.39,-0.32,0.35,-0.1,0.13,-0.04,0.05,-0.15,0.24,-0.2,0.25,-0.23,0.32,-0.24,0.36,-0.18,0.27,-0.49,0.33,-0.51,0.31,-0.35,0.32,-0.05,0.05,-0.34,0.36,-0.4,0.32,-0.33,0.35,-0.27,0.22,-0.29,0.36,-0.45,0.32,-0.42,0.32,-0.21,0.32,-0.1,0.13,-0.16,0.23,-0.26,0.28,-0.25,0.32,-0.18,0.2,-0.29,0.16,-0.29,0.34,-0.25,0.33,-0.25,0.32,-0.23,0.35,-0.2,0.36,-0.21,0.26,-0.25,0.27,-0.13,0.15,-0.38,0.36,-0.39,0.3,-0.26,0.32,-0.21,0.34,-0.21,0.32,-0.01,0.01,-0.12,0.11,-0.38,0.31,-0.4,0.32,-0.18,0.18,-0.1,0.1,-0.2,0.27,-0.24,0.29,-0.3,0.31,-0.2,0.29,-0.21,0.22,-0.37,0.32,-0.38,0.36,-0.17,0.24,-0.21,0.33,-0.23,0.32,-0.27,0.34,-0.16,0.27,-0.32,0.33,-0.21,0.34,-0.32,0.36,-0.23,0.23,-0.51,0.38,-0.5,0.26,-0.36,0.35,-0.24,0.36,-0.26,0.38,-0.13,0.18,-0.29,0.21,-0.28,0.28,-0.27,0.31,-0.36,0.34,-0.29,0.36,-0.22,0.35,-0.26,0.4,-0.25,0.29,-0.3,0.2,-0.25,0.36,-0.25,0.34,-0.27,0.37,-0.27,0.34,-0.22,0.36,-0.21,0.27,-0.17,0.19,-0.16,0.27,-0.09,0.12,-0.2,0.29,-0.23,0.32,-0.23,0.34,-0.19,0.32,-0.1,0.13,-0.16,0.19,-0.25,0.32,-0.24,0.29,-0.24,0.27,-0.43,0.42,-0.42,0.33,-0.24,0.16,-0.25,0.25,-0.11,0.1,-0.42,0.34,-0.46,0.29,-0.38,0.29,-0.22,0.32,-0.12,0.16,-0.34,0.23,-0.4,0.3,-0.37,0.32,-0.32,0.25,-0.07,0.06,-0.12,0.18,-0.1,0.16,-0.01,0.0,-0.01,0.01,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.06,-0.03,0.03,-0.08,0.08,-0.05,0.08,-0.06,0.05,-0.07,0.09,-0.05,0.07,-0.03,0.04,-0.08,0.08,-0.04,0.05,-0.03,0.03,-0.05,0.11,-0.07,0.05,-0.05,0.05,-0.06,0.1,-0.07,0.07,-0.05,0.05,-0.06,0.05,-0.05,0.1,-0.05,0.05,0.0,0.03,-0.04,0.02,-0.04,0.01,-0.04,0.01,-0.03,0.04,-0.03,0.05,-0.01,0.0,-0.02,0.01,-0.01,0.01,-0.01,0.01,-0.1,0.17,-0.4,0.45,-0.34,0.37,-0.24,0.29,-0.34,0.37,-0.28,0.29,-0.45,0.44,-0.45,0.47,-0.41,0.32,-0.18,0.38,-0.19,0.37,-0.32,0.2,-0.22,0.36,-0.31,0.36,-0.26,0.37,-0.28,0.34,-0.25,0.3,-0.18,0.27,-0.14,0.15,-0.19,0.29,-0.14,0.32,-0.09,0.12,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,-0.13,0.2,-0.22,0.28,-0.21,0.29,-0.36,0.37,-0.37,0.35,-0.16,0.17,-0.25,0.26,-0.4,0.38,-0.32,0.33,-0.21,0.27,-0.22,0.35,-0.26,0.32,-0.23,0.25,0.0,0.01,-0.23,0.32,-0.38,0.35,-0.29,0.31,-0.14,0.14,-0.1,0.08,-0.22,0.3,-0.25,0.34,-0.28,0.32,-0.25,0.3,-0.23,0.33,-0.26,0.29,-0.27,0.27,-0.25,0.32,-0.3,0.38,-0.25,0.38,-0.18,0.23,-0.17,0.18,-0.19,0.23,-0.38,0.34,-0.36,0.36,-0.31,0.37,-0.11,0.09,-0.25,0.34,-0.24,0.29,-0.32,0.34,-0.29,0.32,-0.1,0.1,-0.37,0.39,-0.46,0.35,-0.16,0.2,-0.12,0.13,-0.22,0.35,-0.25,0.28,-0.18,0.33,-0.08,0.08,-0.35,0.33,-0.41,0.36,-0.21,0.25,-0.31,0.25,-0.32,0.32,-0.32,0.32,-0.25,0.39,-0.18,0.32,-0.16,0.22,-0.18,0.34,-0.12,0.19,-0.1,0.14,-0.14,0.18,-0.13,0.12,-0.18,0.21,-0.43,0.43,-0.45,0.43,-0.43,0.35,-0.36,0.34,-0.13,0.1,-0.09,0.17,-0.27,0.24,-0.29,0.23,-0.29,0.21,-0.24,0.18,-0.1,0.11,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.12,0.27,-0.28,0.3,-0.25,0.25,-0.27,0.37,-0.18,0.32,-0.1,0.15,-0.42,0.49,-0.4,0.47,-0.42,0.39,-0.17,0.25,-0.01,0.01,-0.27,0.39,-0.34,0.37,-0.25,0.36,-0.31,0.32,-0.2,0.33,-0.24,0.27,-0.1,0.1,-0.39,0.38,-0.5,0.33,-0.47,0.33,-0.45,0.36,-0.28,0.26,-0.32,0.32,-0.25,0.36,-0.22,0.34,-0.24,0.33,-0.25,0.32,-0.11,0.1,-0.29,0.36,-0.34,0.28,-0.34,0.38,-0.32,0.25,-0.23,0.36,-0.15,0.21,-0.06,0.01,-0.46,0.37,-0.46,0.32,-0.3,0.3,-0.16,0.21,-0.39,0.34,-0.47,0.28,-0.4,0.34,-0.27,0.35,-0.08,0.08,-0.12,0.21,-0.1,0.1,-0.12,0.23,-0.26,0.34,-0.2,0.33,-0.24,0.29,-0.26,0.28,-0.26,0.32,-0.23,0.32,-0.21,0.27,-0.33,0.28,-0.3,0.32,-0.29,0.35,-0.24,0.29,-0.18,0.23,-0.2,0.27,-0.36,0.3,-0.36,0.31,-0.06,0.09,-0.1,0.1,-0.25,0.32,-0.23,0.29,-0.11,0.11,-0.16,0.26,-0.36,0.36,-0.34,0.27,-0.21,0.27,-0.2,0.23,-0.16,0.17,-0.15,0.19,-0.17,0.17,-0.07,0.08,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.03,-0.05,0.05,-0.08,0.08,-0.06,0.07,-0.05,0.03,-0.07,0.09,-0.04,0.05,-0.05,0.05,-0.08,0.08,-0.04,0.05,-0.05,0.05,-0.07,0.12,-0.06,0.06,-0.02,0.03,-0.07,0.1,-0.05,0.08,-0.05,0.05,-0.06,0.11,-0.05,0.04,-0.03,0.05,-0.02,0.03,-0.04,0.02,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.05,0.04,-0.22,0.36,-0.27,0.4,-0.34,0.4,-0.31,0.32,-0.32,0.38,-0.21,0.16,-0.41,0.38,-0.47,0.42,-0.38,0.26,-0.21,0.22,-0.12,0.11,-0.42,0.4,-0.5,0.33,-0.46,0.34,-0.35,0.36,-0.22,0.36,-0.17,0.33,-0.28,0.23,-0.3,0.27,-0.41,0.36,-0.43,0.27,-0.36,0.32,-0.17,0.21,-0.1,0.08,0.0,0.0,-0.04,0.03,-0.3,0.32,-0.4,0.36,-0.24,0.32,-0.25,0.32,-0.27,0.36,-0.2,0.19,-0.14,0.15,-0.22,0.27,-0.25,0.32,-0.25,0.31,-0.27,0.32,-0.19,0.31,-0.1,0.11,-0.23,0.32,-0.23,0.34,-0.25,0.32,-0.29,0.39,-0.34,0.37,-0.33,0.33,-0.18,0.22,-0.15,0.25,-0.2,0.24,-0.21,0.21,-0.36,0.23,-0.38,0.35,-0.26,0.36,-0.29,0.16,-0.3,0.33,-0.32,0.29,-0.37,0.34,-0.32,0.31,-0.15,0.24,-0.13,0.14,-0.11,0.12,-0.23,0.25,-0.26,0.35,-0.27,0.36,-0.29,0.34,-0.2,0.29,-0.23,0.35,-0.17,0.2,-0.14,0.15,-0.21,0.25,-0.23,0.31,-0.21,0.28,-0.18,0.22,-0.24,0.24,-0.4,0.4,-0.42,0.4,-0.45,0.34,-0.21,0.31,-0.12,0.13,-0.29,0.33,-0.37,0.31,-0.39,0.31,-0.23,0.3,-0.12,0.21,-0.27,0.29,-0.37,0.35,-0.36,0.36,-0.32,0.35,-0.31,0.34,-0.09,0.1,-0.12,0.14,-0.34,0.36,-0.34,0.37,-0.24,0.27,-0.21,0.27,-0.28,0.27,-0.18,0.13,-0.29,0.34,-0.31,0.32,-0.07,0.08,-0.1,0.24,-0.18,0.29,-0.12,0.17,-0.01,0.0,-0.1,0.06,-0.26,0.33,-0.25,0.36,-0.38,0.35,-0.36,0.36,-0.03,0.03,-0.14,0.14,-0.23,0.28,-0.36,0.34,-0.34,0.32,-0.34,0.34,-0.43,0.35,-0.39,0.28,-0.25,0.29,-0.24,0.35,-0.01,0.03,-0.22,0.32,-0.31,0.33,-0.27,0.38,-0.25,0.28,-0.36,0.31,-0.35,0.34,-0.34,0.2,-0.25,0.18,-0.28,0.29,-0.21,0.15,-0.15,0.32,-0.14,0.25,-0.23,0.14,-0.19,0.15,-0.18,0.2,-0.24,0.25,-0.25,0.27,-0.24,0.35,-0.21,0.36,-0.1,0.11,-0.13,0.14,-0.37,0.4,-0.34,0.38,-0.17,0.29,-0.16,0.16,-0.26,0.27,-0.14,0.17,-0.28,0.32,-0.42,0.46,-0.42,0.46,-0.32,0.25,-0.18,0.2,-0.27,0.33,-0.28,0.32,-0.21,0.27,-0.31,0.3,-0.27,0.29,-0.2,0.29,-0.22,0.25,-0.19,0.18,-0.01,0.01,-0.12,0.11,-0.31,0.27,-0.35,0.29,-0.18,0.34,-0.19,0.35,-0.26,0.34,-0.23,0.34,-0.03,0.04,-0.32,0.36,-0.4,0.33,-0.41,0.36,-0.32,0.32,-0.18,0.3,-0.17,0.36,-0.16,0.29,-0.15,0.28,-0.16,0.27,-0.29,0.27,-0.21,0.25,-0.23,0.3,-0.25,0.25,-0.25,0.34,-0.18,0.29,-0.17,0.23,-0.25,0.27,-0.08,0.14,-0.13,0.11,-0.25,0.33,-0.15,0.23,-0.2,0.23,-0.22,0.31,-0.14,0.21,-0.14,0.18,-0.18,0.27,-0.07,0.1,-0.16,0.34,-0.24,0.32,-0.27,0.29,-0.37,0.36,-0.38,0.38,-0.1,0.16,-0.28,0.35,-0.22,0.3,-0.26,0.3,-0.21,0.16,-0.07,0.1,-0.17,0.21,-0.19,0.24,-0.38,0.36,-0.29,0.34,-0.08,0.12,-0.21,0.32,-0.19,0.27,-0.17,0.3,-0.17,0.32,-0.14,0.16,-0.3,0.34,-0.22,0.32,-0.04,0.05,-0.28,0.32,-0.29,0.3,-0.29,0.34,-0.36,0.34,-0.34,0.38,-0.29,0.36,-0.27,0.3,-0.14,0.18,-0.37,0.36,-0.25,0.29,-0.41,0.42,-0.44,0.4,-0.44,0.35,-0.37,0.3,-0.06,0.08,-0.18,0.24,-0.36,0.32,-0.38,0.3,-0.37,0.32,-0.14,0.22,-0.14,0.24,-0.34,0.34,-0.38,0.36,-0.21,0.27,-0.24,0.35,-0.11,0.09,-0.19,0.25,-0.2,0.27,-0.18,0.26,-0.29,0.21,-0.24,0.24,-0.12,0.1,-0.01,0.01,-0.16,0.2,-0.23,0.29,-0.27,0.27,-0.34,0.35,-0.34,0.31,-0.32,0.29,-0.45,0.33,-0.41,0.27,-0.2,0.21,-0.21,0.17,-0.3,0.34,-0.25,0.32,-0.14,0.18,-0.22,0.35,-0.21,0.24,-0.2,0.28,-0.29,0.32,-0.26,0.32,-0.25,0.26,-0.42,0.49,-0.39,0.47,-0.07,0.1,-0.16,0.29,-0.23,0.35,-0.25,0.37,-0.05,0.09,-0.16,0.25,-0.18,0.25,-0.28,0.24,-0.14,0.23,-0.21,0.3,-0.16,0.22,-0.17,0.18,-0.18,0.27,-0.12,0.1,-0.18,0.29,-0.47,0.29,-0.47,0.27,-0.33,0.32,-0.14,0.23,-0.08,0.1,-0.16,0.21,-0.2,0.28,-0.21,0.21,-0.07,0.11,-0.3,0.36,-0.27,0.31,-0.27,0.35,-0.08,0.07,-0.18,0.28,-0.21,0.38,-0.21,0.24,-0.38,0.3,-0.18,0.32,-0.16,0.3,-0.39,0.32,-0.4,0.3,-0.22,0.28,-0.19,0.3,-0.05,0.06,-0.21,0.38,-0.47,0.38,-0.45,0.34,-0.27,0.34,-0.11,0.14,-0.18,0.29,-0.22,0.29,-0.21,0.22,-0.19,0.18,-0.1,0.12,-0.08,0.07,-0.12,0.09,-0.04,0.03,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.05,-0.05,0.05,-0.08,0.08,-0.06,0.07,-0.05,0.05,-0.07,0.09,-0.04,0.05,-0.04,0.05,-0.08,0.08,-0.04,0.06,-0.04,0.05,-0.07,0.12,-0.06,0.06,-0.03,0.04,-0.07,0.1,-0.05,0.08,-0.05,0.05,-0.07,0.12,-0.06,0.07,-0.03,0.05,-0.02,0.03,-0.05,0.02,-0.05,0.01,-0.04,0.03,-0.03,0.05,-0.03,0.06,-0.03,0.01,-0.03,0.01,-0.01,0.01,-0.08,0.06,-0.51,0.32,-0.44,0.43,-0.23,0.17,-0.27,0.38,-0.15,0.21,-0.2,0.32,-0.4,0.4,-0.34,0.39,-0.21,0.27,-0.15,0.21,-0.26,0.25,-0.29,0.22,-0.26,0.31,-0.24,0.36,-0.27,0.38,-0.22,0.27,-0.18,0.27,-0.31,0.36,-0.09,0.08,-0.14,0.21,-0.19,0.29,-0.21,0.29,-0.31,0.38,-0.24,0.3,-0.25,0.27,-0.26,0.34,-0.21,0.24,-0.14,0.15,-0.14,0.24,-0.26,0.33,-0.23,0.26,-0.38,0.4,-0.29,0.27,-0.42,0.43,-0.45,0.45,-0.37,0.32,-0.25,0.21,-0.28,0.31,-0.1,0.1,-0.13,0.29,-0.33,0.25,-0.37,0.32,-0.19,0.27,-0.14,0.23,-0.1,0.11,-0.08,0.06,-0.23,0.33,-0.48,0.34,-0.5,0.31,-0.34,0.32,-0.03,0.03,-0.1,0.1,-0.27,0.36,-0.25,0.33,-0.1,0.07,-0.4,0.32,-0.47,0.33,-0.45,0.34,-0.24,0.33,-0.47,0.34,-0.43,0.27,-0.13,0.2,-0.22,0.36,-0.19,0.26,-0.38,0.36,-0.36,0.38,-0.38,0.36,-0.29,0.3,-0.15,0.13,-0.21,0.18,-0.25,0.34,-0.28,0.33,-0.25,0.33,-0.21,0.34,-0.27,0.27,-0.27,0.36,-0.34,0.37,-0.29,0.38,-0.18,0.24,-0.23,0.29,-0.4,0.37,-0.37,0.28,-0.17,0.24,-0.3,0.25,-0.24,0.3,-0.17,0.23,-0.13,0.12,-0.25,0.37,-0.26,0.39,-0.05,0.03,-0.21,0.16,-0.32,0.38,-0.35,0.32,-0.32,0.34,-0.27,0.34,-0.25,0.32,-0.33,0.29,-0.37,0.32,-0.13,0.22,-0.22,0.14,-0.23,0.28,-0.25,0.3,-0.29,0.22,-0.16,0.21,-0.18,0.2,-0.19,0.32,-0.12,0.21,-0.16,0.32,-0.25,0.26,-0.23,0.28,-0.2,0.29,-0.1,0.14,-0.16,0.28,-0.42,0.42,-0.39,0.45,-0.25,0.16,-0.07,0.08,-0.29,0.33,-0.31,0.32,-0.25,0.28,-0.26,0.27,-0.25,0.37,-0.23,0.34,-0.18,0.25,-0.32,0.38,-0.29,0.38,-0.33,0.36,-0.32,0.34,-0.18,0.28,-0.08,0.07,-0.45,0.38,-0.48,0.3,-0.4,0.37,-0.25,0.36,-0.14,0.14,-0.18,0.27,-0.18,0.27,-0.22,0.29,-0.21,0.35,-0.1,0.18,-0.09,0.11,-0.11,0.21,-0.23,0.36,-0.21,0.37,-0.15,0.29,-0.36,0.34,-0.35,0.3,-0.25,0.2,-0.21,0.27,-0.32,0.34,-0.09,0.1,-0.02,0.02,-0.2,0.21,-0.23,0.29,-0.22,0.31,-0.07,0.06,-0.13,0.18,-0.17,0.21,-0.23,0.29,-0.21,0.23,-0.27,0.32,-0.25,0.25,-0.07,0.05,0.0,0.0,-0.06,0.07,-0.21,0.31,-0.26,0.37,-0.27,0.35,-0.23,0.34,-0.39,0.21,-0.22,0.23,-0.16,0.21,-0.22,0.26,-0.18,0.18,-0.12,0.05,-0.1,0.22,-0.18,0.26,-0.31,0.29,-0.23,0.35,-0.21,0.27,-0.23,0.25,-0.31,0.37,-0.28,0.35,-0.05,0.03,-0.22,0.34,-0.36,0.37,-0.37,0.34,-0.32,0.31,-0.23,0.27,-0.17,0.33,-0.19,0.16,-0.1,0.1,-0.12,0.18,-0.21,0.25,-0.22,0.3,-0.23,0.27,-0.16,0.18,-0.38,0.39,-0.43,0.42,-0.45,0.36,-0.36,0.3,-0.09,0.09,-0.21,0.27,-0.36,0.36,-0.4,0.34,-0.4,0.31,-0.18,0.27,-0.13,0.25,-0.34,0.32,-0.38,0.37,-0.21,0.27,-0.27,0.38,-0.06,0.05,-0.2,0.31,-0.19,0.29,-0.17,0.15,-0.27,0.32,-0.29,0.3,-0.27,0.27,-0.18,0.25,-0.16,0.26,-0.19,0.3,-0.21,0.24,-0.01,0.01,-0.06,0.08,-0.2,0.22,-0.33,0.32,-0.28,0.39,-0.21,0.3,-0.1,0.14,-0.23,0.35,-0.23,0.33,-0.22,0.35,-0.39,0.39,-0.34,0.38,-0.32,0.21,-0.08,0.05,-0.11,0.19,-0.19,0.25,-0.35,0.37,-0.38,0.35,-0.11,0.12,-0.28,0.36,-0.16,0.18,-0.39,0.4,-0.44,0.42,-0.34,0.34,-0.27,0.21,-0.27,0.31,-0.24,0.17,-0.39,0.4,-0.42,0.42,-0.09,0.12,-0.09,0.18,-0.11,0.15,-0.14,0.18,-0.15,0.15,-0.32,0.32,-0.31,0.32,-0.21,0.29,-0.19,0.36,-0.16,0.38,-0.16,0.34,-0.38,0.39,-0.47,0.36,-0.37,0.35,-0.04,0.07,-0.15,0.18,-0.31,0.35,-0.33,0.36,-0.18,0.32,-0.26,0.34,-0.19,0.31,-0.21,0.34,-0.12,0.11,-0.13,0.16,-0.17,0.32,-0.25,0.23,-0.27,0.3,-0.18,0.16,-0.26,0.36,-0.24,0.25,-0.27,0.31,-0.3,0.34,-0.19,0.26,-0.12,0.14,-0.13,0.17,-0.21,0.25,-0.05,0.03,-0.12,0.27,-0.25,0.34,-0.33,0.33,-0.21,0.33,-0.17,0.14,-0.29,0.2,-0.19,0.34,-0.15,0.14,-0.23,0.35,-0.22,0.36,-0.23,0.34,-0.22,0.18,-0.16,0.26,-0.23,0.34,-0.21,0.32,-0.23,0.32,-0.27,0.3,-0.24,0.27,-0.34,0.26,-0.31,0.27,-0.01,0.01,-0.22,0.27,-0.28,0.32,-0.12,0.1,-0.07,0.08,-0.21,0.27,-0.47,0.37,-0.49,0.4,-0.47,0.38,-0.23,0.27,-0.25,0.16,-0.12,0.24,-0.14,0.14,-0.2,0.25,-0.21,0.22,-0.08,0.08,-0.16,0.15,-0.28,0.3,-0.17,0.13,-0.24,0.35,-0.3,0.36,-0.32,0.32,-0.18,0.23,-0.15,0.19,-0.16,0.17,-0.14,0.14,-0.09,0.06,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.03,0.03,-0.05,0.05,-0.08,0.08,-0.07,0.07,-0.02,0.03,-0.07,0.09,-0.04,0.05,-0.05,0.05,-0.08,0.08,-0.04,0.05,-0.05,0.05,-0.07,0.12,-0.06,0.06,-0.02,0.03,-0.07,0.1,-0.05,0.08,-0.05,0.05,-0.06,0.11,-0.05,0.04,-0.03,0.05,-0.01,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.04,-0.03,0.01,-0.02,0.01,-0.01,0.01,0.0,0.01,-0.25,0.36,-0.32,0.34,-0.21,0.23,-0.47,0.49,-0.48,0.48,-0.36,0.38,-0.27,0.25,-0.33,0.35,-0.41,0.21,-0.44,0.42,-0.42,0.4,-0.08,0.08,-0.1,0.12,-0.27,0.32,-0.27,0.32,-0.23,0.32,-0.23,0.3,-0.18,0.24,-0.37,0.41,-0.42,0.42,-0.45,0.36,-0.39,0.33,-0.1,0.11,-0.15,0.21,-0.3,0.37,-0.39,0.36,-0.42,0.32,-0.33,0.29,-0.1,0.14,-0.25,0.31,-0.34,0.34,-0.34,0.34,-0.29,0.29,-0.34,0.38,-0.23,0.36,-0.14,0.13,-0.12,0.11,-0.14,0.23,-0.18,0.26,-0.34,0.25,-0.23,0.18,-0.18,0.25,-0.17,0.25,-0.33,0.32,-0.35,0.3,-0.27,0.27,-0.42,0.38,-0.42,0.36,-0.29,0.37,-0.23,0.27,-0.24,0.36,-0.35,0.36,-0.34,0.38,-0.32,0.38,-0.29,0.38,-0.34,0.32,-0.22,0.25,-0.21,0.35,-0.11,0.12,-0.08,0.08,-0.48,0.36,-0.48,0.3,-0.38,0.37,-0.16,0.25,-0.14,0.14,-0.21,0.32,-0.34,0.18,-0.08,0.14,-0.09,0.11,-0.26,0.34,-0.27,0.38,-0.18,0.35,-0.37,0.35,-0.38,0.3,-0.27,0.32,-0.08,0.09,-0.18,0.23,-0.21,0.27,-0.19,0.32,-0.26,0.34,-0.21,0.25,-0.45,0.43,-0.48,0.49,-0.4,0.47,-0.38,0.4,-0.23,0.24,-0.25,0.25,-0.29,0.27,-0.14,0.09,-0.22,0.25,-0.23,0.21,-0.17,0.2,-0.23,0.21,-0.27,0.23,-0.24,0.18,-0.18,0.16,-0.01,0.03,0.0,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.04,0.05,-0.21,0.34,-0.24,0.38,-0.28,0.38,-0.27,0.34,-0.3,0.4,-0.21,0.29,-0.38,0.35,-0.27,0.34,-0.25,0.24,-0.27,0.33,-0.3,0.37,-0.32,0.41,-0.16,0.32,-0.32,0.22,-0.2,0.28,-0.14,0.14,-0.25,0.32,-0.51,0.34,-0.49,0.38,-0.19,0.34,-0.33,0.27,-0.32,0.33,-0.11,0.13,-0.21,0.3,-0.18,0.31,-0.18,0.26,-0.08,0.1,-0.14,0.25,-0.25,0.29,-0.27,0.31,-0.3,0.29,-0.16,0.14,-0.17,0.25,-0.21,0.29,-0.29,0.28,-0.34,0.31,-0.27,0.32,-0.34,0.39,-0.35,0.39,-0.21,0.3,-0.09,0.11,-0.14,0.25,-0.26,0.18,-0.2,0.23,-0.19,0.21,-0.18,0.29,-0.18,0.28,-0.23,0.32,-0.15,0.27,-0.07,0.07,-0.44,0.36,-0.48,0.32,-0.47,0.29,-0.32,0.35,-0.24,0.42,-0.19,0.25,-0.24,0.16,-0.22,0.32,-0.23,0.28,-0.13,0.17,-0.08,0.08,0.0,0.0,-0.04,0.03,-0.34,0.34,-0.37,0.34,-0.22,0.34,-0.27,0.25,-0.38,0.34,-0.45,0.38,-0.18,0.23,-0.21,0.36,-0.17,0.32,-0.01,0.01,-0.29,0.35,-0.51,0.34,-0.49,0.34,-0.32,0.34,-0.3,0.25,-0.26,0.33,-0.15,0.29,-0.23,0.21,-0.25,0.26,-0.3,0.27,-0.32,0.27,-0.34,0.29,-0.23,0.27,-0.4,0.4,-0.42,0.37,-0.38,0.37,-0.23,0.32,-0.22,0.36,-0.4,0.39,-0.29,0.34,-0.21,0.38,-0.24,0.33,-0.18,0.29,-0.18,0.29,-0.16,0.23,-0.27,0.35,-0.16,0.32,-0.1,0.12,-0.11,0.15,-0.27,0.35,-0.25,0.36,-0.16,0.36,-0.32,0.36,-0.36,0.35,-0.3,0.27,-0.15,0.19,-0.17,0.16,-0.21,0.27,-0.1,0.17,-0.08,0.08,-0.13,0.13,-0.27,0.34,-0.21,0.35,-0.25,0.34,-0.25,0.34,-0.19,0.32,-0.17,0.26,-0.2,0.36,-0.18,0.34,-0.08,0.1,-0.08,0.1,-0.26,0.32,-0.27,0.36,-0.21,0.34,-0.18,0.25,-0.39,0.34,-0.4,0.33,-0.34,0.29,-0.14,0.21,-0.05,0.06,0.0,0.01,-0.16,0.19,-0.23,0.29,-0.1,0.08,-0.22,0.27,-0.23,0.36,-0.23,0.34,-0.1,0.1,-0.21,0.23,-0.23,0.33,-0.29,0.32,-0.27,0.23,-0.21,0.18,-0.08,0.08,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.02,0.03,-0.21,0.32,-0.29,0.32,-0.29,0.31,-0.37,0.37,-0.4,0.4,-0.14,0.14,-0.25,0.35,-0.27,0.37,-0.21,0.18,-0.23,0.38,-0.21,0.31,-0.14,0.12,-0.28,0.36,-0.28,0.39,-0.21,0.22,-0.14,0.19,-0.25,0.25,-0.35,0.33,-0.23,0.25,-0.23,0.22,-0.14,0.2,-0.25,0.24,-0.21,0.19,-0.08,0.1,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.06,-0.03,0.03,-0.08,0.08,-0.05,0.08,-0.06,0.05,-0.06,0.08,-0.05,0.06,-0.03,0.03,-0.07,0.07,-0.04,0.05,-0.03,0.03,-0.04,0.1,-0.06,0.04,-0.05,0.05,-0.05,0.08,-0.05,0.07,-0.04,0.04,-0.05,0.04,-0.05,0.09,-0.04,0.05,0.0,0.03,-0.03,0.01,-0.03,0.01,-0.03,0.01,-0.03,0.03,-0.03,0.05,0.0,0.0,-0.02,0.01,-0.01,0.01,-0.01,0.01,-0.22,0.23,-0.51,0.36,-0.5,0.38,-0.49,0.32,-0.23,0.34,-0.22,0.32,-0.21,0.21,-0.25,0.28,-0.29,0.36,-0.29,0.35,-0.19,0.15,-0.35,0.36,-0.33,0.45,-0.35,0.37,-0.3,0.38,-0.26,0.33,-0.53,0.38,-0.29,0.25,-0.36,0.38,-0.42,0.42,-0.35,0.32,-0.32,0.31,-0.25,0.23,-0.25,0.29,-0.4,0.4,-0.39,0.34,-0.08,0.07,-0.09,0.1,-0.21,0.29,-0.23,0.24,-0.25,0.32,-0.15,0.24,-0.27,0.29,-0.37,0.34,-0.4,0.34,-0.24,0.25,-0.27,0.37,-0.16,0.27,-0.15,0.16,-0.03,0.03,-0.2,0.23,-0.27,0.35,-0.2,0.22,-0.12,0.12,-0.25,0.3,-0.27,0.28,-0.5,0.42,-0.49,0.42,-0.4,0.38,-0.2,0.3,-0.25,0.33,-0.23,0.37,-0.06,0.05,-0.13,0.2,-0.23,0.29,-0.03,0.04,-0.16,0.22,-0.25,0.4,-0.25,0.4,-0.05,0.02,-0.2,0.38,-0.23,0.36,-0.18,0.33,-0.31,0.24,-0.21,0.33,-0.28,0.31,-0.12,0.21,-0.21,0.31,-0.21,0.25,-0.11,0.08,-0.24,0.25,-0.34,0.27,-0.37,0.36,-0.34,0.37,-0.13,0.14,-0.22,0.36,-0.14,0.27,-0.1,0.16,-0.18,0.22,-0.25,0.25,-0.21,0.34,-0.26,0.36,-0.08,0.08,-0.22,0.28,-0.26,0.23,-0.21,0.21,-0.27,0.28,-0.32,0.36,-0.25,0.26,-0.27,0.26,-0.33,0.31,-0.38,0.39,-0.51,0.36,-0.49,0.34,-0.44,0.27,-0.05,0.07,-0.16,0.24,-0.15,0.19,-0.18,0.15,-0.2,0.21,-0.11,0.12,-0.02,0.02,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.44,0.32,-0.46,0.31,-0.3,0.27,-0.14,0.14,-0.41,0.35,-0.39,0.39,-0.24,0.36,-0.16,0.16,-0.18,0.29,-0.1,0.09,-0.17,0.24,-0.29,0.27,-0.36,0.34,-0.29,0.18,-0.49,0.39,-0.5,0.27,-0.4,0.38,-0.19,0.38,-0.1,0.08,-0.25,0.36,-0.21,0.25,-0.08,0.1,-0.25,0.3,-0.29,0.32,-0.23,0.3,-0.25,0.3,-0.27,0.29,-0.23,0.25,-0.29,0.34,-0.29,0.36,-0.17,0.16,-0.07,0.1,-0.15,0.23,-0.32,0.32,-0.4,0.37,-0.22,0.32,-0.3,0.38,-0.1,0.06,-0.14,0.16,-0.39,0.33,-0.43,0.3,-0.18,0.31,-0.21,0.29,-0.21,0.23,-0.32,0.3,-0.43,0.44,-0.45,0.38,-0.42,0.32,-0.15,0.19,-0.08,0.12,-0.28,0.34,-0.39,0.36,-0.42,0.3,-0.21,0.3,-0.21,0.27,-0.29,0.34,-0.38,0.33,-0.38,0.3,-0.29,0.36,-0.25,0.36,-0.1,0.12,-0.15,0.16,-0.17,0.18,-0.21,0.32,-0.25,0.33,-0.13,0.1,-0.23,0.34,-0.19,0.28,-0.25,0.27,-0.25,0.25,-0.23,0.32,-0.14,0.2,-0.14,0.21,-0.36,0.34,-0.42,0.46,-0.21,0.25,-0.2,0.13,-0.14,0.12,-0.34,0.29,-0.21,0.29,-0.21,0.34,-0.16,0.29,-0.26,0.27,-0.34,0.32,-0.4,0.39,-0.16,0.1,-0.12,0.21,-0.38,0.39,-0.42,0.35,-0.34,0.36,-0.1,0.1,-0.16,0.29,-0.25,0.32,-0.21,0.34,-0.25,0.3,-0.23,0.2,-0.05,0.03,-0.26,0.35,-0.28,0.36,-0.26,0.25,-0.34,0.32,-0.21,0.23,-0.12,0.1,-0.08,0.08,-0.32,0.35,-0.13,0.18,-0.21,0.3,-0.23,0.32,-0.01,0.01,-0.16,0.16,-0.23,0.38,-0.25,0.26,-0.03,0.03,-0.17,0.34,-0.21,0.34,-0.26,0.27,-0.26,0.3,-0.2,0.29,-0.24,0.26,-0.11,0.1,-0.2,0.34,-0.21,0.34,-0.23,0.16,-0.44,0.38,-0.5,0.42,-0.45,0.44,-0.36,0.43,-0.2,0.3,-0.3,0.31,-0.22,0.23,-0.02,0.02,-0.04,0.05,-0.18,0.26,-0.1,0.12,-0.12,0.08,-0.34,0.35,-0.39,0.32,-0.33,0.31,-0.26,0.36,-0.23,0.29,-0.1,0.1,-0.24,0.31,-0.28,0.39,-0.19,0.3,-0.27,0.29,-0.28,0.28,-0.26,0.4,-0.42,0.38,-0.42,0.38,-0.28,0.31,-0.34,0.36,-0.19,0.29,-0.23,0.3,-0.08,0.1,-0.16,0.22,-0.14,0.21,-0.05,0.02,-0.27,0.36,-0.22,0.31,-0.14,0.13,-0.2,0.38,-0.26,0.38,-0.03,0.03,-0.13,0.15,-0.17,0.32,-0.24,0.29,-0.25,0.28,-0.17,0.23,-0.2,0.2,-0.1,0.08,-0.12,0.14,-0.32,0.23,-0.43,0.35,-0.42,0.35,-0.29,0.2,-0.12,0.13,-0.1,0.12,-0.08,0.06,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.09,0.08,-0.05,0.06,-0.05,0.05,-0.09,0.1,-0.08,0.08,-0.05,0.03,-0.08,0.1,-0.05,0.05,-0.05,0.05,-0.09,0.09,-0.05,0.06,-0.05,0.05,-0.08,0.13,-0.07,0.07,-0.03,0.04,-0.08,0.11,-0.05,0.08,-0.05,0.05,-0.07,0.12,-0.06,0.04,-0.03,0.05,-0.02,0.03,-0.05,0.02,-0.05,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.12,0.16,-0.32,0.32,-0.33,0.42,-0.36,0.41,-0.21,0.36,-0.21,0.26,-0.16,0.12,-0.24,0.38,-0.25,0.27,-0.25,0.38,-0.25,0.4,-0.29,0.33,-0.35,0.34,-0.23,0.28,-0.27,0.31,-0.25,0.32,-0.21,0.33,-0.36,0.36,-0.28,0.35,-0.16,0.12,-0.2,0.29,-0.25,0.29,-0.28,0.33,-0.32,0.34,-0.38,0.31,-0.12,0.14,-0.16,0.1,-0.23,0.26,-0.24,0.3,-0.14,0.19,-0.2,0.31,-0.16,0.32,-0.19,0.24,-0.11,0.14,-0.08,0.09,-0.17,0.16,-0.42,0.36,-0.43,0.36,-0.32,0.29,-0.34,0.3,-0.16,0.23,-0.28,0.36,-0.33,0.35,-0.35,0.34,-0.29,0.33,-0.17,0.19,-0.02,0.01,-0.16,0.26,-0.27,0.28,-0.27,0.27,-0.27,0.29,-0.28,0.32,-0.12,0.25,-0.24,0.34,-0.14,0.25,-0.32,0.23,-0.2,0.22,-0.23,0.31,-0.2,0.23,-0.28,0.32,-0.34,0.33,-0.3,0.36,-0.07,0.05,-0.2,0.36,-0.19,0.36,-0.16,0.16,-0.08,0.13,-0.12,0.19,-0.23,0.25,-0.19,0.35,-0.1,0.23,-0.09,0.15,-0.19,0.29,-0.07,0.03,-0.17,0.26,-0.47,0.44,-0.47,0.43,-0.41,0.43,-0.11,0.14,-0.35,0.31,-0.21,0.3,-0.21,0.27,-0.08,0.08,-0.16,0.32,-0.23,0.33,-0.28,0.33,-0.38,0.34,-0.33,0.31,-0.21,0.23,-0.22,0.32,-0.27,0.2,-0.16,0.21,-0.21,0.22,-0.1,0.12,-0.49,0.38,-0.51,0.43,-0.42,0.44,-0.31,0.36,-0.19,0.38,-0.21,0.25,-0.21,0.28,-0.27,0.37,-0.24,0.36,-0.19,0.25,-0.27,0.33,-0.16,0.34,-0.1,0.14,-0.11,0.16,-0.11,0.17,-0.14,0.34,-0.16,0.34,-0.15,0.13,-0.23,0.26,-0.35,0.41,-0.27,0.35,-0.14,0.14,-0.31,0.34,-0.34,0.32,-0.34,0.29,-0.05,0.08,-0.1,0.12,-0.14,0.2,-0.08,0.07,-0.18,0.3,-0.22,0.27,-0.27,0.25,-0.32,0.25,-0.34,0.26,-0.3,0.25,-0.03,0.04,-0.1,0.16,-0.12,0.19,-0.06,0.06,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.02,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.02,0.01,-0.01,0.01,-0.13,0.14,-0.31,0.36,-0.25,0.36,-0.23,0.35,-0.31,0.36,-0.1,0.09,-0.28,0.34,-0.25,0.38,-0.12,0.14,-0.26,0.35,-0.35,0.29,-0.35,0.37,-0.09,0.12,-0.29,0.33,-0.28,0.37,-0.06,0.05,-0.12,0.27,-0.23,0.4,-0.05,0.05,-0.4,0.39,-0.5,0.43,-0.45,0.45,-0.4,0.43,-0.26,0.34,-0.25,0.31,-0.16,0.16,-0.25,0.28,-0.23,0.21,-0.32,0.28,-0.25,0.33,-0.27,0.27,-0.27,0.32,-0.28,0.37,-0.25,0.35,-0.18,0.23,-0.21,0.31,-0.14,0.24,-0.13,0.14,-0.32,0.35,-0.29,0.34,-0.34,0.34,-0.24,0.27,-0.14,0.12,-0.2,0.27,-0.27,0.31,-0.27,0.31,-0.23,0.23,-0.27,0.28,-0.26,0.28,-0.18,0.26,-0.28,0.38,-0.29,0.36,-0.28,0.37,-0.28,0.39,-0.27,0.38,-0.23,0.25,-0.19,0.15,-0.18,0.29,-0.36,0.32,-0.37,0.29,-0.25,0.29,-0.3,0.37,-0.15,0.21,-0.03,0.04,-0.23,0.32,-0.44,0.36,-0.39,0.3,-0.14,0.29,-0.25,0.29,-0.25,0.27,-0.2,0.25,-0.32,0.38,-0.27,0.33,-0.13,0.12,-0.09,0.11,-0.28,0.34,-0.36,0.37,-0.36,0.36,-0.28,0.38,-0.32,0.38,-0.13,0.14,-0.14,0.23,-0.22,0.32,-0.2,0.29,-0.14,0.14,-0.1,0.11,-0.21,0.29,-0.07,0.06,-0.15,0.29,-0.47,0.4,-0.47,0.41,-0.42,0.38,-0.18,0.24,-0.28,0.25,-0.19,0.16,-0.14,0.2,-0.11,0.16,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.06,-0.03,0.03,-0.08,0.08,-0.05,0.08,-0.06,0.05,-0.07,0.09,-0.05,0.07,-0.04,0.04,-0.08,0.08,-0.04,0.06,-0.03,0.04,-0.05,0.11,-0.07,0.06,-0.05,0.05,-0.06,0.1,-0.07,0.08,-0.05,0.05,-0.06,0.05,-0.05,0.11,-0.05,0.05,0.0,0.03,-0.04,0.02,-0.05,0.01,-0.04,0.01,-0.03,0.05,-0.03,0.06,-0.01,0.0,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.42,0.43,-0.44,0.47,-0.11,0.1,-0.27,0.33,-0.45,0.5,-0.38,0.44,-0.21,0.29,-0.18,0.18,-0.21,0.32,-0.32,0.44,-0.25,0.38,-0.13,0.11,-0.22,0.33,-0.27,0.34,-0.25,0.34,-0.21,0.36,-0.14,0.08,-0.21,0.33,-0.28,0.36,-0.26,0.38,-0.18,0.2,-0.31,0.31,-0.32,0.23,-0.43,0.42,-0.44,0.33,-0.4,0.36,-0.32,0.32,-0.38,0.35,-0.21,0.24,-0.32,0.35,-0.3,0.34,-0.27,0.34,-0.31,0.35,-0.26,0.31,-0.34,0.31,-0.38,0.33,-0.44,0.36,-0.42,0.32,-0.05,0.05,-0.1,0.11,-0.1,0.15,-0.23,0.25,-0.25,0.33,-0.36,0.34,-0.31,0.3,-0.42,0.41,-0.36,0.34,-0.19,0.25,-0.23,0.34,-0.21,0.32,-0.29,0.32,-0.26,0.27,-0.22,0.34,-0.47,0.33,-0.46,0.27,-0.34,0.34,-0.18,0.29,-0.25,0.35,-0.12,0.27,-0.01,0.01,0.0,0.01,-0.26,0.34,-0.25,0.38,-0.26,0.38,-0.27,0.36,-0.21,0.36,-0.21,0.34,-0.18,0.17,-0.18,0.32,-0.25,0.31,-0.19,0.28,-0.36,0.37,-0.42,0.37,-0.47,0.36,-0.06,0.08,-0.34,0.26,-0.25,0.32,-0.2,0.24,-0.1,0.12,-0.18,0.27,-0.16,0.18,-0.16,0.12,-0.21,0.27,-0.24,0.32,-0.25,0.33,-0.18,0.23,-0.19,0.35,-0.18,0.29,-0.33,0.36,-0.31,0.27,-0.47,0.36,-0.47,0.27,-0.42,0.35,-0.16,0.26,-0.18,0.2,-0.2,0.29,-0.36,0.27,-0.4,0.3,-0.24,0.22,-0.17,0.21,-0.25,0.36,-0.21,0.25,-0.24,0.16,-0.18,0.29,-0.24,0.35,-0.26,0.36,-0.06,0.08,-0.24,0.26,-0.26,0.31,-0.22,0.25,-0.16,0.2,-0.3,0.42,-0.4,0.4,-0.23,0.27,-0.27,0.35,-0.12,0.16,-0.07,0.1,-0.18,0.23,-0.23,0.34,-0.21,0.35,-0.15,0.32,-0.33,0.3,-0.32,0.34,-0.23,0.25,-0.18,0.16,-0.22,0.32,-0.32,0.33,-0.28,0.33,-0.08,0.07,-0.21,0.28,-0.28,0.32,-0.25,0.21,-0.2,0.18,-0.13,0.13,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.0,-0.02,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.02,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.08,0.05,-0.48,0.37,-0.47,0.4,-0.46,0.36,-0.03,0.03,-0.18,0.37,-0.36,0.4,-0.29,0.34,-0.2,0.26,-0.26,0.38,-0.12,0.1,-0.27,0.34,-0.47,0.48,-0.49,0.39,-0.23,0.23,-0.15,0.22,-0.22,0.34,-0.22,0.28,-0.12,0.16,-0.12,0.1,-0.22,0.34,-0.23,0.34,-0.32,0.31,-0.34,0.3,-0.23,0.38,-0.2,0.34,-0.35,0.33,-0.47,0.36,-0.48,0.29,-0.35,0.33,-0.11,0.12,-0.21,0.26,-0.23,0.29,-0.36,0.37,-0.27,0.29,-0.4,0.39,-0.34,0.35,-0.18,0.25,-0.2,0.34,-0.21,0.32,-0.28,0.21,-0.01,0.02,-0.18,0.28,-0.38,0.32,-0.24,0.27,-0.19,0.23,-0.09,0.07,-0.23,0.26,-0.23,0.33,-0.26,0.34,-0.18,0.23,-0.27,0.34,-0.16,0.19,-0.18,0.27,-0.22,0.32,-0.19,0.29,-0.14,0.23,-0.34,0.36,-0.37,0.36,-0.25,0.38,-0.11,0.12,-0.18,0.31,-0.26,0.27,-0.24,0.34,-0.24,0.31,-0.25,0.24,-0.14,0.25,-0.34,0.32,-0.34,0.31,-0.23,0.27,-0.27,0.32,-0.21,0.32,-0.12,0.15,-0.05,0.05,-0.16,0.21,-0.21,0.27,-0.23,0.36,-0.25,0.35,-0.27,0.27,-0.29,0.37,-0.28,0.39,-0.19,0.25,-0.21,0.2,-0.23,0.36,-0.21,0.37,-0.42,0.36,-0.45,0.31,-0.29,0.36,-0.33,0.35,-0.3,0.27,-0.12,0.14,-0.25,0.28,-0.28,0.32,-0.25,0.32,-0.35,0.26,-0.29,0.29,-0.28,0.3,-0.14,0.15,-0.28,0.4,-0.3,0.38,-0.29,0.38,-0.28,0.38,-0.26,0.36,-0.29,0.23,-0.15,0.11,-0.09,0.21,-0.27,0.29,-0.39,0.36,-0.36,0.32,-0.25,0.35,-0.16,0.28,-0.11,0.1,-0.16,0.27,-0.09,0.09,-0.2,0.28,-0.21,0.25,-0.1,0.08,-0.38,0.32,-0.43,0.37,-0.41,0.36,-0.3,0.2,-0.19,0.22,-0.26,0.2,-0.13,0.2,-0.12,0.17,-0.01,0.01,0.0,0.0,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.06,-0.03,0.03,-0.08,0.08,-0.06,0.08,-0.07,0.06,-0.07,0.1,-0.05,0.07,-0.04,0.05,-0.08,0.08,-0.05,0.07,-0.03,0.04,-0.05,0.05,-0.07,0.12,-0.06,0.06,-0.02,0.03,-0.07,0.1,-0.05,0.08,-0.05,0.05,-0.06,0.11,-0.05,0.05,0.0,0.03,-0.04,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.04,-0.03,0.05,0.0,0.0,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.1,0.09,-0.23,0.35,-0.36,0.45,-0.29,0.43,-0.25,0.29,-0.32,0.42,-0.31,0.43,-0.27,0.34,-0.31,0.38,-0.32,0.34,-0.34,0.3,-0.2,0.36,-0.28,0.24,-0.37,0.3,-0.11,0.23,-0.08,0.12,-0.16,0.17,-0.27,0.35,-0.27,0.32,-0.12,0.12,-0.36,0.38,-0.34,0.3,-0.4,0.38,-0.32,0.34,-0.19,0.25,-0.3,0.37,-0.24,0.31,-0.48,0.34,-0.47,0.42,-0.42,0.4,-0.3,0.29,-0.09,0.08,-0.25,0.29,-0.24,0.3,-0.25,0.31,-0.2,0.33,-0.15,0.28,-0.16,0.3,-0.29,0.18,-0.27,0.15,-0.22,0.27,-0.35,0.35,-0.33,0.36,-0.25,0.26,-0.29,0.27,-0.27,0.2,-0.27,0.36,-0.16,0.18,-0.25,0.36,-0.25,0.33,-0.22,0.33,-0.11,0.17,-0.18,0.25,-0.09,0.08,-0.18,0.29,-0.21,0.32,-0.26,0.23,-0.27,0.33,-0.2,0.35,-0.12,0.21,-0.14,0.25,-0.23,0.3,-0.25,0.27,-0.34,0.32,-0.37,0.33,-0.29,0.37,-0.19,0.19,-0.23,0.25,-0.34,0.32,-0.31,0.27,-0.36,0.32,-0.29,0.27,-0.22,0.27,-0.21,0.25,-0.22,0.27,-0.17,0.25,-0.07,0.08,-0.16,0.14,-0.05,0.06,-0.01,0.0,-0.12,0.28,-0.36,0.34,-0.34,0.3,-0.17,0.32,-0.17,0.31,-0.27,0.29,-0.29,0.27,-0.22,0.29,-0.21,0.27,-0.25,0.29,-0.45,0.43,-0.45,0.37,-0.45,0.34,-0.2,0.33,-0.1,0.11,-0.31,0.38,-0.38,0.38,-0.41,0.32,-0.29,0.34,-0.12,0.19,-0.23,0.29,-0.36,0.34,-0.36,0.36,-0.23,0.27,-0.29,0.38,-0.12,0.19,-0.16,0.17,-0.21,0.34,-0.32,0.32,-0.28,0.29,-0.23,0.36,-0.22,0.32,-0.27,0.16,-0.04,0.03,-0.25,0.24,-0.25,0.36,-0.21,0.36,-0.23,0.28,-0.39,0.38,-0.41,0.34,-0.21,0.21,-0.39,0.38,-0.37,0.36,-0.22,0.28,-0.21,0.25,-0.16,0.19,-0.08,0.16,-0.13,0.08,-0.06,0.04,-0.01,0.01,0.0,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.02,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.33,0.36,-0.34,0.38,-0.25,0.3,-0.27,0.3,-0.29,0.3,-0.23,0.26,-0.17,0.19,-0.29,0.32,-0.26,0.3,-0.36,0.37,-0.34,0.36,-0.21,0.25,-0.14,0.17,-0.19,0.27,-0.19,0.27,-0.11,0.09,-0.25,0.34,-0.25,0.36,-0.26,0.35,-0.29,0.32,-0.32,0.32,-0.42,0.45,-0.38,0.41,-0.18,0.38,-0.23,0.4,-0.04,0.04,-0.21,0.34,-0.27,0.36,-0.25,0.29,-0.46,0.29,-0.49,0.31,-0.45,0.32,-0.2,0.3,-0.1,0.11,-0.21,0.24,-0.25,0.32,-0.23,0.25,-0.14,0.1,-0.2,0.29,-0.32,0.3,-0.32,0.31,-0.14,0.24,-0.06,0.04,-0.12,0.13,-0.1,0.11,-0.01,0.01,-0.05,0.05,-0.34,0.34,-0.39,0.36,-0.2,0.29,-0.18,0.19,-0.32,0.4,-0.34,0.36,-0.25,0.37,-0.2,0.29,-0.12,0.16,-0.44,0.37,-0.51,0.31,-0.38,0.37,-0.28,0.29,-0.24,0.24,-0.21,0.32,-0.25,0.29,-0.25,0.26,-0.25,0.32,-0.31,0.39,-0.26,0.34,-0.27,0.31,-0.09,0.09,-0.12,0.19,-0.34,0.2,-0.32,0.27,-0.22,0.23,-0.4,0.38,-0.41,0.36,-0.18,0.25,-0.26,0.36,-0.23,0.23,-0.33,0.25,-0.2,0.31,-0.03,0.02,-0.27,0.34,-0.3,0.35,-0.27,0.37,-0.25,0.29,-0.28,0.25,-0.25,0.32,-0.23,0.27,-0.38,0.29,-0.43,0.39,-0.47,0.28,-0.32,0.34,-0.11,0.16,-0.1,0.19,-0.23,0.25,-0.25,0.28,-0.3,0.36,-0.12,0.14,-0.29,0.29,-0.25,0.22,-0.27,0.23,-0.23,0.34,-0.25,0.32,-0.16,0.17,-0.09,0.07,-0.44,0.36,-0.48,0.28,-0.45,0.32,-0.32,0.36,-0.21,0.38,-0.32,0.12,-0.12,0.12,-0.18,0.27,-0.32,0.29,-0.32,0.36,-0.08,0.08,-0.34,0.36,-0.37,0.32,-0.21,0.32,-0.22,0.35,-0.12,0.17,-0.13,0.16,-0.12,0.2,-0.17,0.33,-0.19,0.32,-0.27,0.32,-0.27,0.3,-0.36,0.35,-0.38,0.38,-0.18,0.21,-0.21,0.25,-0.31,0.36,-0.29,0.28,-0.21,0.14,-0.14,0.18,-0.17,0.25,-0.09,0.08,-0.08,0.08,-0.16,0.29,-0.16,0.26,-0.18,0.15,-0.2,0.34,-0.25,0.3,-0.5,0.32,-0.47,0.34,-0.21,0.31,-0.02,0.01,-0.47,0.4,-0.47,0.38,-0.38,0.36,-0.1,0.11,-0.31,0.32,-0.11,0.14,-0.35,0.37,-0.36,0.38,-0.27,0.29,-0.45,0.33,-0.47,0.37,-0.4,0.36,-0.26,0.17,-0.1,0.09,-0.09,0.08,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.06,-0.03,0.03,-0.08,0.05,-0.07,0.08,-0.06,0.06,-0.03,0.02,-0.07,0.09,-0.04,0.05,-0.05,0.05,-0.08,0.08,-0.03,0.04,-0.05,0.05,-0.06,0.11,-0.05,0.05,-0.02,0.03,-0.06,0.1,-0.05,0.07,-0.05,0.04,-0.06,0.1,-0.05,0.05,-0.01,0.03,-0.03,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.04,-0.03,0.05,0.0,0.0,-0.02,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.38,0.38,-0.4,0.38,-0.26,0.37,-0.39,0.34,-0.5,0.44,-0.5,0.4,-0.45,0.4,-0.34,0.32,-0.23,0.25,-0.16,0.23,-0.47,0.36,-0.51,0.34,-0.49,0.32,-0.18,0.28,-0.23,0.34,-0.24,0.35,-0.28,0.35,-0.29,0.36,-0.35,0.23,-0.27,0.3,-0.47,0.46,-0.46,0.44,-0.39,0.38,-0.14,0.18,-0.16,0.2,-0.23,0.25,-0.24,0.24,-0.2,0.17,-0.25,0.19,-0.25,0.26,-0.23,0.27,-0.22,0.21,-0.26,0.32,-0.04,0.06,-0.44,0.41,-0.51,0.33,-0.47,0.29,-0.31,0.32,-0.08,0.11,-0.19,0.36,-0.16,0.21,-0.39,0.34,-0.33,0.31,-0.18,0.34,-0.08,0.08,-0.17,0.23,-0.38,0.39,-0.25,0.29,-0.14,0.16,-0.2,0.3,-0.03,0.04,-0.17,0.29,-0.36,0.32,-0.32,0.32,-0.19,0.24,-0.18,0.18,-0.21,0.32,-0.27,0.31,-0.23,0.25,-0.35,0.35,-0.2,0.27,-0.39,0.43,-0.43,0.42,-0.45,0.36,-0.4,0.32,-0.13,0.14,-0.08,0.1,-0.29,0.32,-0.37,0.32,-0.4,0.33,-0.37,0.29,-0.14,0.17,-0.23,0.29,-0.3,0.32,-0.38,0.33,-0.33,0.27,-0.25,0.34,-0.21,0.34,-0.06,0.08,-0.15,0.12,-0.19,0.23,-0.21,0.24,-0.27,0.35,-0.51,0.38,-0.44,0.43,-0.25,0.33,-0.17,0.3,-0.16,0.15,-0.23,0.36,-0.35,0.37,-0.35,0.39,-0.29,0.35,-0.29,0.32,-0.12,0.21,-0.28,0.23,-0.31,0.27,-0.23,0.2,-0.14,0.16,-0.16,0.21,-0.08,0.02,-0.15,0.18,-0.23,0.19,-0.18,0.19,-0.13,0.13,-0.06,0.06,-0.1,0.1,-0.05,0.02,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.03,0.02,-0.22,0.35,-0.24,0.36,-0.32,0.21,-0.35,0.4,-0.35,0.38,-0.34,0.38,-0.12,0.1,-0.23,0.28,-0.26,0.29,-0.27,0.32,-0.38,0.38,-0.38,0.38,-0.26,0.36,-0.25,0.37,-0.29,0.35,-0.39,0.36,-0.4,0.42,-0.12,0.19,-0.27,0.35,-0.33,0.36,-0.37,0.32,-0.32,0.22,-0.25,0.24,-0.25,0.27,-0.21,0.21,-0.06,0.09,-0.29,0.33,-0.3,0.34,-0.31,0.34,-0.29,0.32,-0.24,0.34,-0.25,0.35,-0.23,0.32,-0.21,0.28,-0.15,0.12,-0.21,0.14,0.0,0.0,-0.09,0.15,-0.2,0.27,-0.19,0.25,-0.38,0.36,-0.23,0.32,-0.15,0.33,-0.16,0.3,-0.14,0.14,-0.23,0.34,-0.26,0.27,-0.24,0.36,-0.34,0.38,-0.29,0.38,-0.29,0.32,-0.35,0.28,-0.34,0.18,-0.28,0.28,-0.16,0.14,-0.16,0.25,-0.48,0.32,-0.47,0.33,-0.37,0.33,-0.09,0.1,-0.11,0.13,-0.21,0.32,-0.23,0.21,-0.17,0.23,-0.27,0.26,-0.25,0.21,-0.25,0.32,-0.25,0.25,-0.22,0.21,-0.25,0.27,-0.16,0.22,-0.33,0.3,-0.03,0.02,-0.36,0.34,-0.36,0.35,-0.38,0.39,-0.25,0.36,-0.28,0.25,-0.14,0.2,-0.14,0.2,-0.19,0.24,-0.02,0.02,-0.21,0.36,-0.18,0.32,-0.19,0.23,-0.38,0.36,-0.4,0.45,-0.4,0.41,-0.23,0.34,-0.43,0.4,-0.45,0.3,-0.25,0.27,-0.26,0.29,-0.16,0.14,-0.18,0.28,-0.01,0.01,-0.15,0.22,-0.25,0.28,-0.21,0.29,-0.26,0.22,-0.33,0.31,-0.27,0.23,-0.26,0.37,-0.24,0.35,-0.25,0.36,-0.25,0.35,-0.27,0.34,-0.24,0.32,-0.2,0.18,-0.18,0.16,-0.16,0.22,-0.28,0.27,-0.34,0.36,-0.34,0.36,-0.22,0.37,-0.27,0.33,-0.1,0.08,-0.22,0.27,-0.25,0.32,-0.08,0.06,-0.11,0.23,-0.2,0.25,-0.28,0.34,-0.12,0.14,-0.33,0.35,-0.33,0.29,-0.25,0.27,-0.13,0.04,-0.14,0.16,-0.13,0.14,-0.08,0.09,-0.1,0.12,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.07,-0.03,0.03,-0.08,0.08,-0.08,0.09,-0.07,0.06,-0.05,0.1,-0.08,0.08,-0.05,0.05,-0.05,0.05,-0.08,0.09,-0.03,0.05,-0.05,0.05,-0.08,0.12,-0.06,0.07,-0.03,0.03,-0.08,0.11,-0.05,0.08,-0.06,0.05,-0.07,0.12,-0.05,0.06,0.0,0.04,-0.04,0.03,-0.05,0.01,-0.05,0.01,-0.03,0.05,-0.03,0.06,0.0,0.01,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.22,0.26,-0.47,0.48,-0.48,0.5,-0.18,0.15,-0.39,0.32,-0.23,0.35,-0.17,0.31,-0.21,0.37,-0.31,0.36,-0.14,0.16,-0.22,0.36,-0.27,0.37,-0.27,0.32,-0.28,0.39,-0.29,0.42,-0.07,0.05,-0.01,0.02,-0.23,0.38,-0.31,0.36,-0.29,0.35,-0.27,0.35,-0.28,0.29,-0.31,0.29,-0.25,0.35,-0.18,0.29,-0.08,0.1,0.0,0.0,-0.04,0.09,-0.36,0.3,-0.36,0.32,-0.45,0.38,-0.45,0.29,-0.38,0.32,-0.25,0.34,-0.19,0.28,-0.12,0.14,-0.32,0.29,-0.38,0.37,-0.23,0.27,-0.23,0.36,-0.15,0.36,-0.14,0.36,-0.12,0.1,-0.17,0.3,-0.38,0.37,-0.21,0.26,-0.21,0.33,-0.17,0.3,-0.01,0.01,-0.32,0.35,-0.39,0.35,-0.27,0.32,-0.18,0.22,-0.16,0.16,-0.24,0.33,-0.27,0.32,-0.28,0.29,-0.26,0.35,-0.16,0.3,-0.18,0.11,-0.08,0.05,-0.2,0.32,-0.3,0.37,-0.34,0.37,-0.28,0.38,-0.21,0.19,-0.26,0.33,-0.32,0.25,-0.31,0.25,-0.23,0.3,-0.24,0.32,-0.48,0.36,-0.41,0.42,-0.24,0.25,-0.29,0.38,-0.31,0.38,-0.21,0.36,-0.33,0.27,-0.27,0.25,-0.1,0.15,-0.08,0.08,-0.13,0.23,-0.17,0.25,-0.16,0.2,-0.22,0.23,-0.21,0.22,-0.12,0.14,-0.15,0.1,-0.08,0.07,-0.02,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.02,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.2,0.23,-0.36,0.39,-0.34,0.4,-0.15,0.15,-0.22,0.21,-0.26,0.34,-0.36,0.4,-0.25,0.37,-0.48,0.42,-0.47,0.33,-0.38,0.35,-0.16,0.23,-0.37,0.34,-0.41,0.34,-0.21,0.23,-0.17,0.22,-0.09,0.17,-0.1,0.11,-0.18,0.33,-0.13,0.13,-0.24,0.33,-0.16,0.23,-0.23,0.21,-0.4,0.38,-0.45,0.46,-0.4,0.38,-0.23,0.32,-0.45,0.37,-0.47,0.38,-0.27,0.27,-0.48,0.35,-0.47,0.28,-0.25,0.31,-0.15,0.14,-0.11,0.11,-0.25,0.31,-0.25,0.28,-0.22,0.32,-0.26,0.28,-0.4,0.35,-0.46,0.44,-0.49,0.45,-0.47,0.39,-0.12,0.11,-0.25,0.3,-0.3,0.29,-0.21,0.25,-0.04,0.05,0.0,0.0,-0.1,0.13,-0.28,0.34,-0.3,0.3,-0.4,0.35,-0.29,0.4,-0.23,0.38,-0.15,0.18,-0.11,0.12,-0.18,0.17,-0.26,0.33,-0.37,0.36,-0.36,0.37,-0.21,0.29,-0.25,0.33,-0.18,0.24,-0.29,0.24,-0.2,0.27,-0.14,0.1,-0.29,0.28,-0.46,0.29,-0.43,0.29,-0.14,0.33,-0.1,0.1,-0.12,0.22,-0.29,0.36,-0.27,0.34,-0.09,0.19,-0.11,0.21,-0.26,0.34,-0.27,0.29,-0.27,0.28,-0.31,0.34,-0.24,0.25,-0.42,0.46,-0.4,0.46,-0.16,0.31,-0.37,0.36,-0.13,0.25,-0.08,0.07,-0.25,0.35,-0.15,0.27,-0.21,0.27,-0.52,0.37,-0.51,0.27,-0.34,0.32,-0.06,0.08,-0.06,0.06,-0.15,0.17,-0.25,0.27,-0.14,0.12,-0.38,0.25,-0.38,0.27,-0.31,0.26,-0.08,0.14,-0.12,0.12,-0.05,0.03,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,-0.01,0.0,-0.27,0.27,-0.38,0.4,-0.45,0.42,-0.08,0.1,-0.16,0.21,-0.25,0.3,-0.18,0.29,-0.22,0.21,-0.2,0.3,-0.21,0.33,-0.14,0.16,-0.12,0.14,-0.36,0.36,-0.27,0.34,-0.29,0.38,-0.14,0.2,-0.29,0.4,-0.32,0.37,-0.21,0.34,-0.24,0.38,-0.16,0.3,-0.15,0.21,-0.16,0.28,-0.27,0.26,-0.26,0.35,-0.11,0.08,-0.12,0.13,-0.24,0.41,-0.24,0.4,-0.03,0.03,-0.2,0.18,-0.21,0.4,-0.25,0.31,-0.25,0.37,-0.28,0.39,-0.32,0.36,-0.26,0.34,-0.17,0.26,-0.21,0.3,-0.18,0.24,-0.18,0.21,-0.12,0.08,-0.27,0.36,-0.25,0.32,-0.26,0.36,-0.13,0.13,-0.29,0.36,-0.18,0.23,-0.23,0.27,-0.47,0.35,-0.51,0.27,-0.37,0.34,-0.25,0.36,-0.11,0.1,-0.19,0.33,-0.18,0.17,-0.21,0.25,-0.28,0.36,-0.29,0.36,-0.08,0.08,-0.14,0.19,-0.36,0.29,-0.32,0.37,-0.25,0.26,-0.4,0.38,-0.41,0.38,-0.42,0.38,-0.09,0.08,-0.14,0.1,-0.15,0.27,-0.39,0.34,-0.21,0.28,-0.25,0.32,-0.5,0.38,-0.48,0.31,-0.25,0.35,-0.21,0.36,-0.16,0.32,-0.25,0.25,-0.27,0.27,-0.26,0.29,-0.18,0.17,-0.1,0.12,-0.17,0.28,-0.27,0.32,-0.18,0.16,-0.12,0.1,-0.32,0.33,-0.34,0.31,-0.16,0.16,-0.21,0.19,-0.11,0.16,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,-0.25,0.27,-0.24,0.32,-0.3,0.36,-0.37,0.33,-0.27,0.39,-0.29,0.39,-0.11,0.1,-0.23,0.27,-0.26,0.27,-0.25,0.33,-0.32,0.36,-0.22,0.27,-0.16,0.18,-0.27,0.34,-0.28,0.37,-0.22,0.31,-0.21,0.31,-0.15,0.16,-0.11,0.16,-0.18,0.31,-0.31,0.32,-0.27,0.3,-0.23,0.29,-0.21,0.34,-0.47,0.38,-0.42,0.39,-0.25,0.32,-0.2,0.36,-0.31,0.36,-0.3,0.34,-0.32,0.36,-0.16,0.21,-0.22,0.36,-0.34,0.18,-0.21,0.24,-0.22,0.27,-0.02,0.02,-0.42,0.36,-0.52,0.4,-0.45,0.47,-0.35,0.42,-0.18,0.37,-0.17,0.34,-0.3,0.35,-0.27,0.36,-0.32,0.33,-0.3,0.4,-0.29,0.38,-0.01,0.03,-0.22,0.25,-0.27,0.33,-0.27,0.33,-0.05,0.08,-0.18,0.2,-0.3,0.34,-0.35,0.36,-0.37,0.38,-0.09,0.08,-0.3,0.36,-0.25,0.34,-0.32,0.37,-0.35,0.37,-0.22,0.32,-0.45,0.42,-0.45,0.39,-0.44,0.34,-0.15,0.29,-0.1,0.12,-0.24,0.33,-0.34,0.34,-0.36,0.32,-0.21,0.26,-0.23,0.26,-0.32,0.32,-0.35,0.32,-0.25,0.32,-0.28,0.35,-0.16,0.17,-0.13,0.16,-0.19,0.3,-0.25,0.32,-0.2,0.18,-0.18,0.22,-0.46,0.44,-0.47,0.44,-0.42,0.41,-0.35,0.36,-0.21,0.19,-0.21,0.19,-0.09,0.1,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.03,0.05,-0.03,0.04,-0.07,0.08,-0.05,0.06,-0.05,0.05,-0.06,0.08,-0.04,0.05,-0.04,0.04,-0.07,0.08,-0.03,0.05,-0.03,0.04,-0.06,0.1,-0.05,0.05,-0.03,0.05,-0.06,0.09,-0.05,0.07,-0.03,0.04,-0.05,0.1,-0.05,0.06,-0.03,0.05,-0.01,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.02,0.01,-0.02,0.01,-0.01,0.01,-0.06,0.03,-0.32,0.3,-0.27,0.38,-0.29,0.38,-0.29,0.37,-0.37,0.37,-0.25,0.35,-0.24,0.25,-0.35,0.34,-0.35,0.37,-0.4,0.4,-0.48,0.46,-0.48,0.4,-0.22,0.32,-0.27,0.16,-0.3,0.36,-0.51,0.41,-0.45,0.43,-0.4,0.42,-0.1,0.09,-0.21,0.36,-0.24,0.36,-0.25,0.32,-0.28,0.35,-0.24,0.27,-0.12,0.11,-0.18,0.25,-0.05,0.0,-0.23,0.22,-0.24,0.41,-0.25,0.38,-0.1,0.12,-0.21,0.38,-0.23,0.34,-0.11,0.08,-0.31,0.36,-0.3,0.33,-0.33,0.34,-0.27,0.37,-0.13,0.16,-0.35,0.36,-0.37,0.33,-0.18,0.29,-0.34,0.35,-0.39,0.38,-0.45,0.4,-0.42,0.37,-0.34,0.36,-0.09,0.09,-0.18,0.25,-0.42,0.36,-0.36,0.36,-0.3,0.35,-0.38,0.38,-0.23,0.25,-0.39,0.44,-0.44,0.41,-0.45,0.36,-0.32,0.33,-0.12,0.12,-0.23,0.35,-0.34,0.38,-0.43,0.37,-0.42,0.3,-0.16,0.25,-0.21,0.29,-0.34,0.34,-0.4,0.35,-0.23,0.28,-0.26,0.38,-0.16,0.3,-0.14,0.12,-0.12,0.11,-0.17,0.22,-0.28,0.33,-0.23,0.21,-0.27,0.29,-0.25,0.28,-0.25,0.34,-0.19,0.25,-0.32,0.32,-0.35,0.34,-0.13,0.15,0.0,0.0,-0.43,0.44,-0.42,0.42,-0.15,0.14,-0.15,0.15,-0.31,0.25,-0.19,0.32,-0.31,0.29,-0.25,0.32,-0.26,0.31,-0.24,0.26,-0.1,0.09,-0.25,0.33,-0.23,0.26,-0.23,0.38,-0.14,0.23,-0.15,0.16,-0.23,0.34,-0.23,0.34,-0.33,0.33,-0.32,0.27,-0.22,0.37,-0.29,0.39,-0.27,0.27,-0.21,0.27,-0.21,0.27,-0.36,0.36,-0.49,0.4,-0.47,0.42,-0.19,0.16,-0.35,0.32,-0.3,0.27,-0.19,0.23,-0.08,0.08,-0.37,0.34,-0.41,0.36,-0.3,0.26,-0.26,0.25,-0.29,0.27,-0.35,0.28,-0.23,0.37,-0.2,0.32,-0.16,0.19,-0.22,0.32,-0.16,0.25,-0.04,0.06,-0.01,0.01,-0.2,0.28,-0.25,0.25,-0.25,0.32,-0.21,0.34,-0.09,0.17,-0.2,0.23,-0.34,0.36,-0.24,0.22,-0.18,0.33,-0.22,0.33,-0.23,0.25,-0.24,0.34,-0.29,0.39,-0.21,0.32,-0.21,0.26,-0.29,0.28,-0.38,0.31,-0.23,0.25,-0.08,0.08,-0.22,0.23,-0.27,0.28,-0.3,0.33,-0.29,0.3,-0.31,0.35,-0.36,0.34,-0.38,0.34,-0.32,0.29,-0.05,0.06,-0.1,0.1,-0.2,0.28,-0.25,0.28,-0.09,0.1,-0.04,0.05,-0.18,0.25,-0.23,0.27,-0.03,0.05,-0.14,0.13,-0.47,0.35,-0.48,0.34,-0.29,0.37,-0.22,0.25,-0.09,0.11,-0.3,0.36,-0.43,0.49,-0.38,0.38,-0.2,0.34,-0.16,0.13,-0.2,0.25,-0.18,0.27,-0.21,0.14,-0.29,0.34,-0.24,0.32,-0.34,0.34,-0.27,0.35,-0.3,0.3,-0.4,0.38,-0.3,0.4,-0.13,0.16,-0.15,0.23,-0.29,0.37,-0.16,0.33,-0.08,0.08,-0.1,0.12,-0.23,0.32,-0.21,0.26,-0.27,0.27,-0.25,0.32,-0.21,0.3,-0.37,0.34,-0.1,0.15,-0.16,0.16,-0.17,0.33,-0.14,0.29,-0.26,0.36,-0.23,0.36,-0.1,0.1,-0.18,0.29,-0.16,0.16,-0.27,0.25,-0.29,0.33,-0.23,0.3,-0.29,0.33,-0.12,0.12,-0.27,0.39,-0.28,0.39,-0.18,0.21,-0.05,0.05,-0.16,0.26,-0.23,0.3,-0.2,0.35,-0.26,0.29,-0.33,0.28,-0.05,0.05,-0.44,0.35,-0.47,0.32,-0.4,0.34,-0.16,0.25,-0.04,0.03,-0.26,0.35,-0.26,0.36,-0.21,0.3,-0.14,0.16,-0.14,0.12,-0.14,0.21,-0.27,0.27,-0.27,0.27,-0.21,0.31,-0.29,0.36,-0.21,0.38,-0.16,0.16,-0.16,0.21,-0.29,0.34,-0.34,0.37,-0.1,0.16,-0.21,0.25,-0.13,0.21,-0.22,0.38,-0.17,0.38,-0.22,0.14,-0.08,0.07,-0.23,0.33,-0.2,0.32,-0.12,0.12,-0.1,0.17,-0.38,0.25,-0.4,0.19,-0.26,0.21,-0.14,0.2,-0.1,0.08,-0.12,0.19,-0.11,0.16,-0.01,0.01,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.09,0.08,-0.04,0.07,-0.04,0.03,-0.09,0.05,-0.08,0.1,-0.08,0.07,-0.03,0.03,-0.08,0.11,-0.05,0.05,-0.06,0.06,-0.09,0.1,-0.03,0.05,-0.06,0.06,-0.09,0.14,-0.08,0.08,-0.03,0.04,-0.08,0.12,-0.06,0.09,-0.07,0.06,-0.08,0.14,-0.07,0.07,-0.01,0.04,-0.05,0.03,-0.05,0.02,-0.05,0.01,-0.04,0.05,-0.03,0.07,0.0,0.01,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.3,0.34,-0.33,0.39,-0.27,0.27,-0.14,0.15,-0.31,0.35,-0.32,0.33,-0.35,0.36,-0.13,0.19,-0.3,0.35,-0.28,0.32,-0.24,0.32,-0.16,0.31,-0.21,0.42,-0.14,0.33,-0.36,0.38,-0.4,0.36,-0.32,0.32,-0.01,0.0,-0.23,0.24,-0.49,0.36,-0.51,0.42,-0.44,0.4,-0.18,0.21,-0.23,0.34,-0.28,0.38,-0.19,0.29,-0.12,0.1,-0.21,0.33,-0.18,0.34,-0.15,0.29,-0.17,0.25,-0.12,0.18,-0.18,0.27,-0.21,0.27,-0.18,0.17,-0.21,0.22,-0.39,0.4,-0.24,0.32,-0.35,0.27,-0.33,0.21,-0.27,0.25,-0.29,0.27,-0.17,0.14,-0.17,0.24,-0.33,0.39,-0.23,0.4,-0.33,0.28,-0.11,0.11,-0.22,0.36,-0.19,0.3,-0.12,0.12,-0.18,0.24,-0.02,0.04,-0.12,0.11,-0.49,0.36,-0.5,0.31,-0.44,0.35,-0.25,0.16,-0.11,0.08,-0.12,0.22,-0.25,0.28,-0.25,0.29,-0.18,0.32,-0.08,0.09,-0.21,0.27,-0.25,0.3,-0.29,0.36,-0.2,0.3,-0.18,0.24,-0.1,0.18,-0.32,0.34,-0.21,0.34,-0.19,0.33,-0.2,0.25,-0.12,0.11,-0.34,0.36,-0.37,0.32,-0.27,0.33,-0.25,0.3,-0.22,0.34,-0.21,0.33,-0.12,0.18,0.0,0.01,-0.14,0.26,-0.24,0.34,-0.32,0.34,-0.33,0.34,-0.45,0.45,-0.36,0.4,-0.21,0.38,-0.25,0.39,-0.17,0.27,-0.23,0.4,-0.24,0.4,-0.12,0.13,-0.29,0.29,-0.15,0.16,-0.19,0.17,-0.21,0.3,-0.24,0.21,-0.38,0.34,-0.43,0.37,-0.48,0.32,-0.39,0.39,-0.27,0.37,-0.08,0.07,-0.24,0.32,-0.24,0.28,-0.25,0.27,-0.1,0.18,-0.23,0.28,-0.22,0.29,-0.22,0.29,-0.41,0.4,-0.35,0.36,-0.12,0.12,-0.17,0.26,-0.18,0.19,-0.16,0.12,-0.19,0.15,-0.08,0.07,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.26,0.34,-0.34,0.37,-0.36,0.39,-0.29,0.29,-0.33,0.36,-0.24,0.38,-0.24,0.31,-0.3,0.36,-0.12,0.13,-0.19,0.25,-0.27,0.27,-0.28,0.29,-0.24,0.35,-0.29,0.37,-0.23,0.38,-0.18,0.23,-0.21,0.15,-0.01,0.01,-0.13,0.14,-0.32,0.3,-0.32,0.34,-0.19,0.31,-0.25,0.37,-0.21,0.27,-0.25,0.26,-0.27,0.36,-0.17,0.12,-0.21,0.21,-0.25,0.33,-0.23,0.33,-0.29,0.38,-0.22,0.38,-0.08,0.08,-0.01,0.01,-0.18,0.27,-0.26,0.31,-0.15,0.16,-0.31,0.36,-0.29,0.36,-0.29,0.33,-0.16,0.25,-0.14,0.32,-0.12,0.16,-0.18,0.19,-0.26,0.32,-0.26,0.25,-0.09,0.08,-0.12,0.2,-0.13,0.13,-0.2,0.25,-0.06,0.08,-0.22,0.27,-0.21,0.26,-0.05,0.06,-0.11,0.18,-0.14,0.17,-0.09,0.12,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.1,0.08,-0.25,0.31,-0.27,0.42,-0.25,0.39,-0.08,0.02,-0.12,0.15,-0.25,0.27,-0.21,0.27,-0.07,0.05,-0.21,0.32,-0.45,0.45,-0.18,0.21,-0.17,0.14,-0.35,0.35,-0.36,0.34,-0.21,0.26,-0.1,0.09,-0.3,0.34,-0.23,0.31,-0.21,0.33,-0.11,0.2,-0.11,0.12,-0.31,0.3,-0.35,0.39,-0.31,0.35,-0.24,0.38,-0.22,0.38,-0.12,0.12,-0.24,0.39,-0.4,0.37,-0.4,0.32,-0.34,0.34,-0.16,0.14,-0.14,0.14,-0.21,0.3,-0.45,0.34,-0.42,0.28,-0.16,0.33,-0.09,0.1,-0.11,0.12,-0.38,0.34,-0.34,0.37,-0.23,0.27,-0.2,0.39,-0.18,0.38,-0.17,0.38,-0.12,0.1,-0.18,0.33,-0.37,0.36,-0.36,0.31,-0.29,0.31,-0.14,0.14,-0.06,0.07,-0.14,0.18,-0.21,0.23,-0.08,0.09,-0.13,0.12,-0.45,0.5,-0.38,0.46,-0.34,0.31,-0.16,0.11,-0.22,0.28,-0.12,0.24,-0.18,0.24,-0.16,0.27,-0.14,0.14,-0.21,0.27,-0.24,0.32,-0.25,0.33,-0.05,0.06,-0.21,0.28,-0.26,0.27,-0.26,0.2,-0.17,0.16,-0.16,0.17,-0.15,0.18,-0.1,0.1,0.0,0.0,-0.01,0.01,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.05,-0.05,0.05,-0.08,0.09,-0.07,0.07,-0.05,0.05,-0.07,0.1,-0.04,0.05,-0.05,0.05,-0.08,0.08,-0.04,0.06,-0.04,0.05,-0.07,0.12,-0.06,0.06,-0.03,0.05,-0.07,0.1,-0.05,0.08,-0.04,0.05,-0.06,0.11,-0.05,0.06,-0.03,0.05,-0.01,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.02,0.01,-0.03,0.01,-0.01,0.01,0.0,0.01,-0.2,0.24,-0.42,0.39,-0.4,0.39,-0.29,0.36,-0.49,0.4,-0.51,0.49,-0.5,0.44,-0.37,0.36,-0.32,0.3,-0.02,0.03,-0.26,0.33,-0.28,0.33,-0.11,0.14,-0.18,0.25,-0.18,0.29,-0.23,0.14,-0.23,0.23,-0.25,0.26,-0.16,0.16,-0.11,0.1,-0.22,0.25,-0.21,0.27,-0.08,0.15,-0.22,0.25,-0.31,0.35,-0.34,0.35,-0.15,0.14,-0.19,0.35,-0.18,0.34,-0.23,0.34,-0.26,0.37,-0.12,0.12,-0.19,0.21,-0.23,0.37,-0.23,0.33,-0.1,0.1,-0.23,0.23,-0.48,0.38,-0.52,0.3,-0.36,0.37,-0.26,0.32,-0.34,0.29,-0.21,0.34,-0.27,0.34,-0.23,0.26,-0.4,0.38,-0.38,0.4,-0.09,0.09,-0.32,0.33,-0.39,0.34,-0.39,0.33,-0.23,0.17,-0.09,0.1,-0.16,0.25,-0.28,0.3,-0.02,0.01,-0.13,0.12,-0.25,0.27,-0.17,0.26,-0.32,0.29,-0.26,0.33,-0.08,0.09,-0.14,0.18,-0.21,0.27,-0.19,0.23,-0.25,0.23,-0.44,0.47,-0.45,0.45,-0.19,0.27,-0.23,0.16,-0.23,0.37,-0.34,0.37,-0.28,0.36,-0.08,0.08,-0.14,0.15,-0.08,0.15,-0.23,0.25,-0.21,0.23,-0.4,0.35,-0.37,0.35,-0.21,0.19,-0.1,0.14,-0.25,0.3,-0.32,0.27,-0.33,0.32,-0.25,0.35,-0.25,0.34,-0.27,0.37,-0.1,0.08,-0.1,0.18,-0.25,0.29,-0.35,0.32,-0.32,0.27,-0.22,0.32,-0.17,0.26,-0.16,0.29,-0.18,0.3,-0.19,0.16,-0.29,0.18,-0.37,0.32,-0.38,0.29,-0.34,0.27,-0.25,0.21,-0.09,0.1,-0.1,0.06,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.09,0.08,-0.27,0.42,-0.26,0.4,-0.22,0.21,-0.12,0.12,-0.23,0.41,-0.32,0.4,-0.23,0.39,-0.21,0.37,-0.22,0.35,-0.51,0.38,-0.47,0.29,-0.16,0.34,-0.16,0.35,-0.1,0.11,-0.19,0.27,-0.21,0.28,-0.13,0.13,-0.27,0.36,-0.25,0.32,-0.22,0.34,-0.23,0.29,-0.28,0.35,-0.23,0.34,-0.25,0.25,-0.18,0.27,-0.3,0.34,-0.37,0.36,-0.33,0.31,-0.24,0.29,-0.28,0.39,-0.17,0.35,-0.26,0.22,-0.3,0.3,-0.22,0.21,-0.27,0.27,-0.27,0.26,-0.24,0.3,-0.17,0.32,-0.24,0.33,-0.27,0.16,-0.25,0.25,-0.49,0.42,-0.46,0.42,-0.41,0.33,-0.05,0.04,-0.27,0.27,-0.27,0.32,-0.26,0.29,-0.15,0.16,-0.15,0.15,-0.14,0.25,-0.26,0.29,-0.25,0.34,-0.33,0.36,-0.23,0.3,-0.32,0.25,-0.23,0.37,-0.44,0.37,-0.28,0.32,-0.21,0.27,-0.29,0.37,-0.14,0.16,-0.29,0.38,-0.29,0.4,-0.2,0.23,-0.12,0.14,-0.18,0.27,-0.18,0.32,-0.18,0.3,-0.23,0.27,-0.28,0.23,-0.14,0.18,-0.21,0.23,-0.28,0.23,-0.27,0.25,-0.14,0.09,-0.14,0.1,-0.05,0.04,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.06,-0.04,0.05,-0.08,0.09,-0.06,0.08,-0.07,0.05,-0.07,0.1,-0.05,0.05,-0.05,0.05,-0.08,0.09,-0.04,0.06,-0.04,0.05,-0.08,0.12,-0.08,0.06,-0.04,0.06,-0.08,0.11,-0.07,0.08,-0.04,0.04,-0.07,0.12,-0.06,0.07,-0.04,0.06,-0.01,0.04,-0.05,0.02,-0.05,0.01,-0.04,0.03,-0.03,0.05,-0.03,0.06,-0.03,0.01,-0.03,0.01,-0.01,0.01,-0.03,0.04,-0.21,0.38,-0.29,0.37,-0.09,0.09,-0.16,0.16,-0.42,0.38,-0.56,0.34,-0.49,0.4,-0.33,0.42,-0.22,0.42,-0.29,0.42,-0.27,0.17,-0.22,0.29,-0.2,0.29,-0.1,0.09,-0.2,0.3,-0.18,0.26,-0.4,0.38,-0.39,0.37,-0.21,0.18,-0.13,0.16,-0.16,0.22,-0.22,0.19,-0.25,0.27,-0.21,0.32,-0.26,0.29,-0.26,0.33,-0.35,0.36,-0.34,0.36,-0.29,0.36,-0.25,0.35,-0.27,0.34,-0.03,0.04,-0.26,0.32,-0.31,0.39,-0.23,0.33,-0.06,0.02,-0.01,0.01,-0.05,0.04,-0.07,0.09,-0.27,0.32,-0.24,0.29,-0.29,0.28,-0.22,0.24,-0.28,0.33,-0.25,0.28,-0.22,0.32,-0.14,0.32,-0.19,0.4,-0.13,0.24,-0.09,0.08,-0.22,0.27,-0.26,0.32,-0.38,0.35,-0.36,0.28,-0.19,0.31,-0.16,0.24,-0.14,0.18,-0.23,0.35,-0.3,0.4,-0.14,0.13,-0.29,0.24,-0.25,0.29,-0.25,0.33,-0.38,0.42,-0.4,0.34,-0.37,0.37,-0.09,0.08,-0.29,0.31,-0.27,0.29,-0.24,0.25,-0.26,0.38,-0.29,0.38,-0.23,0.27,-0.16,0.14,-0.1,0.12,-0.26,0.36,-0.26,0.34,-0.24,0.36,-0.18,0.35,-0.12,0.14,-0.08,0.11,-0.13,0.2,-0.08,0.06,-0.04,0.05,-0.21,0.25,-0.23,0.27,-0.11,0.12,-0.27,0.35,-0.26,0.29,-0.21,0.37,-0.23,0.3,-0.28,0.37,-0.21,0.36,-0.18,0.24,-0.18,0.17,-0.32,0.37,-0.29,0.3,-0.15,0.16,-0.19,0.07,-0.42,0.36,-0.53,0.27,-0.42,0.36,-0.25,0.37,-0.34,0.33,-0.19,0.32,-0.24,0.21,-0.19,0.19,-0.13,0.2,-0.2,0.23,-0.08,0.04,-0.38,0.39,-0.42,0.36,-0.18,0.31,-0.16,0.16,-0.23,0.31,-0.36,0.35,-0.33,0.35,-0.14,0.19,-0.13,0.29,-0.22,0.31,-0.23,0.21,-0.28,0.24,-0.29,0.29,-0.36,0.21,-0.32,0.18,-0.14,0.17,-0.12,0.09,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.02,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.19,0.21,-0.32,0.36,-0.23,0.3,-0.16,0.13,-0.27,0.39,-0.28,0.36,-0.16,0.16,-0.23,0.25,-0.15,0.16,-0.3,0.39,-0.29,0.39,-0.16,0.12,-0.12,0.16,-0.25,0.36,-0.21,0.38,-0.23,0.36,-0.34,0.26,-0.08,0.16,-0.32,0.35,-0.31,0.36,-0.1,0.14,-0.16,0.17,-0.36,0.35,-0.32,0.33,-0.32,0.31,-0.1,0.12,-0.06,0.12,-0.23,0.32,-0.25,0.34,-0.21,0.31,-0.49,0.36,-0.5,0.31,-0.45,0.28,-0.28,0.36,-0.23,0.34,-0.16,0.3,-0.09,0.1,-0.2,0.32,-0.21,0.3,-0.26,0.38,-0.22,0.34,-0.08,0.08,-0.24,0.26,-0.23,0.36,-0.26,0.36,-0.25,0.34,-0.25,0.35,-0.23,0.34,-0.14,0.14,-0.07,0.13,-0.29,0.31,-0.19,0.19,-0.25,0.27,-0.3,0.3,-0.27,0.34,-0.31,0.34,-0.05,0.03,-0.25,0.35,-0.32,0.37,-0.33,0.34,-0.35,0.35,-0.24,0.29,-0.03,0.04,-0.14,0.16,-0.16,0.22,-0.1,0.08,-0.16,0.13,-0.19,0.22,-0.37,0.31,-0.31,0.29,-0.11,0.15,-0.34,0.3,-0.25,0.27,-0.2,0.29,-0.25,0.35,-0.22,0.29,-0.25,0.33,-0.19,0.2,0.0,0.01,-0.03,0.04,-0.15,0.16,-0.24,0.36,-0.13,0.21,-0.15,0.22,-0.29,0.39,-0.29,0.3,-0.21,0.33,-0.18,0.14,-0.18,0.31,-0.22,0.27,-0.26,0.25,-0.1,0.12,-0.16,0.22,-0.24,0.29,-0.32,0.24,-0.14,0.23,-0.27,0.29,-0.24,0.27,-0.25,0.32,-0.14,0.22,-0.33,0.34,-0.31,0.29,-0.12,0.12,0.0,0.01,-0.19,0.21,-0.27,0.28,-0.26,0.25,-0.46,0.35,-0.42,0.27,-0.22,0.14,-0.39,0.42,-0.47,0.46,-0.35,0.36,-0.16,0.23,-0.14,0.16,-0.23,0.34,-0.19,0.29,-0.21,0.24,-0.36,0.3,-0.08,0.07,-0.24,0.32,-0.3,0.33,-0.29,0.29,-0.05,0.08,-0.23,0.25,-0.25,0.33,-0.25,0.34,-0.17,0.33,-0.49,0.36,-0.51,0.29,-0.41,0.27,-0.28,0.33,-0.21,0.32,-0.13,0.28,-0.11,0.08,-0.22,0.34,-0.22,0.34,-0.12,0.08,-0.34,0.38,-0.28,0.39,-0.18,0.16,-0.04,0.07,-0.18,0.33,-0.28,0.37,-0.28,0.38,-0.17,0.36,-0.12,0.16,-0.08,0.09,-0.12,0.18,-0.1,0.09,-0.18,0.21,-0.23,0.24,-0.29,0.33,-0.26,0.29,-0.14,0.16,-0.31,0.32,-0.29,0.32,-0.21,0.26,-0.22,0.37,-0.29,0.25,-0.26,0.21,-0.34,0.36,-0.34,0.35,-0.1,0.1,-0.2,0.18,-0.14,0.17,-0.23,0.33,-0.23,0.33,-0.14,0.14,-0.17,0.14,-0.29,0.29,-0.27,0.22,-0.1,0.15,-0.15,0.18,-0.1,0.14,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,-0.02,0.01,-0.25,0.27,-0.4,0.4,-0.42,0.4,-0.1,0.12,-0.14,0.12,-0.25,0.28,-0.32,0.33,-0.01,0.02,-0.09,0.03,-0.02,0.01,-0.09,0.08,-0.28,0.37,-0.27,0.4,-0.07,0.08,-0.14,0.14,-0.27,0.36,-0.36,0.37,-0.24,0.34,-0.15,0.14,-0.18,0.34,-0.4,0.4,-0.41,0.35,-0.31,0.33,-0.28,0.38,-0.28,0.34,-0.27,0.32,-0.14,0.33,-0.18,0.33,-0.1,0.08,-0.26,0.38,-0.31,0.36,-0.27,0.32,-0.29,0.35,-0.29,0.31,-0.18,0.18,-0.44,0.41,-0.45,0.41,-0.36,0.31,-0.14,0.29,-0.22,0.36,-0.25,0.33,-0.33,0.29,-0.25,0.28,-0.16,0.2,-0.12,0.29,-0.29,0.35,-0.25,0.29,-0.26,0.27,-0.29,0.32,-0.32,0.36,-0.29,0.34,-0.26,0.27,-0.2,0.18,-0.3,0.29,-0.24,0.23,-0.13,0.12,-0.1,0.17,-0.03,0.03,-0.17,0.25,-0.21,0.28,-0.21,0.27,-0.27,0.39,-0.22,0.37,-0.32,0.39,-0.2,0.25,-0.17,0.36,-0.14,0.18,-0.07,0.08,-0.21,0.22,-0.29,0.33,-0.23,0.29,-0.29,0.28,-0.08,0.08,-0.37,0.35,-0.38,0.32,-0.41,0.49,-0.36,0.5,-0.3,0.31,-0.25,0.32,-0.2,0.32,-0.21,0.31,-0.21,0.35,-0.17,0.29,-0.16,0.23,-0.23,0.31,-0.32,0.34,-0.4,0.3,-0.21,0.28,-0.11,0.14,-0.2,0.37,-0.25,0.41,-0.05,0.07,-0.14,0.12,-0.21,0.36,-0.21,0.32,-0.25,0.27,-0.21,0.29,-0.23,0.27,-0.15,0.13,-0.18,0.24,-0.33,0.29,-0.36,0.34,-0.14,0.13,-0.2,0.23,-0.21,0.24,-0.21,0.21,-0.16,0.19,-0.16,0.18,-0.1,0.12,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.07,-0.04,0.04,-0.08,0.09,-0.06,0.08,-0.07,0.05,-0.07,0.1,-0.05,0.07,-0.03,0.05,-0.08,0.08,-0.04,0.06,-0.03,0.05,-0.07,0.12,-0.07,0.06,-0.04,0.05,-0.07,0.1,-0.06,0.08,-0.04,0.03,-0.06,0.1,-0.05,0.06,-0.03,0.05,-0.01,0.03,-0.04,0.02,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.01,0.0,-0.02,0.01,-0.01,0.01,-0.01,0.01,-0.15,0.18,-0.31,0.4,-0.31,0.31,-0.31,0.3,-0.3,0.4,-0.27,0.4,-0.24,0.32,-0.29,0.42,-0.27,0.4,-0.39,0.28,-0.24,0.33,-0.14,0.14,-0.19,0.28,-0.52,0.37,-0.52,0.29,-0.34,0.36,-0.04,0.03,-0.17,0.23,-0.25,0.34,-0.28,0.31,-0.26,0.37,-0.4,0.4,-0.08,0.12,-0.12,0.12,-0.38,0.38,-0.43,0.36,-0.43,0.35,-0.29,0.29,-0.13,0.15,-0.24,0.38,-0.21,0.34,-0.35,0.31,-0.41,0.41,-0.41,0.34,-0.21,0.36,-0.09,0.09,-0.47,0.38,-0.47,0.47,-0.47,0.42,-0.09,0.08,-0.15,0.13,-0.17,0.16,-0.26,0.3,-0.12,0.12,-0.19,0.17,-0.32,0.33,-0.34,0.38,-0.31,0.38,-0.11,0.12,-0.32,0.36,-0.36,0.36,-0.19,0.17,-0.2,0.24,-0.21,0.3,-0.36,0.26,-0.32,0.3,-0.21,0.23,-0.4,0.36,-0.43,0.36,-0.25,0.32,-0.36,0.34,-0.27,0.29,-0.22,0.27,-0.03,0.04,-0.01,0.01,-0.23,0.25,-0.3,0.36,-0.24,0.29,-0.31,0.36,-0.2,0.27,-0.25,0.31,-0.18,0.31,-0.14,0.23,-0.4,0.36,-0.42,0.32,-0.21,0.27,-0.21,0.27,-0.1,0.09,-0.26,0.29,-0.35,0.33,-0.4,0.36,-0.21,0.36,-0.15,0.17,-0.18,0.36,-0.16,0.27,-0.27,0.38,-0.21,0.37,-0.08,0.12,-0.15,0.23,-0.28,0.32,-0.45,0.32,-0.42,0.3,-0.29,0.34,-0.24,0.32,-0.1,0.14,-0.29,0.24,-0.47,0.46,-0.48,0.44,-0.17,0.29,-0.1,0.11,-0.18,0.27,-0.17,0.28,-0.24,0.25,-0.28,0.24,-0.16,0.25,-0.18,0.27,-0.09,0.09,-0.18,0.33,-0.32,0.36,-0.29,0.26,-0.33,0.27,-0.15,0.25,-0.23,0.33,-0.24,0.25,-0.14,0.12,-0.26,0.35,-0.49,0.36,-0.51,0.42,-0.45,0.42,-0.33,0.25,-0.21,0.32,-0.22,0.29,-0.08,0.14,0.0,0.0,-0.03,0.02,-0.19,0.32,-0.21,0.34,-0.11,0.1,-0.16,0.33,-0.32,0.35,-0.25,0.27,-0.38,0.34,-0.39,0.27,-0.26,0.29,-0.27,0.29,-0.36,0.36,-0.41,0.41,-0.18,0.34,-0.28,0.3,-0.29,0.34,-0.31,0.33,-0.31,0.3,-0.1,0.16,-0.02,0.01,-0.13,0.13,-0.21,0.29,-0.19,0.3,-0.16,0.16,-0.27,0.27,-0.34,0.36,-0.38,0.38,-0.23,0.36,-0.28,0.38,-0.36,0.38,-0.25,0.31,-0.29,0.32,-0.37,0.49,-0.45,0.47,-0.4,0.36,-0.21,0.32,-0.09,0.1,-0.1,0.1,-0.03,0.03,-0.01,0.0,-0.25,0.24,-0.34,0.32,-0.08,0.09,-0.26,0.26,-0.42,0.4,-0.23,0.28,-0.23,0.32,-0.22,0.39,-0.37,0.38,-0.33,0.38,-0.23,0.28,-0.44,0.43,-0.45,0.36,-0.45,0.36,-0.31,0.35,-0.09,0.1,-0.27,0.34,-0.38,0.35,-0.4,0.32,-0.36,0.33,-0.18,0.24,-0.25,0.29,-0.4,0.35,-0.4,0.35,-0.25,0.36,-0.2,0.37,-0.16,0.18,-0.22,0.23,-0.07,0.05,-0.25,0.28,-0.23,0.26,-0.24,0.31,-0.25,0.34,-0.23,0.29,-0.25,0.31,-0.11,0.1,-0.08,0.16,-0.25,0.36,-0.23,0.27,-0.29,0.33,-0.35,0.28,-0.21,0.27,-0.2,0.25,-0.08,0.08,-0.49,0.42,-0.48,0.42,-0.48,0.38,-0.03,0.03,-0.21,0.23,-0.25,0.29,-0.23,0.31,-0.16,0.18,-0.11,0.11,-0.05,0.05,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.05,-0.04,0.04,-0.08,0.08,-0.06,0.07,-0.06,0.05,-0.06,0.09,-0.05,0.05,-0.04,0.04,-0.07,0.08,-0.04,0.05,-0.03,0.04,-0.07,0.11,-0.05,0.05,-0.03,0.05,-0.06,0.1,-0.06,0.07,-0.04,0.03,-0.06,0.1,-0.05,0.06,-0.03,0.05,-0.01,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.02,0.01,-0.02,0.01,-0.01,0.01,-0.01,0.03,-0.06,0.06,-0.25,0.36,-0.32,0.42,-0.29,0.4,-0.27,0.36,-0.23,0.29,-0.39,0.4,-0.4,0.4,-0.21,0.38,-0.27,0.3,-0.38,0.36,-0.25,0.4,-0.27,0.34,-0.27,0.34,-0.3,0.39,-0.28,0.36,-0.19,0.27,-0.16,0.34,-0.23,0.37,-0.23,0.35,-0.26,0.37,-0.25,0.36,-0.38,0.34,-0.29,0.34,-0.16,0.16,-0.44,0.26,-0.49,0.36,-0.35,0.4,-0.31,0.29,-0.3,0.28,-0.16,0.25,-0.4,0.38,-0.38,0.36,-0.25,0.3,-0.27,0.3,-0.43,0.39,-0.41,0.34,-0.21,0.36,-0.08,0.08,-0.23,0.31,-0.25,0.3,-0.25,0.33,-0.22,0.32,-0.14,0.16,-0.18,0.19,-0.27,0.4,-0.25,0.35,-0.03,0.02,-0.2,0.38,-0.27,0.36,-0.29,0.33,-0.2,0.28,-0.26,0.27,-0.13,0.14,-0.2,0.27,-0.25,0.26,-0.3,0.33,-0.17,0.28,-0.14,0.21,-0.26,0.27,-0.27,0.37,-0.24,0.36,-0.26,0.29,-0.23,0.27,-0.27,0.32,-0.38,0.37,-0.35,0.33,-0.29,0.38,-0.24,0.38,-0.15,0.13,-0.18,0.21,-0.32,0.31,-0.29,0.27,-0.24,0.24,-0.27,0.28,-0.21,0.25,-0.02,0.03,-0.03,0.05,-0.25,0.29,-0.29,0.34,-0.21,0.36,-0.29,0.37,-0.15,0.23,-0.23,0.29,-0.29,0.21,-0.18,0.21,-0.25,0.28,-0.29,0.38,-0.23,0.32,-0.16,0.28,-0.25,0.26,-0.31,0.32,-0.21,0.29,-0.25,0.39,-0.32,0.35,-0.22,0.36,-0.32,0.24,-0.21,0.38,-0.32,0.37,-0.32,0.33,-0.21,0.27,0.0,0.0,-0.01,0.01,-0.39,0.31,-0.38,0.32,-0.18,0.28,-0.24,0.36,-0.27,0.29,-0.25,0.33,-0.32,0.36,-0.31,0.39,-0.26,0.3,-0.35,0.38,-0.23,0.23,-0.14,0.26,-0.1,0.13,-0.21,0.29,-0.27,0.34,-0.29,0.32,-0.42,0.49,-0.44,0.43,-0.3,0.36,-0.21,0.25,-0.23,0.27,-0.4,0.39,-0.37,0.36,-0.2,0.25,-0.21,0.32,-0.19,0.29,-0.25,0.23,0.0,0.01,-0.33,0.34,-0.34,0.33,-0.18,0.13,-0.1,0.1,-0.14,0.21,-0.22,0.27,-0.29,0.27,-0.24,0.27,-0.24,0.29,-0.29,0.29,-0.17,0.18,-0.05,0.04,-0.05,0.05,-0.26,0.36,-0.23,0.33,-0.25,0.31,-0.29,0.36,-0.27,0.29,-0.31,0.31,-0.32,0.34,-0.12,0.16,-0.4,0.43,-0.25,0.4,-0.39,0.42,-0.42,0.38,-0.25,0.31,-0.07,0.06,-0.36,0.36,-0.36,0.22,-0.4,0.28,-0.47,0.3,-0.36,0.38,-0.15,0.31,-0.31,0.23,-0.16,0.27,-0.3,0.28,-0.44,0.37,-0.45,0.39,-0.38,0.38,-0.32,0.26,-0.05,0.07,0.0,0.0,-0.13,0.21,-0.28,0.29,-0.21,0.23,-0.18,0.26,-0.27,0.28,-0.24,0.31,-0.21,0.3,0.0,0.0,-0.21,0.29,-0.42,0.36,-0.36,0.35,-0.18,0.22,-0.12,0.11,-0.25,0.32,-0.31,0.36,-0.35,0.35,-0.34,0.32,-0.15,0.21,-0.14,0.18,-0.17,0.27,-0.14,0.22,-0.08,0.13,-0.15,0.24,-0.2,0.25,-0.27,0.36,-0.29,0.32,-0.28,0.38,-0.25,0.39,-0.27,0.28,-0.33,0.32,-0.19,0.27,-0.33,0.33,-0.41,0.34,-0.28,0.21,-0.46,0.29,-0.44,0.4,-0.32,0.37,-0.31,0.24,-0.17,0.27,-0.27,0.29,-0.45,0.41,-0.43,0.4,-0.42,0.32,-0.09,0.1,-0.21,0.29,-0.24,0.29,-0.24,0.3,-0.18,0.28,-0.18,0.28,-0.3,0.38,-0.36,0.32,-0.28,0.36,-0.03,0.05,-0.16,0.34,-0.14,0.32,-0.16,0.2,-0.28,0.31,-0.21,0.22,0.0,0.0,-0.21,0.25,-0.16,0.28,-0.16,0.16,-0.2,0.25,-0.38,0.38,-0.25,0.33,-0.23,0.35,-0.21,0.34,-0.28,0.27,-0.05,0.05,-0.15,0.29,-0.37,0.33,-0.17,0.29,-0.28,0.21,-0.18,0.28,-0.29,0.34,-0.28,0.32,-0.21,0.29,-0.31,0.29,-0.25,0.21,-0.49,0.36,-0.5,0.28,-0.34,0.33,-0.08,0.06,-0.27,0.16,-0.17,0.16,-0.08,0.07,-0.27,0.31,-0.32,0.35,-0.08,0.06,-0.17,0.23,-0.18,0.23,-0.29,0.35,-0.34,0.34,-0.32,0.38,-0.27,0.32,-0.27,0.4,-0.26,0.32,-0.31,0.36,-0.28,0.27,-0.27,0.37,-0.27,0.36,-0.07,0.08,-0.21,0.27,-0.23,0.29,-0.27,0.32,-0.34,0.38,-0.32,0.35,-0.21,0.26,-0.19,0.22,-0.25,0.25,-0.23,0.3,-0.21,0.23,-0.21,0.21,-0.31,0.27,-0.25,0.31,-0.31,0.38,-0.47,0.36,-0.44,0.42,-0.25,0.26,-0.16,0.24,-0.28,0.36,-0.27,0.37,-0.12,0.11,-0.07,0.08,-0.27,0.29,-0.34,0.35,-0.38,0.38,-0.33,0.27,-0.23,0.24,-0.2,0.27,-0.1,0.1,-0.11,0.11,-0.01,0.03,-0.02,0.01,-0.29,0.29,-0.34,0.38,-0.23,0.31,-0.29,0.38,-0.23,0.35,-0.16,0.18,-0.26,0.36,-0.27,0.31,-0.3,0.3,-0.23,0.2,-0.34,0.42,-0.32,0.38,-0.18,0.25,-0.14,0.14,-0.31,0.29,-0.4,0.36,-0.29,0.18,-0.12,0.12,-0.29,0.35,-0.14,0.13,-0.44,0.28,-0.45,0.38,-0.36,0.39,-0.25,0.24,-0.23,0.28,-0.16,0.25,-0.45,0.35,-0.42,0.35,-0.42,0.32,-0.09,0.1,-0.19,0.29,-0.23,0.28,-0.26,0.32,-0.29,0.32,-0.14,0.14,-0.2,0.18,-0.27,0.27,-0.32,0.34,-0.31,0.34,-0.27,0.35,-0.23,0.34,-0.26,0.33,-0.15,0.3,-0.36,0.33,-0.42,0.33,-0.36,0.34,-0.23,0.27,-0.25,0.27,-0.26,0.34,-0.24,0.34,-0.29,0.2,-0.23,0.23,-0.33,0.38,-0.39,0.32,-0.35,0.36,-0.14,0.15,-0.1,0.19,-0.23,0.25,-0.25,0.25,-0.37,0.38,-0.39,0.36,-0.03,0.02,-0.16,0.15,-0.18,0.15,-0.12,0.18,-0.31,0.25,-0.28,0.23,-0.17,0.23,-0.22,0.23,-0.21,0.18,-0.14,0.16,-0.12,0.12,-0.12,0.18,-0.1,0.12,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.04,-0.05,0.05,-0.08,0.09,-0.07,0.07,-0.03,0.03,-0.08,0.1,-0.05,0.05,-0.05,0.05,-0.08,0.09,-0.03,0.06,-0.05,0.05,-0.08,0.13,-0.07,0.07,-0.03,0.03,-0.08,0.11,-0.05,0.08,-0.06,0.05,-0.07,0.12,-0.06,0.04,-0.01,0.05,-0.02,0.03,-0.04,0.01,-0.05,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.04,-0.03,0.01,-0.02,0.01,-0.01,0.01,0.0,0.01,-0.25,0.38,-0.28,0.36,-0.34,0.39,-0.4,0.42,-0.34,0.27,-0.28,0.34,-0.5,0.45,-0.42,0.37,-0.18,0.27,-0.3,0.34,-0.2,0.25,-0.25,0.36,-0.34,0.36,-0.36,0.36,-0.1,0.17,-0.23,0.32,-0.26,0.3,-0.22,0.36,-0.29,0.37,-0.2,0.18,-0.28,0.21,-0.31,0.38,-0.34,0.4,-0.23,0.37,-0.2,0.23,-0.25,0.09,-0.27,0.34,-0.18,0.29,-0.21,0.23,-0.34,0.37,-0.34,0.36,-0.32,0.37,-0.21,0.25,-0.22,0.32,-0.2,0.24,-0.11,0.1,-0.27,0.29,-0.18,0.23,-0.01,0.0,-0.09,0.03,-0.01,0.01,-0.19,0.25,-0.23,0.31,-0.27,0.34,-0.33,0.37,-0.16,0.18,-0.16,0.3,-0.21,0.36,-0.25,0.38,-0.22,0.27,-0.24,0.36,-0.42,0.4,-0.22,0.33,-0.1,0.11,-0.14,0.13,-0.42,0.36,-0.45,0.4,-0.39,0.34,-0.26,0.23,-0.27,0.23,-0.07,0.08,-0.19,0.24,-0.21,0.23,-0.15,0.16,-0.17,0.13,-0.1,0.08,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.23,0.28,-0.29,0.33,-0.36,0.37,-0.36,0.38,-0.12,0.14,-0.48,0.43,-0.48,0.37,-0.42,0.38,-0.1,0.14,-0.24,0.37,-0.33,0.4,-0.22,0.35,-0.19,0.36,-0.16,0.21,-0.26,0.32,-0.29,0.4,-0.23,0.38,-0.24,0.32,-0.38,0.36,-0.45,0.39,-0.26,0.28,-0.35,0.32,-0.27,0.24,-0.19,0.37,-0.18,0.14,-0.13,0.12,-0.23,0.29,-0.23,0.36,-0.32,0.38,-0.22,0.35,-0.22,0.36,-0.13,0.16,-0.14,0.24,-0.23,0.26,-0.23,0.25,-0.26,0.34,-0.15,0.2,-0.18,0.27,-0.21,0.23,-0.1,0.08,-0.14,0.14,-0.29,0.34,-0.19,0.23,-0.26,0.36,-0.25,0.36,-0.26,0.36,-0.21,0.3,-0.28,0.36,-0.21,0.25,-0.24,0.21,-0.18,0.25,-0.21,0.28,-0.27,0.39,-0.21,0.38,-0.34,0.16,-0.18,0.18,-0.23,0.33,-0.1,0.14,-0.14,0.26,-0.47,0.34,-0.45,0.28,-0.34,0.3,-0.16,0.25,-0.17,0.18,-0.21,0.29,-0.14,0.18,-0.01,0.01,-0.07,0.07,-0.18,0.25,-0.2,0.27,-0.38,0.37,-0.36,0.34,-0.18,0.16,-0.17,0.33,-0.13,0.12,-0.18,0.21,-0.36,0.38,-0.32,0.38,-0.26,0.36,-0.12,0.13,-0.18,0.35,-0.18,0.23,-0.28,0.27,-0.23,0.25,-0.27,0.27,-0.25,0.34,-0.29,0.35,-0.31,0.4,-0.23,0.32,-0.24,0.25,-0.14,0.24,-0.24,0.34,-0.18,0.25,-0.25,0.34,-0.29,0.38,-0.25,0.38,-0.21,0.27,-0.16,0.24,-0.13,0.22,-0.16,0.07,-0.26,0.3,-0.46,0.4,-0.38,0.31,-0.21,0.27,-0.46,0.34,-0.5,0.43,-0.42,0.41,-0.22,0.23,-0.2,0.27,-0.27,0.29,-0.14,0.21,-0.18,0.28,-0.18,0.13,-0.12,0.16,-0.22,0.28,-0.25,0.27,-0.16,0.26,-0.36,0.26,-0.32,0.26,-0.2,0.17,-0.12,0.11,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.06,-0.03,0.03,-0.08,0.08,-0.07,0.08,-0.06,0.05,-0.05,0.09,-0.07,0.07,-0.04,0.05,-0.08,0.08,-0.05,0.07,-0.03,0.04,-0.05,0.05,-0.08,0.12,-0.06,0.06,-0.02,0.03,-0.07,0.1,-0.05,0.08,-0.05,0.05,-0.07,0.11,-0.05,0.05,0.0,0.03,-0.04,0.03,-0.05,0.01,-0.04,0.01,-0.03,0.04,-0.03,0.05,0.0,0.0,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.16,0.26,-0.29,0.36,-0.29,0.32,-0.12,0.12,-0.25,0.36,-0.33,0.37,-0.33,0.4,-0.36,0.42,-0.29,0.4,-0.27,0.42,-0.23,0.39,-0.16,0.17,-0.18,0.23,-0.3,0.36,-0.25,0.34,-0.23,0.32,-0.19,0.27,-0.36,0.36,-0.45,0.44,-0.45,0.38,-0.42,0.34,-0.16,0.25,-0.11,0.16,-0.32,0.38,-0.41,0.35,-0.45,0.32,-0.3,0.29,-0.21,0.27,-0.29,0.34,-0.38,0.35,-0.39,0.35,-0.29,0.36,-0.28,0.38,-0.18,0.32,-0.12,0.1,-0.08,0.13,-0.18,0.29,-0.29,0.25,-0.14,0.18,-0.29,0.37,-0.14,0.27,-0.16,0.25,-0.18,0.34,-0.07,0.03,-0.23,0.39,-0.36,0.34,-0.32,0.38,-0.24,0.28,-0.18,0.31,-0.19,0.36,-0.2,0.25,-0.27,0.26,-0.09,0.09,-0.21,0.26,-0.14,0.18,-0.43,0.38,-0.49,0.38,-0.47,0.35,-0.21,0.28,-0.21,0.3,-0.05,0.03,-0.18,0.16,-0.31,0.33,-0.34,0.35,-0.23,0.31,-0.22,0.32,-0.19,0.31,-0.14,0.15,-0.18,0.25,-0.29,0.32,-0.25,0.27,-0.38,0.37,-0.45,0.41,-0.42,0.4,-0.29,0.28,-0.11,0.16,-0.07,0.07,-0.01,0.01,-0.06,0.05,-0.26,0.36,-0.28,0.38,-0.2,0.28,-0.42,0.38,-0.46,0.42,-0.06,0.04,-0.1,0.09,-0.2,0.22,-0.28,0.25,-0.19,0.25,-0.4,0.32,-0.29,0.23,-0.48,0.29,-0.48,0.35,-0.34,0.4,-0.32,0.3,-0.21,0.31,-0.19,0.23,-0.45,0.36,-0.44,0.38,-0.18,0.27,-0.12,0.17,-0.23,0.31,-0.25,0.28,-0.23,0.32,-0.15,0.23,-0.23,0.27,-0.32,0.32,-0.33,0.3,-0.22,0.3,-0.34,0.39,-0.15,0.37,-0.32,0.26,-0.37,0.34,-0.41,0.38,-0.43,0.34,-0.3,0.34,-0.25,0.24,-0.21,0.26,-0.16,0.26,-0.07,0.08,-0.23,0.29,-0.28,0.33,-0.02,0.01,-0.17,0.23,-0.16,0.23,-0.15,0.21,-0.2,0.2,-0.14,0.12,-0.01,0.0,-0.16,0.15,-0.23,0.26,-0.29,0.33,-0.27,0.32,-0.39,0.36,-0.42,0.34,-0.19,0.32,-0.15,0.14,-0.21,0.37,-0.29,0.37,-0.18,0.32,-0.21,0.34,-0.2,0.19,-0.17,0.21,-0.41,0.36,-0.51,0.3,-0.43,0.36,-0.29,0.38,-0.1,0.1,-0.22,0.27,-0.19,0.25,0.0,0.0,-0.27,0.21,-0.36,0.34,-0.35,0.34,-0.1,0.14,-0.22,0.36,-0.19,0.27,-0.14,0.33,-0.21,0.35,-0.13,0.15,-0.26,0.29,-0.34,0.34,-0.1,0.1,-0.14,0.25,-0.18,0.28,-0.18,0.32,-0.1,0.05,-0.23,0.31,-0.4,0.34,-0.43,0.26,-0.27,0.3,-0.27,0.29,-0.35,0.38,-0.29,0.4,-0.36,0.25,-0.25,0.27,-0.29,0.3,-0.2,0.22,-0.32,0.27,-0.27,0.31,-0.43,0.35,-0.41,0.4,-0.3,0.34,-0.1,0.1,-0.01,0.01,-0.18,0.25,-0.36,0.36,-0.25,0.39,-0.07,0.07,-0.08,0.14,-0.4,0.39,-0.34,0.34,-0.11,0.1,-0.34,0.37,-0.41,0.36,-0.45,0.38,-0.4,0.32,-0.08,0.09,-0.19,0.25,-0.23,0.38,-0.06,0.09,-0.12,0.12,-0.25,0.37,-0.21,0.32,-0.25,0.29,-0.43,0.36,-0.5,0.47,-0.31,0.41,-0.18,0.28,-0.21,0.25,-0.2,0.21,-0.17,0.18,-0.16,0.17,-0.09,0.1,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.06,-0.03,0.04,-0.08,0.08,-0.05,0.08,-0.06,0.05,-0.06,0.08,-0.05,0.06,-0.03,0.04,-0.07,0.08,-0.04,0.05,-0.03,0.03,-0.06,0.11,-0.07,0.05,-0.04,0.05,-0.06,0.1,-0.07,0.08,-0.04,0.05,-0.06,0.11,-0.05,0.07,-0.05,0.05,-0.01,0.03,-0.04,0.02,-0.05,0.01,-0.04,0.03,-0.03,0.05,-0.03,0.06,-0.01,0.0,-0.03,0.01,-0.01,0.01,-0.01,0.01,-0.42,0.31,-0.44,0.46,-0.29,0.32,-0.09,0.1,-0.33,0.43,-0.42,0.45,-0.1,0.14,-0.11,0.05,-0.27,0.33,-0.28,0.29,-0.37,0.4,-0.32,0.4,-0.12,0.26,-0.33,0.36,-0.23,0.29,-0.23,0.2,-0.33,0.23,-0.23,0.26,-0.34,0.36,-0.3,0.34,-0.27,0.32,-0.18,0.23,-0.28,0.34,-0.32,0.29,-0.26,0.26,-0.15,0.18,-0.4,0.43,-0.45,0.41,-0.46,0.36,-0.36,0.34,-0.12,0.1,-0.21,0.32,-0.36,0.39,-0.42,0.35,-0.44,0.32,-0.19,0.29,-0.22,0.25,-0.33,0.34,-0.37,0.32,-0.35,0.32,-0.28,0.3,-0.27,0.34,-0.21,0.35,-0.14,0.14,-0.03,0.02,-0.1,0.14,-0.23,0.31,-0.26,0.27,-0.27,0.28,-0.33,0.4,-0.32,0.36,-0.27,0.36,-0.27,0.14,-0.23,0.29,-0.23,0.28,-0.27,0.35,-0.25,0.33,-0.2,0.27,-0.3,0.4,-0.21,0.3,0.0,0.01,-0.33,0.39,-0.36,0.4,-0.32,0.37,-0.04,0.01,-0.26,0.35,-0.26,0.34,-0.15,0.25,-0.28,0.27,-0.32,0.27,-0.33,0.27,-0.22,0.29,-0.23,0.32,-0.13,0.13,-0.13,0.14,0.0,0.0,-0.08,0.13,-0.25,0.29,-0.27,0.29,-0.22,0.27,-0.23,0.25,-0.27,0.32,-0.27,0.34,-0.38,0.42,-0.3,0.21,-0.33,0.24,-0.34,0.39,-0.51,0.37,-0.49,0.36,-0.47,0.3,-0.06,0.06,-0.18,0.26,-0.15,0.23,-0.16,0.16,-0.18,0.19,-0.16,0.12,-0.01,0.02,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.05,-0.04,0.04,-0.08,0.08,-0.06,0.07,-0.05,0.03,-0.06,0.09,-0.04,0.05,-0.05,0.04,-0.07,0.08,-0.04,0.05,-0.05,0.05,-0.07,0.11,-0.05,0.05,-0.03,0.03,-0.07,0.1,-0.05,0.08,-0.05,0.05,-0.06,0.11,-0.05,0.04,-0.03,0.05,-0.02,0.03,-0.05,0.02,-0.05,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.06,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.1,0.08,-0.36,0.4,-0.32,0.43,-0.2,0.16,-0.31,0.42,-0.29,0.45,-0.25,0.27,-0.15,0.16,-0.24,0.29,-0.27,0.33,-0.36,0.38,-0.48,0.36,-0.21,0.24,-0.25,0.38,-0.23,0.32,-0.25,0.34,-0.45,0.38,-0.23,0.37,-0.21,0.24,-0.29,0.34,-0.43,0.42,-0.47,0.34,-0.38,0.32,-0.14,0.1,-0.11,0.07,-0.1,0.07,-0.26,0.34,-0.29,0.33,-0.16,0.17,-0.35,0.39,-0.49,0.39,-0.31,0.21,-0.14,0.13,-0.34,0.34,-0.14,0.17,-0.14,0.16,-0.3,0.36,-0.38,0.36,-0.32,0.38,-0.28,0.24,-0.08,0.09,-0.01,0.01,-0.25,0.37,-0.27,0.34,-0.21,0.24,-0.18,0.18,-0.09,0.05,-0.19,0.21,-0.34,0.36,-0.39,0.36,-0.3,0.26,-0.16,0.12,-0.18,0.34,-0.22,0.23,0.0,0.01,-0.35,0.38,-0.37,0.35,-0.32,0.37,-0.08,0.1,-0.25,0.34,-0.27,0.32,-0.14,0.23,-0.29,0.32,-0.36,0.35,-0.23,0.34,-0.18,0.35,-0.19,0.16,-0.26,0.3,-0.39,0.38,-0.36,0.36,-0.24,0.26,-0.24,0.32,-0.42,0.39,-0.42,0.4,-0.4,0.37,-0.1,0.11,-0.22,0.33,-0.17,0.29,-0.14,0.2,-0.16,0.22,-0.26,0.29,-0.28,0.29,-0.29,0.32,-0.36,0.34,-0.23,0.29,-0.1,0.1,-0.16,0.23,-0.11,0.12,-0.1,0.19,-0.27,0.38,-0.23,0.29,-0.17,0.29,-0.27,0.17,-0.21,0.32,-0.23,0.26,-0.38,0.3,-0.23,0.29,-0.25,0.33,0.0,0.02,-0.12,0.12,-0.25,0.4,-0.12,0.25,-0.08,0.03,-0.18,0.36,-0.23,0.32,-0.2,0.29,-0.22,0.21,-0.13,0.18,-0.12,0.18,-0.01,0.01,-0.3,0.31,-0.4,0.36,-0.08,0.08,-0.07,0.12,-0.25,0.34,-0.3,0.32,-0.31,0.27,-0.14,0.16,-0.19,0.2,-0.18,0.18,-0.01,0.03,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.09,0.08,-0.04,0.07,-0.04,0.03,-0.09,0.09,-0.08,0.1,-0.08,0.07,-0.05,0.1,-0.08,0.08,-0.05,0.05,-0.08,0.05,-0.05,0.09,-0.03,0.04,-0.05,0.05,-0.08,0.13,-0.07,0.07,-0.03,0.03,-0.08,0.11,-0.05,0.08,-0.06,0.05,-0.07,0.12,-0.05,0.06,-0.01,0.04,-0.04,0.03,-0.05,0.02,-0.05,0.01,-0.03,0.05,-0.03,0.06,0.0,0.01,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.27,0.29,-0.34,0.41,-0.51,0.47,-0.32,0.49,-0.14,0.21,-0.25,0.27,-0.25,0.32,-0.26,0.23,-0.05,0.1,-0.5,0.39,-0.45,0.35,-0.31,0.36,-0.24,0.34,-0.08,0.09,-0.13,0.16,-0.25,0.29,-0.12,0.11,-0.32,0.29,-0.27,0.28,-0.3,0.42,-0.51,0.39,-0.49,0.34,-0.3,0.34,-0.1,0.09,-0.11,0.13,-0.1,0.08,-0.32,0.32,-0.25,0.29,-0.23,0.27,-0.45,0.44,-0.45,0.47,-0.21,0.28,-0.19,0.15,-0.14,0.14,-0.25,0.34,-0.25,0.32,-0.29,0.36,-0.21,0.35,-0.2,0.36,-0.12,0.18,-0.14,0.22,-0.1,0.13,-0.01,0.01,-0.32,0.36,-0.28,0.32,-0.01,0.0,-0.22,0.25,-0.2,0.23,-0.27,0.32,-0.35,0.38,-0.26,0.32,-0.07,0.15,0.0,0.0,-0.01,0.01,-0.15,0.16,-0.24,0.36,-0.19,0.29,-0.19,0.15,-0.21,0.33,-0.24,0.29,-0.02,0.01,-0.33,0.38,-0.35,0.35,-0.33,0.4,-0.19,0.25,-0.22,0.32,-0.28,0.34,-0.18,0.27,-0.12,0.26,-0.34,0.34,-0.4,0.35,-0.27,0.36,-0.26,0.39,-0.16,0.14,-0.18,0.36,-0.16,0.31,-0.18,0.18,-0.24,0.27,-0.39,0.41,-0.37,0.38,-0.12,0.16,-0.23,0.29,-0.25,0.3,-0.23,0.29,-0.38,0.37,-0.38,0.34,-0.32,0.39,-0.21,0.27,-0.21,0.16,-0.2,0.27,-0.27,0.29,-0.3,0.36,-0.24,0.35,-0.18,0.25,-0.49,0.38,-0.51,0.37,-0.47,0.35,-0.45,0.26,-0.16,0.24,-0.26,0.29,-0.25,0.21,-0.21,0.21,-0.16,0.18,-0.14,0.18,-0.08,0.08,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.14,0.13,-0.28,0.29,-0.31,0.41,-0.36,0.37,-0.29,0.38,-0.23,0.26,-0.29,0.37,-0.25,0.27,-0.18,0.18,-0.29,0.4,-0.28,0.42,-0.18,0.19,-0.09,0.05,-0.31,0.36,-0.17,0.12,0.0,0.0,-0.23,0.3,-0.25,0.29,-0.36,0.39,-0.35,0.39,-0.12,0.1,-0.18,0.27,-0.18,0.32,-0.38,0.37,-0.31,0.4,-0.26,0.33,-0.24,0.21,-0.09,0.21,-0.17,0.28,-0.22,0.3,-0.13,0.1,-0.33,0.39,-0.48,0.38,-0.5,0.3,-0.35,0.38,-0.22,0.35,-0.23,0.39,-0.2,0.14,-0.07,0.09,-0.2,0.23,-0.22,0.26,-0.13,0.16,-0.21,0.31,-0.24,0.22,-0.45,0.38,-0.46,0.43,-0.43,0.42,-0.16,0.23,-0.08,0.1,-0.16,0.22,-0.25,0.29,-0.25,0.28,-0.27,0.34,-0.25,0.36,-0.14,0.15,-0.2,0.34,-0.23,0.35,-0.34,0.32,-0.33,0.32,-0.27,0.38,-0.07,0.12,-0.12,0.07,-0.21,0.38,-0.13,0.21,-0.24,0.38,-0.21,0.31,-0.16,0.16,-0.21,0.27,-0.01,0.03,-0.19,0.14,-0.29,0.38,-0.25,0.36,-0.21,0.25,-0.23,0.25,-0.31,0.38,-0.11,0.26,-0.27,0.38,-0.1,0.08,-0.21,0.23,-0.36,0.38,-0.35,0.35,-0.28,0.37,-0.23,0.37,-0.21,0.36,-0.44,0.34,-0.27,0.16,-0.23,0.18,-0.24,0.26,-0.2,0.18,-0.21,0.33,-0.27,0.38,-0.21,0.29,-0.13,0.13,-0.18,0.21,-0.36,0.24,-0.34,0.29,-0.16,0.21,-0.25,0.16,-0.19,0.27,-0.12,0.16,-0.14,0.05,-0.15,0.21,-0.17,0.21,-0.15,0.18,-0.15,0.14,-0.12,0.1,-0.03,0.03,-0.01,0.01,-0.01,0.01,-0.01,0.02,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.02,0.01,-0.01,0.01,-0.01,0.01,-0.37,0.33,-0.35,0.4,-0.11,0.12,-0.08,0.1,-0.38,0.37,-0.41,0.42,-0.3,0.14,-0.06,0.07,-0.25,0.29,-0.17,0.21,-0.29,0.31,-0.3,0.32,-0.23,0.26,-0.05,0.05,-0.23,0.25,-0.29,0.39,-0.25,0.34,-0.16,0.21,-0.13,0.1,-0.29,0.36,-0.26,0.32,-0.1,0.16,-0.5,0.46,-0.49,0.45,-0.47,0.4,-0.42,0.29,-0.21,0.2,-0.14,0.21,-0.15,0.18,-0.06,0.07,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.03,0.05,-0.04,0.04,-0.07,0.08,-0.05,0.06,-0.04,0.02,-0.05,0.08,-0.03,0.04,-0.04,0.03,-0.06,0.07,-0.03,0.05,-0.03,0.04,-0.05,0.09,-0.05,0.05,-0.03,0.03,-0.05,0.08,-0.03,0.05,-0.04,0.03,-0.05,0.09,-0.04,0.03,-0.03,0.04,-0.01,0.02,-0.03,0.01,-0.03,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.02,0.01,-0.01,0.01,-0.01,0.01,-0.13,0.11,-0.26,0.31,-0.24,0.25,-0.31,0.33,-0.2,0.2,-0.24,0.28,-0.29,0.4,-0.23,0.38,-0.23,0.29,-0.27,0.4,-0.19,0.34,-0.14,0.11,-0.21,0.32,-0.27,0.35,-0.36,0.41,-0.38,0.39,-0.39,0.36,-0.41,0.39,-0.36,0.36,-0.17,0.21,-0.29,0.23,-0.18,0.2,-0.29,0.4,-0.24,0.4,-0.33,0.24,-0.25,0.32,-0.2,0.25,-0.2,0.34,-0.25,0.36,-0.27,0.29,-0.45,0.32,-0.51,0.47,-0.48,0.4,-0.41,0.34,-0.23,0.34,-0.32,0.38,-0.32,0.36,-0.21,0.23,-0.27,0.37,-0.19,0.36,-0.14,0.13,-0.32,0.35,-0.32,0.32,-0.21,0.25,-0.21,0.32,-0.24,0.29,-0.32,0.29,-0.31,0.26,-0.09,0.1,-0.12,0.13,-0.2,0.32,-0.52,0.35,-0.51,0.35,-0.27,0.37,-0.34,0.39,-0.41,0.3,-0.18,0.21,-0.38,0.36,-0.45,0.35,-0.41,0.36,-0.31,0.36,-0.14,0.17,-0.11,0.19,-0.23,0.27,-0.27,0.31,-0.29,0.34,-0.29,0.34,-0.29,0.29,-0.27,0.27,-0.07,0.07,-0.08,0.06,-0.35,0.39,-0.51,0.41,-0.49,0.32,-0.34,0.37,-0.08,0.08,-0.18,0.34,-0.11,0.11,-0.45,0.36,-0.43,0.32,-0.29,0.34,-0.21,0.35,-0.1,0.09,-0.18,0.23,-0.44,0.42,-0.45,0.43,-0.36,0.38,-0.19,0.25,-0.45,0.42,-0.48,0.44,-0.47,0.34,-0.03,0.03,-0.15,0.23,-0.09,0.08,-0.22,0.31,-0.26,0.32,-0.23,0.35,-0.19,0.29,-0.01,0.01,-0.34,0.39,-0.36,0.38,-0.29,0.4,-0.07,0.08,-0.21,0.27,-0.22,0.27,-0.16,0.23,-0.19,0.19,-0.25,0.22,-0.24,0.21,-0.17,0.17,-0.18,0.18,-0.13,0.18,-0.18,0.13,-0.07,0.07,-0.01,0.01,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.07,0.16,-0.21,0.32,-0.14,0.13,-0.25,0.32,-0.31,0.27,-0.19,0.17,-0.26,0.29,-0.43,0.49,-0.39,0.49,-0.03,0.03,-0.21,0.36,-0.2,0.29,-0.28,0.4,-0.12,0.16,-0.12,0.15,-0.18,0.23,-0.24,0.34,-0.22,0.33,-0.25,0.29,-0.16,0.25,-0.23,0.31,-0.36,0.34,-0.36,0.36,-0.25,0.37,-0.33,0.38,-0.16,0.16,-0.11,0.12,-0.11,0.22,-0.25,0.34,-0.28,0.34,-0.45,0.47,-0.45,0.48,-0.41,0.36,-0.17,0.34,-0.17,0.18,-0.4,0.41,-0.43,0.42,-0.25,0.29,-0.16,0.14,-0.21,0.29,-0.27,0.29,-0.42,0.39,-0.42,0.42,-0.42,0.42,-0.38,0.3,-0.1,0.1,-0.26,0.32,-0.25,0.27,-0.05,0.07,-0.01,0.01,-0.27,0.24,-0.32,0.32,-0.32,0.35,-0.33,0.38,-0.28,0.36,-0.38,0.38,-0.24,0.32,-0.25,0.22,-0.26,0.21,-0.27,0.25,-0.38,0.4,-0.32,0.36,-0.19,0.25,-0.2,0.25,-0.22,0.28,-0.13,0.14,-0.32,0.4,-0.36,0.36,-0.32,0.38,-0.29,0.34,-0.29,0.3,-0.25,0.28,-0.13,0.15,-0.08,0.08,-0.47,0.37,-0.49,0.33,-0.37,0.36,-0.23,0.25,-0.21,0.4,-0.25,0.22,-0.19,0.05,-0.21,0.36,-0.29,0.36,-0.18,0.24,-0.44,0.35,-0.43,0.41,-0.05,0.06,-0.22,0.25,-0.36,0.28,-0.45,0.39,-0.46,0.29,-0.25,0.29,-0.12,0.1,-0.16,0.27,-0.18,0.27,-0.4,0.26,-0.16,0.18,-0.23,0.33,-0.16,0.24,-0.22,0.31,-0.08,0.1,-0.11,0.16,-0.25,0.34,-0.27,0.32,-0.32,0.36,-0.34,0.34,-0.08,0.08,-0.24,0.33,-0.27,0.32,-0.19,0.25,-0.13,0.12,-0.08,0.07,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.07,0.07,-0.42,0.38,-0.52,0.37,-0.51,0.41,-0.42,0.38,-0.21,0.29,-0.25,0.38,-0.27,0.32,-0.27,0.32,-0.31,0.37,-0.13,0.15,-0.21,0.32,-0.28,0.34,-0.3,0.32,-0.3,0.29,-0.25,0.31,-0.19,0.32,-0.14,0.18,-0.16,0.14,-0.31,0.32,-0.23,0.36,-0.03,0.01,-0.17,0.32,-0.27,0.28,-0.36,0.3,-0.23,0.33,-0.24,0.34,-0.26,0.34,-0.26,0.25,-0.05,0.07,-0.1,0.05,-0.27,0.36,-0.24,0.33,-0.23,0.16,-0.24,0.32,-0.42,0.4,-0.36,0.38,-0.25,0.32,-0.42,0.47,-0.37,0.45,-0.1,0.09,-0.19,0.21,-0.16,0.21,-0.11,0.14,-0.25,0.3,-0.45,0.46,-0.44,0.47,-0.43,0.34,-0.23,0.34,-0.23,0.25,-0.36,0.2,-0.26,0.29,-0.14,0.23,-0.13,0.17,-0.47,0.34,-0.49,0.33,-0.4,0.34,-0.21,0.33,-0.17,0.2,-0.17,0.29,-0.09,0.1,-0.19,0.29,-0.2,0.29,-0.19,0.32,-0.17,0.23,-0.13,0.17,-0.41,0.38,-0.38,0.39,-0.29,0.23,-0.2,0.17,-0.1,0.1,-0.43,0.4,-0.5,0.32,-0.45,0.33,-0.32,0.37,-0.25,0.38,-0.15,0.18,-0.26,0.18,-0.29,0.27,-0.21,0.23,-0.18,0.23,-0.16,0.21,-0.34,0.34,-0.34,0.25,-0.24,0.14,-0.2,0.2,-0.21,0.14,-0.03,0.03,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.06,-0.04,0.05,-0.08,0.08,-0.06,0.07,-0.06,0.05,-0.07,0.09,-0.05,0.06,-0.04,0.05,-0.08,0.08,-0.04,0.06,-0.03,0.04,-0.07,0.11,-0.07,0.05,-0.04,0.05,-0.07,0.1,-0.06,0.07,-0.04,0.03,-0.06,0.1,-0.05,0.06,-0.03,0.05,-0.01,0.03,-0.04,0.01,-0.04,0.01,-0.03,0.03,-0.03,0.05,-0.03,0.05,-0.01,0.01,-0.03,0.01,-0.01,0.01,-0.01,0.01,-0.12,0.27,-0.43,0.38,-0.44,0.38,-0.27,0.34,-0.51,0.37,-0.53,0.45,-0.46,0.41,-0.34,0.36,-0.35,0.32,-0.12,0.15,-0.16,0.23,-0.28,0.27,-0.3,0.31,-0.25,0.35,-0.11,0.11,-0.03,0.03,-0.21,0.25,-0.25,0.36,-0.36,0.35,-0.34,0.4,-0.2,0.3,-0.35,0.25,-0.19,0.29,-0.51,0.45,-0.49,0.43,-0.43,0.43,-0.21,0.23,-0.34,0.32,-0.27,0.29,-0.05,0.1,-0.04,0.04,-0.16,0.15,-0.27,0.34,-0.21,0.34,-0.2,0.36,-0.03,0.01,-0.33,0.36,-0.29,0.34,-0.02,0.01,-0.18,0.23,-0.27,0.26,-0.34,0.37,-0.15,0.14,-0.23,0.25,-0.23,0.32,-0.2,0.18,-0.28,0.25,-0.28,0.4,-0.15,0.18,-0.16,0.29,-0.15,0.33,-0.22,0.19,-0.18,0.11,-0.21,0.33,-0.17,0.14,-0.28,0.36,-0.3,0.33,-0.21,0.21,-0.09,0.08,-0.01,0.01,-0.03,0.04,-0.27,0.25,-0.23,0.3,-0.14,0.16,-0.14,0.31,-0.18,0.14,-0.13,0.14,-0.41,0.42,-0.29,0.32,-0.08,0.09,-0.21,0.28,-0.34,0.36,-0.33,0.37,-0.28,0.32,-0.28,0.3,-0.16,0.23,-0.08,0.1,-0.24,0.31,-0.18,0.27,-0.21,0.16,-0.31,0.34,-0.37,0.36,-0.26,0.34,-0.28,0.33,-0.23,0.37,-0.32,0.35,-0.4,0.36,-0.29,0.21,-0.49,0.38,-0.48,0.4,-0.36,0.34,-0.17,0.14,-0.11,0.11,-0.19,0.23,-0.25,0.29,-0.39,0.38,-0.45,0.32,-0.37,0.26,-0.15,0.18,-0.07,0.1,-0.13,0.25,-0.2,0.27,-0.23,0.3,-0.43,0.45,-0.42,0.47,-0.38,0.33,-0.19,0.32,-0.2,0.23,-0.26,0.28,-0.42,0.38,-0.32,0.29,-0.18,0.24,-0.2,0.34,-0.23,0.21,-0.23,0.21,0.0,0.0,-0.26,0.24,-0.26,0.21,-0.1,0.09,-0.09,0.08,-0.06,0.07,-0.13,0.16,-0.2,0.16,-0.21,0.16,-0.13,0.13,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.02,0.01,-0.01,0.01,-0.23,0.32,-0.16,0.25,-0.24,0.38,-0.25,0.38,-0.37,0.34,-0.24,0.3,-0.29,0.38,-0.29,0.38,-0.25,0.23,-0.4,0.37,-0.4,0.38,-0.23,0.27,-0.28,0.38,-0.25,0.37,-0.23,0.16,-0.1,0.14,-0.18,0.23,-0.18,0.2,-0.23,0.28,-0.17,0.22,-0.33,0.31,-0.31,0.38,-0.41,0.37,-0.23,0.2,-0.16,0.26,-0.19,0.34,-0.16,0.21,-0.14,0.21,-0.16,0.24,-0.08,0.1,-0.26,0.38,-0.45,0.41,-0.34,0.34,-0.03,0.04,-0.14,0.19,-0.44,0.37,-0.42,0.36,-0.19,0.18,-0.13,0.13,-0.15,0.25,-0.29,0.36,-0.29,0.34,-0.21,0.29,-0.21,0.37,-0.34,0.4,-0.1,0.11,-0.23,0.27,-0.37,0.33,-0.36,0.36,-0.3,0.36,-0.23,0.21,-0.17,0.25,-0.18,0.27,-0.23,0.25,-0.09,0.1,-0.2,0.18,-0.36,0.27,-0.38,0.33,-0.35,0.32,-0.16,0.17,-0.05,0.04,-0.09,0.1,-0.04,0.04,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,-0.01,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.28,0.27,-0.38,0.38,-0.25,0.38,-0.05,0.06,-0.24,0.29,-0.29,0.38,-0.25,0.3,-0.16,0.18,-0.31,0.32,-0.14,0.16,-0.36,0.35,-0.38,0.38,-0.11,0.06,-0.38,0.39,-0.37,0.36,-0.09,0.1,-0.22,0.36,-0.23,0.36,-0.23,0.36,-0.38,0.37,-0.36,0.4,-0.27,0.34,-0.32,0.41,-0.23,0.4,-0.12,0.18,-0.25,0.3,-0.35,0.34,-0.35,0.35,-0.27,0.38,-0.2,0.36,-0.1,0.1,-0.19,0.24,-0.32,0.33,-0.29,0.29,-0.25,0.27,-0.21,0.19,-0.15,0.21,-0.36,0.36,-0.38,0.34,-0.34,0.34,-0.22,0.23,-0.21,0.18,-0.17,0.16,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.23,0.25,-0.4,0.38,-0.34,0.32,-0.38,0.34,-0.28,0.38,-0.25,0.35,-0.34,0.38,-0.24,0.36,-0.25,0.27,-0.3,0.4,-0.32,0.36,-0.25,0.31,-0.11,0.11,-0.25,0.31,-0.23,0.29,-0.16,0.21,-0.2,0.22,-0.06,0.08,-0.05,0.03,-0.21,0.23,-0.39,0.37,-0.4,0.36,-0.25,0.38,-0.08,0.05,-0.12,0.13,-0.32,0.4,-0.27,0.4,-0.24,0.36,-0.2,0.14,-0.14,0.16,-0.23,0.36,-0.24,0.38,-0.34,0.29,-0.34,0.34,-0.21,0.34,-0.09,0.11,-0.35,0.38,-0.38,0.3,-0.26,0.34,-0.18,0.32,-0.28,0.39,-0.13,0.27,-0.19,0.34,-0.17,0.28,-0.29,0.24,-0.23,0.33,-0.25,0.3,-0.27,0.32,-0.26,0.36,-0.22,0.34,-0.23,0.36,-0.14,0.12,-0.19,0.31,-0.14,0.32,-0.08,0.1,-0.01,0.01,-0.29,0.3,-0.27,0.3,-0.09,0.1,-0.15,0.17,-0.33,0.33,-0.26,0.31,-0.28,0.32,-0.08,0.09,-0.25,0.31,-0.07,0.1,-0.29,0.16,-0.21,0.25,-0.25,0.31,-0.36,0.34,-0.29,0.32,-0.47,0.39,-0.5,0.43,-0.49,0.4,-0.24,0.21,-0.18,0.14,-0.17,0.28,-0.04,0.05,-0.1,0.12,-0.24,0.4,-0.25,0.4,-0.01,0.01,-0.13,0.15,-0.23,0.41,-0.2,0.32,-0.22,0.31,-0.15,0.13,-0.22,0.34,-0.21,0.29,-0.28,0.38,-0.24,0.38,-0.19,0.32,-0.19,0.33,-0.19,0.36,-0.16,0.2,-0.18,0.22,-0.34,0.27,-0.34,0.27,-0.29,0.23,-0.13,0.14,-0.1,0.08,0.0,0.0,0.0,0.0,0.0,0.0,-0.02,0.01,-0.01,0.01,0.0,0.0,-0.01,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.26,0.36,-0.36,0.38,-0.21,0.21,-0.24,0.31,-0.47,0.49,-0.4,0.42,-0.2,0.29,-0.23,0.25,-0.26,0.34,-0.32,0.34,-0.28,0.32,-0.2,0.29,-0.23,0.35,-0.22,0.29,-0.25,0.4,-0.36,0.41,-0.19,0.27,-0.11,0.14,-0.27,0.32,-0.26,0.29,-0.49,0.37,-0.49,0.42,-0.19,0.15,-0.23,0.23,-0.4,0.4,-0.29,0.34,-0.17,0.16,-0.16,0.28,-0.1,0.1,-0.21,0.32,-0.25,0.32,-0.01,0.01,-0.18,0.35,-0.49,0.42,-0.47,0.42,-0.41,0.41,-0.25,0.23,-0.35,0.31,-0.23,0.34,-0.17,0.22,-0.18,0.34,-0.23,0.34,-0.28,0.28,-0.27,0.27,-0.32,0.36,-0.27,0.3,-0.23,0.23,-0.3,0.39,-0.25,0.36,-0.01,0.01,-0.34,0.4,-0.36,0.39,-0.34,0.41,-0.04,0.07,-0.26,0.32,-0.25,0.31,-0.14,0.21,-0.26,0.3,-0.34,0.33,-0.36,0.32,-0.26,0.35,-0.16,0.36,-0.05,0.04,-0.24,0.26,-0.27,0.29,-0.18,0.19,-0.25,0.21,-0.34,0.34,-0.32,0.29,-0.23,0.23,-0.33,0.29,-0.38,0.32,-0.38,0.31,-0.32,0.21,-0.1,0.12,-0.14,0.2,-0.12,0.16,-0.01,0.0,-0.01,0.01,-0.01,0.01,0.0,0.0,-0.01,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.08,-0.04,0.06,-0.03,0.03,-0.08,0.08,-0.06,0.08,-0.06,0.05,-0.07,0.09,-0.05,0.07,-0.04,0.05,-0.08,0.08,-0.05,0.07,-0.03,0.04,-0.05,0.05,-0.08,0.12,-0.06,0.06,-0.03,0.03,-0.07,0.1,-0.05,0.08,-0.06,0.05,-0.07,0.12,-0.05,0.06,-0.01,0.04,-0.04,0.03,-0.05,0.01,-0.05,0.01,-0.03,0.05,-0.03,0.06,-0.01,0.0,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.1,0.12,-0.32,0.47,-0.34,0.49,-0.3,0.45,-0.21,0.34,-0.25,0.4,-0.25,0.35,-0.23,0.27,-0.12,0.13,-0.01,0.01,-0.08,0.14,-0.31,0.37,-0.16,0.25,-0.1,0.22,-0.35,0.4,-0.34,0.4,-0.27,0.36,-0.15,0.03,-0.25,0.34,-0.25,0.34,-0.14,0.23,-0.29,0.31,-0.36,0.33,-0.42,0.35,-0.23,0.28,-0.34,0.38,-0.15,0.32,-0.09,0.08,-0.17,0.23,-0.29,0.25,-0.25,0.25,-0.3,0.36,-0.27,0.29,-0.29,0.34,-0.35,0.37,-0.31,0.38,-0.21,0.26,-0.23,0.4,-0.14,0.17,-0.06,0.1,-0.19,0.24,-0.26,0.31,-0.18,0.18,-0.29,0.31,-0.32,0.32,-0.25,0.32,-0.19,0.25,-0.1,0.08,-0.27,0.32,-0.21,0.27,-0.08,0.09,-0.17,0.2,-0.24,0.4,-0.25,0.38,-0.02,0.02,-0.21,0.36,-0.36,0.4,-0.39,0.33,-0.25,0.34,-0.2,0.33,-0.21,0.33,-0.32,0.28,-0.25,0.35,-0.25,0.35,-0.1,0.12,-0.23,0.28,-0.19,0.28,-0.26,0.25,-0.14,0.19,-0.22,0.25,-0.23,0.29,-0.06,0.08,-0.25,0.37,-0.41,0.43,-0.32,0.4,-0.27,0.24,-0.26,0.28,-0.25,0.34,-0.25,0.25,-0.27,0.25,-0.18,0.25,-0.48,0.43,-0.47,0.39,-0.46,0.36,-0.33,0.37,-0.24,0.36,-0.2,0.17,-0.33,0.25,-0.45,0.38,-0.49,0.3,-0.4,0.31,-0.15,0.19,-0.16,0.18,-0.18,0.21,-0.17,0.21,-0.26,0.29,-0.1,0.09,-0.26,0.22,-0.19,0.32,-0.25,0.32,-0.31,0.32,-0.28,0.3,-0.16,0.17,-0.28,0.27,-0.3,0.21,-0.33,0.4,-0.32,0.36,-0.25,0.34,-0.21,0.23,-0.22,0.32,-0.28,0.4,-0.39,0.39,-0.33,0.35,-0.16,0.16,-0.14,0.16,-0.24,0.33,-0.21,0.29,-0.24,0.34,-0.16,0.21,-0.18,0.14,-0.4,0.24,-0.43,0.34,-0.21,0.34,-0.23,0.21,-0.34,0.27,-0.34,0.36,-0.29,0.3,-0.27,0.32,-0.08,0.08,-0.18,0.32,-0.15,0.18,-0.23,0.2,-0.29,0.29,-0.21,0.27,-0.21,0.33,-0.21,0.25,-0.22,0.26,-0.47,0.43,-0.46,0.36,-0.45,0.36,-0.19,0.29,-0.1,0.08,-0.27,0.31,-0.34,0.31,-0.36,0.31,-0.31,0.27,-0.13,0.17,-0.23,0.23,-0.26,0.23,-0.26,0.23,-0.18,0.18,-0.16,0.18,-0.12,0.16,-0.1,0.11,-0.04,0.04,0.0,0.0,-0.01,0.01,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.08,0.07,-0.04,0.06,-0.04,0.04,-0.08,0.08,-0.06,0.07,-0.06,0.05,-0.07,0.09,-0.05,0.05,-0.04,0.05,-0.08,0.08,-0.04,0.05,-0.04,0.04,-0.07,0.12,-0.06,0.06,-0.03,0.05,-0.07,0.1,-0.07,0.08,-0.04,0.03,-0.07,0.11,-0.05,0.07,-0.04,0.05,-0.01,0.03,-0.05,0.02,-0.05,0.01,-0.04,0.03,-0.03,0.05,-0.03,0.06,-0.03,0.01,-0.03,0.01,-0.01,0.01,-0.01,0.01,-0.18,0.31,-0.29,0.36,-0.34,0.36,-0.32,0.4,-0.37,0.44,-0.11,0.08,-0.28,0.16,-0.28,0.47,-0.31,0.45,-0.04,0.02,-0.25,0.36,-0.27,0.42,-0.27,0.36,-0.31,0.31,-0.29,0.25,-0.22,0.17,-0.35,0.33,-0.16,0.22,-0.16,0.18,-0.16,0.13,-0.11,0.19,-0.52,0.36,-0.5,0.3,-0.34,0.37,-0.23,0.36,-0.23,0.28,-0.08,0.12,-0.21,0.34,-0.32,0.36,-0.42,0.47,-0.38,0.49,-0.36,0.4,-0.27,0.33,-0.19,0.29,-0.21,0.34,-0.12,0.25,-0.01,0.01,-0.02,0.03,-0.18,0.28,-0.3,0.26,-0.34,0.31,-0.24,0.32,-0.21,0.25,-0.28,0.26,-0.45,0.41,-0.47,0.38,-0.43,0.35,-0.21,0.32,-0.1,0.18,-0.31,0.36,-0.41,0.37,-0.43,0.34,-0.26,0.29,-0.12,0.23,-0.29,0.31,-0.38,0.38,-0.4,0.36,-0.28,0.38,-0.24,0.38,-0.06,0.08,-0.12,0.25,-0.25,0.32,-0.37,0.27,-0.23,0.32,-0.21,0.32,-0.12,0.15,-0.17,0.28,-0.23,0.27,-0.27,0.23,-0.16,0.26,-0.16,0.3,-0.23,0.28,-0.38,0.34,-0.36,0.25,-0.42,0.42,-0.34,0.33,-0.18,0.22,-0.25,0.33,-0.21,0.35,-0.08,0.12,-0.31,0.38,-0.34,0.35,-0.27,0.33,-0.27,0.33,-0.21,0.26,-0.17,0.21,-0.15,0.18,-0.1,0.11,-0.02,0.01,-0.01,0.01,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,-0.02,0.01,-0.02,0.01,-0.01,0.01,0.0,0.01,-0.01,0.01,0.0,0.0,0.0,0.0,-0.01,0.01,-0.34,0.34,-0.45,0.42,-0.37,0.36,-0.29,0.37,-0.29,0.39,-0.28,0.27,-0.4,0.38,-0.32,0.41,-0.17,0.25,-0.25,0.4,-0.23,0.36,-0.14,0.2,-0.29,0.25,-0.32,0.38,-0.15,0.1,-0.18,0.23,-0.25,0.39,-0.51,0.43,-0.48,0.36,-0.41,0.32,-0.23,0.34,-0.29,0.32,-0.29,0.31,-0.22,0.23,-0.17,0.22,-0.27,0.22,-0.34,0.26,-0.32,0.27,-0.22,0.19,-0.12,0.14,-0.12,0.08,0.0,0.0,-0.01,0.01,-0.01,0.01,-0.01,0.01,-0.02,0.01,-0.01,0.01,-0.13,0.1,-0.27,0.28,-0.28,0.4,-0.35,0.4,-0.32,0.38,-0.06,0.07,-0.2,0.36,-0.36,0.42,-0.27,0.34,-0.32,0.38,-0.27,0.4,-0.27,0.26,-0.34,0.37,-0.26,0.32,-0.36,0.29,-0.37,0.36,-0.21,0.2,-0.37,0.39,-0.41,0.36,-0.4,0.36,-0.3,0.31,-0.37,0.34,-0.41,0.41,-0.28,0.31,-0.2,0.27,-0.24,0.36,-0.25,0.36,-0.27,0.37,-0.19,0.23,-0.27,0.36,-0.21,0.36,-0.26,0.19,-0.25,0.31,-0.27,0.27,-0.27,0.34,-0.27,0.37,-0.22,0.27,-0.21,0.2,-0.25,0.36,-0.3,0.39,-0.24,0.25,-0.25,0.27,-0.25,0.3,-0.28,0.34,-0.22,0.27,-0.12,0.18,-0.08,0.05,-0.23,0.35,-0.22,0.3,-0.12,0.2,-0.26,0.29,-0.4,0.37,-0.34,0.34,-0.25,0.39,-0.18,0.39,-0.26,0.26,-0.34,0.3,-0.28,0.38,-0.29,0.34,-0.03,0.05,-0.1,0.11,-0.1,0.21,-0.25,0.3,-0.26,0.27,-0.27,0.25,-0.29,0.38,-0.23,0.29,-0.14,0.18,-0.2,0.23,-0.14,0.1,-0.18,0.25,-0.42,0.38,-0.42,0.38,-0.32,0.28,-0.3,0.32,-0.08,0.15,-0.19,0.25,-0.23,0.27,-0.24,0.36,-0.14,0.21,-0.14,0.09,-0.38,0.3,-0.43,0.35,-0.14,0.22,-0.25,0.21,-0.08,0.09,-0.23,0.27,-0.23,0.33,-0.31,0.34,-0.23,0.31,-0.32,0.32,-0.35,0.33,-0.1,0.16,-0.42,0.36,-0.38,0.35,-0.18,0.34,-0.18,0.35,-0.16,0.23,-0.21,0.26,-0.32,0.32,-0.33,0.31,-0.33,0.33,-0.29,0.38,-0.14,0.36,-0.22,0.18,-0.14,0.1,-0.18,0.34,-0.15,0.13,-0.3,0.39,-0.29,0.38,-0.23,0.31,-0.23,0.31,-0.29,0.36,-0.23,0.29,-0.21,0.25,-0.23,0.34,-0.28,0.37,-0.3,0.36,-0.19,0.18,-0.28,0.35,-0.29,0.28,-0.24,0.27,-0.35,0.34,-0.37,0.33,-0.38,0.32,-0.29,0.21,-0.14,0.16,-0.14,0.2,-0.12,0.17,-0.08,0.06,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,0.0,0.0,0.0,0.0,0.0,0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.01,-0.08,0.07,-0.03,0.03,-0.04,0.04,-0.07,0.08,-0.06,0.05,-0.02,0.02,-0.06,0.08,-0.04,0.04,-0.05,0.04,-0.07,0.08,-0.03,0.04,-0.04,0.05,-0.07,0.11,-0.05,0.05,-0.02,0.03,-0.07,0.1,-0.05,0.07,-0.05,0.05,-0.06,0.11,-0.05,0.04,-0.01,0.05,-0.03,0.03,-0.05,0.01,-0.05,0.01,-0.03,0.03,-0.03,0.06,-0.03,0.05,-0.03,0.01,-0.02,0.01,-0.01,0.01,-0.24,0.21,-0.4,0.43,-0.36,0.4,-0.06,0.07,-0.24,0.28,-0.27,0.4,-0.29,0.38,-0.13,0.16,-0.33,0.41,-0.17,0.3,-0.21,0.24,-0.15,0.23,-0.21,0.29,-0.27,0.36,-0.27,0.29,-0.42,0.38,-0.47,0.47,-0.42,0.45,-0.32,0.42,-0.27,0.36,-0.21,0.18,-0.34,0.24,-0.15,0.23,-0.16,0.24,-0.25,0.29,-0.23,0.23,-0.16,0.2,-0.25,0.22,-0.28,0.33,-0.11,0.11,-0.29,0.37,-0.34,0.37,-0.28,0.36,-0.25,0.36,-0.3,0.38,-0.23,0.25,-0.19,0.2,-0.31,0.38,-0.28,0.35,-0.16,0.21,-0.09,0.1,-0.14,0.21,-0.23,0.29,-0.22,0.25,-0.19,0.18,-0.31,0.37,-0.23,0.32,-0.22,0.36,-0.17,0.18,-0.1,0.11,-0.18,0.32,-0.23,0.31,0.0,0.0,-0.21,0.32,-0.48,0.42,-0.47,0.44,-0.44,0.43,-0.31,0.33,-0.36,0.28,-0.13,0.23,-0.08,0.1,-0.18,0.35,-0.3,0.36,-0.32,0.35,-0.27,0.29,-0.15,0.08,-0.21,0.35,-0.24,0.42,-0.05,0.08,-0.18,0.14,-0.19,0.38,-0.21,0.3,-0.23,0.34,-0.23,0.33,-0.24,0.3,-0.14,0.14,-0.16,0.32,-0.14,0.1,-0.2,0.3,-0.25,0.32,-0.21,0.29,-0.25,0.3,-0.25,0.29,-0.39,0.32,-0.4,0.33,-0.4,0.32,-0.18,0.32,-0.22,0.32,-0.14,0.24,-0.26,0.31,-0.35,0.36,-0.37,0.36,-0.21,0.27,-0.32,0.38,-0.16,0.31,-0.18,0.19,-0.21,0.3,-0.27,0.32,-0.27,0.27,-0.15,0.18,-0.29,0.33,-0.29,0.33,-0.22,0.29,-0.12,0.27,-0.43,0.4,-0.31,0.33,-0.43,0.45,-0.45,0.43,-0.19,0.17,-0.29,0.17,-0.21,0.28,-0.25,0.28,-0.32,0.33,-0.34,0.36,-0.29,0.29,-0.27,0.17,-0.2,0.23,-0.47,0.34,-0.45,0.27,-0.25,0.35,-0.1,0.1,-0.11,0.25,-0.25,0.34,-0.32,0.34,-0.19,0.32,-0.2,0.38,-0.14,0.18,-0.16,0.16,-0.22,0.3,-0.19,0.29,-0.34,0.27,-0.25,0.26,-0.27,0.27,-0.3,0.34,-0.28,0.32,-0.16,0.21,-0.1,0.13,-0.13,0.2,-0.08,0.09,-0.27,0.31,-0.38,0.33,-0.38,0.36,-0.21,0.21,-0.21,0.24,-0.11,0.1,-0.08,0.1,0.0,0.01,-0.04,0.03,-0.39,0.35,-0.44,0.38,-0.34,0.36,-0.16,0.14,-0.31,0.4,-0.3,0.38,-0.14,0.27,-0.27,0.23,-0.23,0.27,-0.25,0.34,-0.36,0.32,-0.34,0.37,-0.16,0.21,-0.15,0.29,-0.21,0.32,-0.33,0.27,-0.27,0.25,-0.44,0.4,-0.45,0.32,-0.22,0.31,-0.11,0.09,-0.36,0.37,-0.44,0.36,-0.4,0.36,-0.18,0.27,-0.23,0.34,-0.14,0.26,-0.13,0.13,-0.27,0.33,-0.34,0.36,-0.32,0.38,-0.27,0.23,-0.3,0.17,-0.32,0.31,-0.3,0.32,-0.16,0.25,-0.16,0.26,-0.07,0.05,-0.23,0.33,-0.23,0.33,-0.17,0.23,-0.32,0.3,-0.35,0.36,-0.25,0.27,-0.3,0.38,-0.14,0.29,-0.32,0.31,-0.25,0.29,-0.43,0.38,-0.5,0.44,-0.42,0.42,-0.11,0.11,-0.08,0.08,-0.18,0.33,-0.25,0.32,-0.25,0.34,-0.53,0.37,-0.5,0.47,-0.36,0.41,-0.14,0.25,-0.1,0.12,-0.21,0.31,-0.3,0.38,-0.3,0.29,-0.16,0.32,-0.24,0.29,-0.26,0.34,-0.42,0.4,-0.05,0.08,-0.18,0.29,-0.26,0.34,-0.29,0.34,-0.21,0.32,-0.25,0.35,-0.28,0.3,-0.28,0.31,-0.24,0.34,-0.32,0.4,-0.24,0.38,-0.1,0.1,-0.05,0.04,-0.48,0.37,-0.49,0.34,-0.34,0.31,-0.05,0.05,-0.21,0.35,-0.24,0.34,-0.25,0.32,-0.19,0.29,-0.14,0.16,-0.27,0.26,-0.28,0.23,-0.21,0.17,-0.15,0.14,-0.15,0.18,-0.1,0.13,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.01,0.02,-0.01,0.01,-0.03,0.07,-0.05,0.07,-0.05,0.05,-0.05,0.06,-0.07,0.13,-0.08,0.11,-0.08,0.11,-0.11,0.17,-0.04,0.07,-0.1,0.12,-0.1,0.24,-0.12,0.27,-0.12,0.21,-0.14,0.25,-0.19,0.29,-0.09,0.16,-0.19,0.33,-0.2,0.33,-0.16,0.18,-0.18,0.29,-0.16,0.34,-0.17,0.32,-0.2,0.28,-0.2,0.24,-0.21,0.31,-0.21,0.34,-0.21,0.34,-0.23,0.32,-0.25,0.31,-0.21,0.32,-0.23,0.34,-0.21,0.34,-0.23,0.34,-0.23,0.34,-0.23,0.32,-0.04,0.08,-0.01,0.02,-0.02,0.02,-0.01,0.02,-0.01,0.02,-0.01,0.02,-0.01,0.01,0.0,0.0,-0.01,0.01,0.0,0.0,0.0,0.0,-0.01,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0];

}
